@@ -51,7 +51,7 @@ class qtractorAudioEngineProxy : public QObject
 public:
 
 	// Constructor.
-	qtractorAudioEngineProxy(QObject *pParent = NULL)
+	qtractorAudioEngineProxy(QObject *pParent = nullptr)
 		: QObject(pParent) {}
 
 	// Event notifications.
@@ -222,6 +222,7 @@ public:
 	// JACK Timebase mode accessors.
 	void setTimebase(bool bTimebase);
 	bool isTimebase() const;
+	bool isTimebaseEx() const;
 
 	// JACK Timebase reset methods.
 	void resetTimebase();
@@ -370,7 +371,7 @@ public:
 
 	// Bus-buffering methods.
 	void buffer_prepare(unsigned int nframes,
-		qtractorAudioBus *pInputBus = NULL);
+		qtractorAudioBus *pInputBus = nullptr);
 	void buffer_commit(unsigned int nframes);
 
 	// Up-and-running predicate.
