@@ -1,7 +1,7 @@
 // qtractorAudioMonitor.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,6 +24,9 @@
 
 #include "qtractorMonitor.h"
 
+// Forward decls.
+class qtractorAudioMeter;
+
 
 //----------------------------------------------------------------------------
 // qtractorAudioMonitor -- Audio monitor bridge value processor.
@@ -78,6 +81,34 @@ private:
 };
 
 
+//----------------------------------------------------------------------------
+// qtractorAudioOutputMonitor -- Audio-output monitor bridge value processor.
+
+class qtractorAudioOutputMonitor : public qtractorAudioMonitor
+{
+public:
+
+	// Constructor.
+	qtractorAudioOutputMonitor(unsigned short iChannels,
+		float fGain = 1.0f, float fPanning = 0.0f);
+
+	// Destructor.
+	~qtractorAudioOutputMonitor();
+
+	// Channel property accessors.
+	void setChannels(unsigned short iChannels);
+
+	// Associated meters (kinda observers) managament methods.
+	void addAudioMeter(qtractorAudioMeter *pAudioMeter);
+	void removeAudioMeter(qtractorAudioMeter *pAudioMeter);
+
+private:
+
+	// Instance variables.
+	QList<qtractorAudioMeter *> m_meters;
+};
+
+
 #endif  // __qtractorAudioMonitor_h
 
 // end of qtractorAudioMonitor.h
