@@ -1,7 +1,7 @@
 // qtractorConnectForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -42,11 +42,8 @@ qtractorConnectForm::qtractorConnectForm (
 
 	m_pAudioConnect = new qtractorAudioConnect(
 		m_ui.AudioOListView, m_ui.AudioIListView, m_ui.AudioConnectorView);
-	m_pAudioConnect->setBezierLines(true);
-
 	m_pMidiConnect = new qtractorMidiConnect(
 		m_ui.MidiOListView, m_ui.MidiIListView, m_ui.MidiConnectorView);
-	m_pMidiConnect->setBezierLines(true);
 
 	// UI signal/slot connections...
 	QObject::connect(m_ui.AudioIClientsComboBox,
@@ -87,6 +84,19 @@ qtractorConnectForm::qtractorConnectForm (
 		SLOT(midiRefresh()));
 
 	// Connect it to some UI feedback slots.
+	QObject::connect(m_ui.AudioOListView,
+		SIGNAL(itemSelectionChanged()),
+		SLOT(audioStabilize()));
+	QObject::connect(m_ui.AudioIListView,
+		SIGNAL(itemSelectionChanged()),
+		SLOT(audioStabilize()));
+	QObject::connect(m_ui.MidiOListView,
+		SIGNAL(itemSelectionChanged()),
+		SLOT(midiStabilize()));
+	QObject::connect(m_ui.MidiIListView,
+		SIGNAL(itemSelectionChanged()),
+		SLOT(midiStabilize()));
+
 	QObject::connect(m_ui.AudioOListView,
 		SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)),
 		SLOT(audioStabilize()));
@@ -125,7 +135,7 @@ void qtractorConnectForm::audioIClientChanged (void)
 #endif
 
 	// Reset any port name pattern...
-	m_ui.AudioIListView->setPortName(QString::null);
+	m_ui.AudioIListView->setPortName(QString());
 	audioRefresh();
 }
 
@@ -136,7 +146,7 @@ void qtractorConnectForm::audioOClientChanged (void)
 #endif
 
 	// Reset any port name pattern...
-	m_ui.AudioOListView->setPortName(QString::null);
+	m_ui.AudioOListView->setPortName(QString());
 	audioRefresh();
 }
 
@@ -183,10 +193,10 @@ void qtractorConnectForm::audioUpdate ( bool bClear )
 
 	m_ui.AudioOListView->setClientName(
 		m_ui.AudioOClientsComboBox->currentIndex() > 0 && !bClear
-			? m_ui.AudioOClientsComboBox->currentText() : QString::null);
+			? m_ui.AudioOClientsComboBox->currentText() : QString());
 	m_ui.AudioIListView->setClientName(
 		m_ui.AudioIClientsComboBox->currentIndex() > 0 && !bClear
-			? m_ui.AudioIClientsComboBox->currentText() : QString::null);
+			? m_ui.AudioIClientsComboBox->currentText() : QString());
 
 	m_pAudioConnect->updateContents(bClear);
 
@@ -245,7 +255,7 @@ void qtractorConnectForm::midiIClientChanged (void)
 #endif
 
 	// Reset any port name pattern...
-	m_ui.MidiIListView->setPortName(QString::null);
+	m_ui.MidiIListView->setPortName(QString());
 	midiRefresh();
 }
 
@@ -256,7 +266,7 @@ void qtractorConnectForm::midiOClientChanged (void)
 #endif
 
 	// Reset any port name pattern...
-	m_ui.MidiOListView->setPortName(QString::null);
+	m_ui.MidiOListView->setPortName(QString());
 	midiRefresh();
 }
 
@@ -303,10 +313,10 @@ void qtractorConnectForm::midiUpdate ( bool bClear )
 
 	m_ui.MidiOListView->setClientName(
 		m_ui.MidiOClientsComboBox->currentIndex() > 0 && !bClear
-			? m_ui.MidiOClientsComboBox->currentText() : QString::null);
+			? m_ui.MidiOClientsComboBox->currentText() : QString());
 	m_ui.MidiIListView->setClientName(
 		m_ui.MidiIClientsComboBox->currentIndex() > 0 && !bClear
-			? m_ui.MidiIClientsComboBox->currentText() : QString::null);
+			? m_ui.MidiIClientsComboBox->currentText() : QString());
 
 	m_pMidiConnect->updateContents(bClear);
 	
