@@ -1,7 +1,7 @@
 // qtractorFileListView.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -65,9 +65,9 @@ public:
 
 	// Add a new group/file item, optionally under a given group.
 	qtractorFileGroupItem *addGroupItem(const QString& sName,
-		qtractorFileGroupItem *pParentItem = NULL);
+		qtractorFileGroupItem *pParentItem = nullptr);
 	qtractorFileListItem *addFileItem(const QString& sPath,
-		qtractorFileGroupItem *pParentItem = NULL);
+		qtractorFileGroupItem *pParentItem = nullptr);
 
 	// Current group/file item accessors...
 	qtractorFileGroupItem *currentGroupItem() const;
@@ -78,8 +78,8 @@ public:
 	qtractorFileListItem  *findFileItem(const QString& sPath) const;
 
 	// Make as current selection an existing file item.
-	qtractorFileListItem *selectFileItem(const QString& sPath,
-		int iChannel = -1);
+	qtractorFileListItem *selectFileItem(
+		const QString& sPath, int iChannel = -1);
 
 	// Add a new group item below the current one.
 	void newGroup();
@@ -99,7 +99,7 @@ public:
 	void cleanup();
 
 	// Emit actiovation signal for given item...
-	void activateItem(QTreeWidgetItem *pItem = NULL);
+	void activateItem(QTreeWidgetItem *pItem = nullptr);
 
 	// Master clean-up.
 	void clear();
