@@ -35,6 +35,7 @@
 #include "qtractorMidiEditorForm.h"
 
 #include "qtractorMainForm.h"
+
 #if 0//QTRACTOR_MIDI_EDITOR_TOOL
 #include "qtractorOptions.h"
 #endif
@@ -171,24 +172,31 @@ qtractorMidiClip::FileHash qtractorMidiClip::g_hashFiles;
 qtractorMidiClip::qtractorMidiClip ( qtractorTrack *pTrack )
 	: qtractorClip(pTrack)
 {
-	m_pFile = NULL;
-	m_pKey  = NULL;
-	m_pData = NULL;
+	m_pFile = nullptr;
+	m_pKey  = nullptr;
+	m_pData = nullptr;
 
 	m_iTrackChannel = 0;
 	m_bSessionFlag = false;
 	m_iRevision = 0;
 
-	m_pMidiEditorForm = NULL;
+	m_pMidiEditorForm = nullptr;
+
+	m_iEditorHorizontalZoom = 100;
+	m_iEditorVerticalZoom = 100;
+
+	m_iBeatsPerBar2 = 0;
+	m_iBeatDivisor2 = 0;
 }
 
+
 // Copy constructor.
 qtractorMidiClip::qtractorMidiClip ( const qtractorMidiClip& clip )
 	: qtractorClip(clip.track())
 {
-	m_pFile = NULL;
-	m_pKey  = NULL;
-	m_pData = NULL;
+	m_pFile = nullptr;
+	m_pKey  = nullptr;
+	m_pData = nullptr;
 
 	setFilename(clip.filename());
 	setTrackChannel(clip.trackChannel());
@@ -199,7 +207,16 @@ qtractorMidiClip::qtractorMidiClip ( const qtractorMidiClip& clip )
 	m_bSessionFlag = false;
 	m_iRevision = clip.revision();
 
-	m_pMidiEditorForm = NULL;
+	m_pMidiEditorForm = nullptr;
+
+	m_iEditorHorizontalZoom = clip.editorHorizontalZoom();
+	m_iEditorVerticalZoom = clip.editorVerticalZoom();
+
+	m_editorHorizontalSizes = clip.editorHorizontalSizes();
+	m_editorVerticalSizes = clip.editorVerticalSizes();
+
+	m_iBeatsPerBar2 = clip.beatsPerBar2();
+	m_iBeatDivisor2 = clip.beatDivisor2();
 }
 
 
@@ -219,11 +236,11 @@ bool qtractorMidiClip::createMidiFile (
 	closeMidiFile();
 
 	qtractorTrack *pTrack = track();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 
 	qtractorSession *pSession = pTrack->session();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 #ifdef CONFIG_DEBUG_0
@@ -257,7 +274,7 @@ bool qtractorMidiClip::createMidiFile (
 	m_pFile = new qtractorMidiFile();
 	if (!m_pFile->open(sFilename, qtractorMidiFile::Write)) {
 		delete m_pFile;
-		m_pFile = NULL;
+		m_pFile = nullptr;
 		return false;
 	}
 
@@ -289,14 +306,14 @@ bool qtractorMidiClip::createMidiFile (
 		}
 		// Sure this is a brand new file...
 		if (iFormat == 1)
-			m_pFile->writeTrack(NULL);
+			m_pFile->writeTrack(nullptr);
 		m_pFile->writeTrack(pSeq);
 		m_pFile->close();
 	}
 
 	// It's there now.
 	delete m_pFile;
-	m_pFile = NULL;
+	m_pFile = nullptr;
 
 	// Clip name should be clear about it all.
 	if (clipName().isEmpty())
@@ -319,11 +336,11 @@ bool qtractorMidiClip::openMidiFile (
 	closeMidiFile();
 
 	qtractorTrack *pTrack = track();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 
 	qtractorSession *pSession = pTrack->session();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 #ifdef CONFIG_DEBUG_0
@@ -344,7 +361,7 @@ bool qtractorMidiClip::openMidiFile (
 	// New key-data sequence...
 	if (!bWrite) {
 		m_pKey  = new Key(this);
-		m_pData = g_hashTable.value(*m_pKey, NULL);
+		m_pData = g_hashTable.value(*m_pKey, nullptr);
 		if (m_pData) {
 			m_pData->attach(this);
 			qtractorMidiSequence *pSeq = m_pData->sequence();
@@ -367,7 +384,7 @@ bool qtractorMidiClip::openMidiFile (
 	m_pFile = new qtractorMidiFile();
 	if (!m_pFile->open(sFilename, iMode)) {
 		delete m_pFile;
-		m_pFile = NULL;
+		m_pFile = nullptr;
 		return false;
 	}
 
@@ -435,12 +452,12 @@ bool qtractorMidiClip::openMidiFile (
 			// Import eventual SysEx setup...
 			// - take care that given track might not be currently open,
 			//   so that we'll resolve MIDI output bus somehow...
-			qtractorMidiBus *pMidiBus = NULL;
+			qtractorMidiBus *pMidiBus = nullptr;
 			qtractorMidiEngine *pMidiEngine = pSession->midiEngine();
 			if (pMidiEngine) {
 				pMidiBus = static_cast<qtractorMidiBus *> (
 					pMidiEngine->findOutputBus(pTrack->outputBusName()));
-				if (pMidiBus == NULL) {
+				if (pMidiBus == nullptr) {
 					for (qtractorBus *pBus = pMidiEngine->buses().first();
 							pBus; pBus = pBus->next()) {
 						if (pBus->busMode() & qtractorBus::Output) {
@@ -458,7 +475,7 @@ bool qtractorMidiClip::openMidiFile (
 			qtractorMidiFileTempo *pTempoMap = m_pFile->tempoMap();
 			if (pTempoMap) {
 				pTempoMap->intoTimeScale(pSession->timeScale(), t0);
-				pSession->updateTimeScale();
+				pSession->updateTimeScaleEx();
 			}
 			// Reset session flag now.
 			m_bSessionFlag = false;
@@ -517,7 +534,7 @@ void qtractorMidiClip::closeMidiFile (void)
 			removeHashKey();
 			delete m_pData;
 		}
-		m_pData = NULL;
+		m_pData = nullptr;
 		// Unregister file path...
 		qtractorSession *pSession = qtractorSession::getInstance();
 		if (pSession)
@@ -526,12 +543,12 @@ void qtractorMidiClip::closeMidiFile (void)
 
 	if (m_pKey) {
 		delete m_pKey;
-		m_pKey = NULL;
+		m_pKey = nullptr;
 	}
 
 	if (m_pFile) {
 		delete m_pFile;
-		m_pFile = NULL;
+		m_pFile = nullptr;
 	}
 }
 
@@ -573,14 +590,14 @@ void qtractorMidiClip::setFilenameEx (
 	const QString& sFilename, bool bUpdate )
 {
 	qtractorTrack *pTrack = track();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return;
 
 	qtractorSession *pSession = pTrack->session();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
-	if (m_pData == NULL)
+	if (m_pData == nullptr)
 		return;
 
 	removeHashKey();
@@ -605,7 +622,7 @@ void qtractorMidiClip::setFilenameEx (
 // Sync all ref-counted clip-lengths.
 void qtractorMidiClip::setClipLengthEx ( unsigned long iClipLength )
 {
-	if (m_pData == NULL)
+	if (m_pData == nullptr)
 		return;
 
 	removeHashKey();
@@ -624,7 +641,7 @@ void qtractorMidiClip::setClipLengthEx ( unsigned long iClipLength )
 // Sync all ref-counted clip editors.
 void qtractorMidiClip::updateEditorEx ( bool bSelectClear )
 {
-	if (m_pData == NULL)
+	if (m_pData == nullptr)
 		return;
 
 	QListIterator<qtractorMidiClip *> iter(m_pData->clips());
@@ -636,7 +653,7 @@ void qtractorMidiClip::updateEditorEx ( bool bSelectClear )
 // Sync all ref-counted clip-dirtyness.
 void qtractorMidiClip::setDirtyEx ( bool bDirty )
 {
-	if (m_pData == NULL)
+	if (m_pData == nullptr)
 		return;
 
 	QListIterator<qtractorMidiClip *> iter(m_pData->clips());
@@ -663,7 +680,7 @@ void qtractorMidiClip::insertHashKey (void)
 
 void qtractorMidiClip::updateHashKey (void)
 {
-	if (m_pKey == NULL)
+	if (m_pKey == nullptr)
 		m_pKey = new Key(this);
 	else
 		m_pKey->update(this);
@@ -689,7 +706,7 @@ void qtractorMidiClip::removeHashKey (void)
 // Unlink (clone) local hash data.
 void qtractorMidiClip::unlinkHashData (void)
 {
-	if (m_pData == NULL)
+	if (m_pData == nullptr)
 		return;
 	if (m_pData->count() < 2)
 		return;
@@ -725,7 +742,7 @@ void qtractorMidiClip::unlinkHashData (void)
 // Relink local hash data.
 void qtractorMidiClip::relinkHashData (void)
 {
-	if (m_pData == NULL)
+	if (m_pData == nullptr)
 		return;
 	if (m_pData->count() > 1)
 		return;
@@ -733,10 +750,10 @@ void qtractorMidiClip::relinkHashData (void)
 	removeHashKey();
 	updateHashKey();
 
-	Data *pNewData = g_hashTable.value(*m_pKey, NULL);
-	if (pNewData == NULL) {
+	Data *pNewData = g_hashTable.value(*m_pKey, nullptr);
+	if (pNewData == nullptr) {
 		delete m_pKey;
-		m_pKey = NULL;
+		m_pKey = nullptr;
 	} else {
 		m_pData->detach(this);
 		delete m_pData;
@@ -790,15 +807,15 @@ void qtractorMidiClip::seek ( unsigned long iFrame )
 #endif
 
 	qtractorTrack *pTrack = track();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return;
 
 	qtractorSession *pSession = pTrack->session();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	qtractorMidiSequence *pSeq = sequence();
-	if (pSeq == NULL)
+	if (pSeq == nullptr)
 		return;
 
 	const unsigned long t0 = pSession->tickFromFrame(clipStart());
@@ -813,7 +830,7 @@ void qtractorMidiClip::seek ( unsigned long iFrame )
 void qtractorMidiClip::reset ( bool /* bLooping */ )
 {
 	qtractorMidiSequence *pSeq = sequence();
-	if (pSeq == NULL)
+	if (pSeq == nullptr)
 		return;
 
 	// Reset to the first sequence event...
@@ -837,11 +854,11 @@ void qtractorMidiClip::close (void)
 #endif
 
 	qtractorTrack *pTrack = track();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return;
 
 	qtractorSession *pSession = pTrack->session();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	// Take pretended clip-length...
@@ -868,7 +885,7 @@ void qtractorMidiClip::close (void)
 	if (bNewFile && iClipLength > 0 && pSeq) {
 		// Write channel tracks...
 		if (m_pFile->format() == 1)
-			m_pFile->writeTrack(NULL);	// Setup track (SMF format 1).
+			m_pFile->writeTrack(nullptr);	// Setup track (SMF format 1).
 		m_pFile->writeTrack(pSeq);		// Channel track.
 		m_pFile->close();
 	}
@@ -877,7 +894,7 @@ void qtractorMidiClip::close (void)
 	if (m_pMidiEditorForm) {
 		m_pMidiEditorForm->close();
 		delete m_pMidiEditorForm;
-		m_pMidiEditorForm = NULL;
+		m_pMidiEditorForm = nullptr;
 	}
 
 	// Just to be sure things get deallocated..
@@ -907,19 +924,19 @@ void qtractorMidiClip::process (
 #endif
 
 	qtractorTrack *pTrack = track();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return;
 
 	qtractorSession *pSession = pTrack->session();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	qtractorMidiEngine *pMidiEngine = pSession->midiEngine();
-	if (pMidiEngine == NULL)
+	if (pMidiEngine == nullptr)
 		return;
 
 	qtractorMidiSequence *pSeq = sequence();
-	if (pSeq == NULL)
+	if (pSeq == nullptr)
 		return;
 
 	// Track mute state...
@@ -953,15 +970,15 @@ void qtractorMidiClip::process_export (
 	unsigned long iFrameStart, unsigned long iFrameEnd )
 {
 	qtractorTrack *pTrack = track();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return;
 
 	qtractorSession *pSession = pTrack->session();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	qtractorMidiSequence *pSeq = sequence();
-	if (pSeq == NULL)
+	if (pSeq == nullptr)
 		return;
 
 	// Track mute state...
@@ -996,15 +1013,15 @@ void qtractorMidiClip::draw (
 	QPainter *pPainter, const QRect& clipRect, unsigned long iClipOffset )
 {
 	qtractorTrack *pTrack = track();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return;
 
 	qtractorSession *pSession = pTrack->session();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	qtractorMidiSequence *pSeq = sequence();
-	if (pSeq == NULL)
+	if (pSeq == nullptr)
 		return;
 
 	// Check min/maximum note span...
@@ -1108,20 +1125,20 @@ void qtractorMidiClip::update (void)
 bool qtractorMidiClip::startEditor ( QWidget *pParent )
 {
 	qtractorTrack *pTrack = track();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 
-	if (m_pMidiEditorForm == NULL) {
+	if (m_pMidiEditorForm == nullptr) {
 		// Build up the editor form...
-		// Make sure it has a parent...
-		if (pParent == NULL)
-			pParent = qtractorMainForm::getInstance();
 		// What style do we create tool childs?
 		Qt::WindowFlags wflags = Qt::Window;
 	#if 0//QTRACTOR_MIDI_EDITOR_TOOL
 		qtractorOptions *pOptions = qtractorOptions::getInstance();
 		if (pOptions && pOptions->bKeepToolsOnTop) {
 			wflags |= Qt::Tool;
+			// Make sure it has a parent...
+			if (pParent == nullptr)
+				pParent = qtractorMainForm::getInstance();
 		}
 	#endif
 		// Do it...
@@ -1134,13 +1151,6 @@ bool qtractorMidiClip::startEditor ( QWidget *pParent )
 		m_pMidiEditorForm->show();
 	}
 
-	// Set its most standing properties...
-	if (!m_posEditor.isNull()
-		&& m_posEditor.x() >= 0 && m_posEditor.y() >= 0)
-		m_pMidiEditorForm->move(m_posEditor);
-	if (!m_sizeEditor.isNull() && m_sizeEditor.isValid())
-		m_pMidiEditorForm->resize(m_sizeEditor);
-
 	// Get it up any way...
 	m_pMidiEditorForm->raise();
 	m_pMidiEditorForm->activateWindow();
@@ -1154,7 +1164,7 @@ void qtractorMidiClip::updateEditor ( bool bSelectClear )
 {
 	update();
 
-	if (m_pMidiEditorForm == NULL)
+	if (m_pMidiEditorForm == nullptr)
 		return;
 
 	qtractorMidiEditor *pMidiEditor = m_pMidiEditorForm->editor();
@@ -1179,7 +1189,7 @@ void qtractorMidiClip::updateEditor ( bool bSelectClear )
 // Clip editor update.
 void qtractorMidiClip::updateEditorContents (void)
 {
-	if (m_pMidiEditorForm == NULL)
+	if (m_pMidiEditorForm == nullptr)
 		return;
 
 	qtractorMidiEditor *pMidiEditor = m_pMidiEditorForm->editor();
@@ -1248,7 +1258,11 @@ QString qtractorMidiClip::toolTip (void) const
 bool qtractorMidiClip::saveCopyFile ( bool bUpdate )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
+		return false;
+
+	// Do nothing if session is yet untitled...
+	if (pSession->sessionName().isEmpty())
 		return false;
 
 	// Have a new filename revision...
@@ -1301,9 +1315,33 @@ bool qtractorMidiClip::loadClipElement (
 			m_sizeEditor.setWidth(swh.at(0).toInt());
 			m_sizeEditor.setHeight(swh.at(1).toInt());
 		}
+		else if (eChild.tagName() == "editor-horizontal-zoom") {
+			m_iEditorHorizontalZoom = eChild.text().toUShort();
+		}
+		else if (eChild.tagName() == "editor-vertical-zoom") {
+			m_iEditorVerticalZoom = eChild.text().toUShort();
+		}
+		else if (eChild.tagName() == "editor-horizontal-sizes") {
+			const QStringList& hsizes = eChild.text().split(',');
+			m_editorHorizontalSizes.clear();
+			m_editorHorizontalSizes.append(hsizes.at(0).toInt());
+			m_editorHorizontalSizes.append(hsizes.at(1).toInt());
+		}
+		else if (eChild.tagName() == "editor-vertical-sizes") {
+			const QStringList& vsizes = eChild.text().split(',');
+			m_editorVerticalSizes.clear();
+			m_editorVerticalSizes.append(vsizes.at(0).toInt());
+			m_editorVerticalSizes.append(vsizes.at(1).toInt());
+		}
 		else if (eChild.tagName() == "ghost-track-name") {
 			m_sGhostTrackName = eChild.text();
 		}
+		else if (eChild.tagName() == "beats-per-bar-2") {
+			m_iBeatsPerBar2 = eChild.text().toUInt();
+		}
+		else if (eChild.tagName() == "beat-divisor-2") {
+			m_iBeatDivisor2 = eChild.text().toUInt();
+		}
 	}
 
 	return true;
@@ -1313,12 +1351,6 @@ bool qtractorMidiClip::loadClipElement (
 bool qtractorMidiClip::saveClipElement (
 	qtractorDocument *pDocument, QDomElement *pElement )
 {
-	// Freeze current MIDI clip editor, if up and visible...
-	if (m_pMidiEditorForm && m_pMidiEditorForm->isVisible()) {
-		m_posEditor = m_pMidiEditorForm->pos();
-		m_sizeEditor = m_pMidiEditorForm->size();
-	}
-
 	QDomElement eMidiClip = pDocument->document()->createElement("midi-clip");
 	pDocument->saveTextElement("filename",
 		qtractorMidiClip::relativeFilename(pDocument), &eMidiClip);
@@ -1336,10 +1368,36 @@ bool qtractorMidiClip::saveClipElement (
 			QString::number(m_sizeEditor.width()) + ',' +
 			QString::number(m_sizeEditor.height()), &eMidiClip);
 	}
+	if (m_iEditorHorizontalZoom != 100) {
+		pDocument->saveTextElement("editor-horizontal-zoom",
+			QString::number(m_iEditorHorizontalZoom), &eMidiClip);
+	}
+	if (m_iEditorVerticalZoom != 100) {
+		pDocument->saveTextElement("editor-vertical-zoom",
+			QString::number(m_iEditorVerticalZoom), &eMidiClip);
+	}
+	if (m_editorHorizontalSizes.count() >= 2) {
+		pDocument->saveTextElement("editor-horizontal-sizes",
+			QString::number(m_editorHorizontalSizes.at(0)) + ',' +
+			QString::number(m_editorHorizontalSizes.at(1)), &eMidiClip);
+	}
+	if (m_editorVerticalSizes.count() >= 2) {
+		pDocument->saveTextElement("editor-vertical-sizes",
+			QString::number(m_editorVerticalSizes.at(0)) + ',' +
+			QString::number(m_editorVerticalSizes.at(1)), &eMidiClip);
+	}
 	if (!m_sGhostTrackName.isEmpty()) {
 		pDocument->saveTextElement("ghost-track-name",
 			m_sGhostTrackName, &eMidiClip);
 	}
+	if (m_iBeatsPerBar2 > 0) {
+		pDocument->saveTextElement("beats-per-bar-2",
+			QString::number(m_iBeatsPerBar2), &eMidiClip);
+	}
+	if (m_iBeatDivisor2 > 0) {
+		pDocument->saveTextElement("beat-divisor-2",
+			QString::number(m_iBeatDivisor2), &eMidiClip);
+	}
 	pElement->appendChild(eMidiClip);
 
 	return true;
@@ -1352,15 +1410,15 @@ bool qtractorMidiClip::clipExport (
 	unsigned long iOffset, unsigned long iLength ) const
 {
 	qtractorTrack *pTrack = track();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 
 	qtractorSession *pSession = pTrack->session();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	qtractorMidiSequence *pSeq = sequence();
-	if (pSeq == NULL)
+	if (pSeq == nullptr)
 		return false;
 
 	if (iLength < 1)
@@ -1414,7 +1472,7 @@ void qtractorMidiClip::enqueue_export ( qtractorTrack *pTrack,
 	qtractorMidiEvent *pEvent, unsigned long iTime, float fGain ) const
 {
 	qtractorSession *pSession = pTrack->session();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	snd_seq_event_t ev;
