@@ -1,7 +1,7 @@
 // qtractorMidiControlForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -50,7 +50,7 @@ protected:
 	bool operator< ( const QTreeWidgetItem& other ) const
 	{
 		QTreeWidget *parent = QTreeWidgetItem::treeWidget();
-		if (parent == NULL)
+		if (parent == nullptr)
 			return false;
 
 		const int col = parent->sortColumn();
@@ -105,7 +105,7 @@ qtractorMidiControlForm::qtractorMidiControlForm (
 	pHeader->setMovable(false);
 #endif
 
-	m_pControlTypeGroup = new qtractorMidiControlTypeGroup(NULL,
+	m_pControlTypeGroup = new qtractorMidiControlTypeGroup(nullptr,
 		m_ui.ControlTypeComboBox, m_ui.ParamComboBox, m_ui.ParamTextLabel);
 
 	m_ui.ControlTypeComboBox->setCurrentIndex(3); // Controller (default).
@@ -227,21 +227,21 @@ void qtractorMidiControlForm::reject (void)
 void qtractorMidiControlForm::importSlot (void)
 {
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
-	if (pOptions == NULL)
+	if (pOptions == nullptr)
 		return;
 
 	QStringList files;
 
 	const QString  sExt("qtc");
 	const QString& sTitle
-		= tr("Import Controller Files") + " - " QTRACTOR_TITLE;
+		= tr("Import Controller Files");
 
 	QStringList filters;
 	filters.append(tr("Controller files (*.%1)").arg(sExt));
 	filters.append(tr("All files (*.*)"));
 	const QString& sFilter = filters.join(";;");
 
-	QWidget *pParentWidget = NULL;
+	QWidget *pParentWidget = nullptr;
 	QFileDialog::Options options = 0;
 	if (pOptions->bDontUseNativeDialogs) {
 		options |= QFileDialog::DontUseNativeDialog;
@@ -250,7 +250,7 @@ void qtractorMidiControlForm::importSlot (void)
 #if 1//QT_VERSION < QT_VERSION_CHECK(4, 4, 0)
 	// Ask for the filename to open...
 	files = QFileDialog::getOpenFileNames(pParentWidget,
-		sTitle, pOptions->sMidiControlDir, sFilter, NULL, options);
+		sTitle, pOptions->sMidiControlDir, sFilter, nullptr, options);
 #else
 	// Construct open-files dialog...
 	QFileDialog fileDialog(pParentWidget,
@@ -277,15 +277,15 @@ void qtractorMidiControlForm::importSlot (void)
 	// Remember this last directory...
 	
 	// For avery selected controller file to load...
-	QTreeWidgetItem *pItem = NULL;
+	QTreeWidgetItem *pItem = nullptr;
 	QStringListIterator iter(files);
 	while (iter.hasNext()) {
 		// Merge the file contents into global container...
 		const QString& sPath = iter.next();
 		// Start inserting in the current selected or last item...
-		if (pItem == NULL)
+		if (pItem == nullptr)
 			pItem = m_ui.FilesListView->currentItem();
-		if (pItem == NULL) {
+		if (pItem == nullptr) {
 			int iLastItem = m_ui.FilesListView->topLevelItemCount() - 1;
 			if (iLastItem >= 0)
 				pItem = m_ui.FilesListView->topLevelItem(iLastItem);
@@ -311,7 +311,7 @@ void qtractorMidiControlForm::importSlot (void)
 void qtractorMidiControlForm::removeSlot (void)
 {
 	QTreeWidgetItem *pItem = m_ui.FilesListView->currentItem();
-	if (pItem == NULL)
+	if (pItem == nullptr)
 		return;
 
 	// Prompt user if he/she's sure about this...
@@ -319,7 +319,7 @@ void qtractorMidiControlForm::removeSlot (void)
 	if (pOptions && pOptions->bConfirmRemove) {
 		// Show the warning...
 		if (QMessageBox::warning(this,
-			tr("Warning") + " - " QTRACTOR_TITLE,
+			tr("Warning"),
 			tr("About to remove controller file:\n\n"
 			"\"%1\"\n\n"
 			"Are you sure?")
@@ -375,7 +375,7 @@ void qtractorMidiControlForm::moveDownSlot (void)
 void qtractorMidiControlForm::mapSlot (void)
 {
 	qtractorMidiControl *pMidiControl = qtractorMidiControl::getInstance();
-	if (pMidiControl == NULL)
+	if (pMidiControl == nullptr)
 		return;
 
 	const qtractorMidiControl::ControlType ctype
@@ -414,7 +414,7 @@ void qtractorMidiControlForm::mapSlot (void)
 void qtractorMidiControlForm::unmapSlot (void)
 {
 	qtractorMidiControl *pMidiControl = qtractorMidiControl::getInstance();
-	if (pMidiControl == NULL)
+	if (pMidiControl == nullptr)
 		return;
 
 	const qtractorMidiControl::ControlType ctype
@@ -441,18 +441,18 @@ void qtractorMidiControlForm::unmapSlot (void)
 void qtractorMidiControlForm::exportSlot (void)
 {
 	qtractorMidiControl *pMidiControl = qtractorMidiControl::getInstance();
-	if (pMidiControl == NULL)
+	if (pMidiControl == nullptr)
 		return;
 
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
-	if (pOptions == NULL)
+	if (pOptions == nullptr)
 		return;
 
 	QString sPath;
 
 	const QString  sExt("qtc");
 	const QString& sTitle
-		= tr("Export Controller File") + " - " QTRACTOR_TITLE;
+		= tr("Export Controller File");
 
 	QStringList filters;
 	filters.append(tr("Controller files (*.%1)").arg(sExt));
@@ -465,7 +465,7 @@ void qtractorMidiControlForm::exportSlot (void)
 	}
 	else sPath = pOptions->midiControlFiles.last();
 
-	QWidget *pParentWidget = NULL;
+	QWidget *pParentWidget = nullptr;
 	QFileDialog::Options options = 0;
 	if (pOptions->bDontUseNativeDialogs) {
 		options |= QFileDialog::DontUseNativeDialog;
@@ -474,7 +474,7 @@ void qtractorMidiControlForm::exportSlot (void)
 #if 1//QT_VERSION < QT_VERSION_CHECK(4, 4, 0)
 	// Ask for the filename to open...
 	sPath = QFileDialog::getSaveFileName(pParentWidget,
-		sTitle, sPath, sFilter, NULL, options);
+		sTitle, sPath, sFilter, nullptr, options);
 #else
 	// Construct open-files dialog...
 	QFileDialog fileDialog(pParentWidget, sTitle, sPath, sFilter);
@@ -505,7 +505,7 @@ void qtractorMidiControlForm::exportSlot (void)
 		// Check if already exists...
 		if (QFileInfo(sPath).exists()) {
 			if (QMessageBox::warning(this,
-				tr("Warning") + " - " QTRACTOR_TITLE,
+				tr("Warning"),
 				tr("The controller file already exists:\n\n"
 				"\"%1\"\n\n"
 				"Do you want to replace it?")
@@ -520,7 +520,7 @@ void qtractorMidiControlForm::exportSlot (void)
 		pOptions->sMidiControlDir = QFileInfo(sPath).absolutePath();
 		if (m_iDirtyMap > 0 &&
 			QMessageBox::warning(this,
-				tr("Warning") + " - " QTRACTOR_TITLE,
+				tr("Warning"),
 				tr("Saved controller mappings may not be effective\n"
 				"the next time you start this program.\n\n"
 				"\"%1\"\n\n"
@@ -552,13 +552,13 @@ void qtractorMidiControlForm::syncSlot ( bool bOn )
 void qtractorMidiControlForm::reloadSlot (void)
 {
 	qtractorMidiControl *pMidiControl = qtractorMidiControl::getInstance();
-	if (pMidiControl == NULL)
+	if (pMidiControl == nullptr)
 		return;
 
 	// Check if there's any pending map changes...
 	if (m_iDirtyMap > 0 && !pMidiControl->controlMap().isEmpty() &&
 		QMessageBox::warning(this,
-			tr("Warning") + " - " QTRACTOR_TITLE,
+			tr("Warning"),
 			tr("Controller mappings have been changed.") + "\n\n" +
 			tr("Do you want to save the changes?"),
 			QMessageBox::Save |
@@ -569,7 +569,7 @@ void qtractorMidiControlForm::reloadSlot (void)
 	}
 
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
-	if (pOptions == NULL)
+	if (pOptions == nullptr)
 		return;
 
 	// Ooops...
@@ -628,7 +628,7 @@ void qtractorMidiControlForm::keyChangedSlot (void)
 void qtractorMidiControlForm::stabilizeKeyChange (void)
 {
 	qtractorMidiControl *pMidiControl = qtractorMidiControl::getInstance();
-	if (pMidiControl == NULL)
+	if (pMidiControl == nullptr)
 		return;
 
 	const QString& sType    = m_ui.ControlTypeComboBox->currentText();
@@ -692,7 +692,7 @@ void qtractorMidiControlForm::valueChangedSlot (void)
 void qtractorMidiControlForm::stabilizeValueChange (void)
 {
 	qtractorMidiControl *pMidiControl = qtractorMidiControl::getInstance();
-	if (pMidiControl == NULL)
+	if (pMidiControl == nullptr)
 		return;
 
 	const qtractorMidiControl::ControlType ctype
@@ -791,11 +791,11 @@ void qtractorMidiControlForm::stabilizeForm (void)
 void qtractorMidiControlForm::refreshFiles (void)
 {
 	qtractorMidiControl *pMidiControl = qtractorMidiControl::getInstance();
-	if (pMidiControl == NULL)
+	if (pMidiControl == nullptr)
 		return;
 
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
-	if (pOptions == NULL)
+	if (pOptions == nullptr)
 		return;
 
 	// Freeze...
@@ -826,7 +826,7 @@ void qtractorMidiControlForm::refreshFiles (void)
 void qtractorMidiControlForm::refreshControlMap (void)
 {
 	qtractorMidiControl *pMidiControl = qtractorMidiControl::getInstance();
-	if (pMidiControl == NULL)
+	if (pMidiControl == nullptr)
 		return;
 
 	// Freeze...
