@@ -1,7 +1,7 @@
 // qtractorMidiControlObserver.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -61,7 +61,7 @@ qtractorMidiControlObserver::qtractorMidiControlObserver (
 		m_ctype(qtractorMidiEvent::CONTROLLER), m_iChannel(0), m_iParam(0),
 		m_bLogarithmic(false), m_bFeedback(false),
 		m_bInvert(false), m_bHook(false), m_bLatch(true), m_bTriggered(false),
-		m_fMidiValue(0.0f), m_bMidiSync(false), m_pCurveList(NULL)
+		m_fMidiValue(0.0f), m_bMidiSync(false), m_pCurveList(nullptr)
 {
 }
 
@@ -130,8 +130,8 @@ void qtractorMidiControlObserver::setMidiValue ( unsigned short iValue )
 			(fValue < v0 && v0 >= v1 && v1 >= fValue))
 			 bSync = true;
 	#else
-		const float d1 = (v1 - fValue);
-		const float d2 = (v1 - v0) * d1;
+		const float d1 = ::fabsf(v1 - fValue);
+		const float d2 = ::fabsf(v1 - v0) * d1;
 		bSync = (d2 < 0.001f);
 	#endif
 		if (bSync)
