@@ -61,7 +61,7 @@ qtractorMidiEditTime::qtractorMidiEditTime (
 	m_dragState  = DragNone;
 	m_dragCursor = DragNone;
 
-	m_pDragMarker = NULL;
+	m_pDragMarker = nullptr;
 
 	qtractorScrollView::setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 	qtractorScrollView::setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -102,15 +102,16 @@ void qtractorMidiEditTime::updatePixmap ( int cx, int /*cy*/)
 	m_pixmap.fill(pal.window().color());
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	qtractorTimeScale *pTimeScale = m_pEditor->timeScale();
-	if (pTimeScale == NULL)
+	if (pTimeScale == nullptr)
 		return;
 
 	QPainter painter(&m_pixmap);
 //	painter.initFrom(this);
+	painter.setFont(qtractorScrollView::font());
 
 	//
 	// Draw the time scale...
@@ -124,7 +125,7 @@ void qtractorMidiEditTime::updatePixmap ( int cx, int /*cy*/)
 
 	qtractorTimeScale::Cursor cursor(pTimeScale);
 	qtractorTimeScale::Node *pNode = cursor.seekPixel(dx);
-
+#if 0
 	unsigned short iPixelsPerBeat = pNode->pixelsPerBeat();
 	unsigned int iBeat = pNode->beatFromPixel(dx);
 	if (iBeat > 0) pNode = cursor.seekBeat(--iBeat);
@@ -164,6 +165,65 @@ void qtractorMidiEditTime::updatePixmap ( int cx, int /*cy*/)
 		pNode = cursor.seekBeat(++iBeat);
 		x = pNode->pixelFromBeat(iBeat) - dx;
 	}
+#else
+	unsigned short iBar = pNode->barFromPixel(dx);
+	if (iBar > 0) --iBar;
+	x = x1 = pNode->pixelFromBar(iBar) - dx;
+	while (x < w) {
+		// Next bar...
+		pNode = cursor.seekPixel(x + dx);
+		const int x2 = pNode->pixelFromBar(++iBar) - dx;
+		// Bar label...
+		if (x >= x1) {
+			const QString& sBar	= QString::number(iBar);
+			x1 = x;
+			y1 = fm.ascent();
+			painter.setPen(pal.windowText().color());
+			painter.drawText(x1 + 2, y1, sBar);
+			x1 += fm.horizontalAdvance(sBar) + 2;
+		}
+		x1 += 2;
+		// Tempo/time-sig. label...
+		if (iBar == pNode->bar + 1) {
+			const QString& sTempo = QString("%1 %2/%3")
+				.arg(pNode->tempo, 0, 'f', 1)
+				.arg(pNode->beatsPerBar)
+				.arg(1 << pNode->beatDivisor);
+			y1 = fm.ascent();
+			painter.setPen(Qt::darkGray);
+			painter.drawText(x1 + 2, y1, sTempo);
+			x1 += fm.horizontalAdvance(sTempo) + 2;
+		}
+		// Beat lines...
+		const unsigned short iBeatsPerBar2 = pNode->beatsPerBar2();
+		const float q2 = float(x2 - x) / float(iBeatsPerBar2);
+		if (q2 > 8.0f) {
+			float p2 = float(x - 1);
+			for (int i = 1; i < iBeatsPerBar2; ++i) {
+				x = int(p2 += q2);
+				if (x > w)
+					break;
+				if (x > x1) {
+					y1 = fm.ascent();
+					painter.setPen(pal.mid().color());
+					painter.drawLine(x, y1, x, y2);
+					painter.setPen(pal.light().color());
+					++x; painter.drawLine(x, y1, x, y2);
+				}
+			}
+		}
+		// Bar line...
+		if (x2 > x1) {
+			y1 = 0;
+			painter.setPen(pal.mid().color());
+			painter.drawLine(x2 - 1, y1, x2 - 1, y2);
+			painter.setPen(pal.light().color());
+			painter.drawLine(x2, y1, x2, y2);
+		}
+		// Move forward...
+		x = x2;
+	}
+#endif
 
 	// Draw location markers, if any...
 	qtractorTimeScale::Marker *pMarker
@@ -171,8 +231,18 @@ void qtractorMidiEditTime::updatePixmap ( int cx, int /*cy*/)
 	while (pMarker) {
 		x = pTimeScale->pixelFromFrame(pMarker->frame) - dx + 4;
 		if (x > w) break;
-		painter.setPen(pMarker->color);
-		painter.drawText(x, y2, pMarker->text);
+		if (pMarker->accidentals || pMarker->mode) {
+			const QString& sKeySignature
+				= qtractorTimeScale::keySignatureName(
+					pMarker->accidentals, pMarker->mode);
+			painter.setPen(Qt::darkGray);
+			painter.drawText(x, y2, sKeySignature);
+			x += fm.horizontalAdvance(sKeySignature) + 4;
+		}
+		if (!pMarker->text.isEmpty()) {
+			painter.setPen(pMarker->color);
+			painter.drawText(x, y2, pMarker->text);
+		}
 		pMarker = pMarker->next();
 	}
 
@@ -331,11 +401,11 @@ bool qtractorMidiEditTime::dragHeadStart ( const QPoint& pos )
 
 	// Check loop and punch points...
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	qtractorTimeScale *pTimeScale = m_pEditor->timeScale();
-	if (pTimeScale == NULL)
+	if (pTimeScale == nullptr)
 		return false;
 
 	const int dx = pTimeScale->pixelFromFrame(m_pEditor->offset()) + d;
@@ -417,7 +487,7 @@ void qtractorMidiEditTime::mousePressEvent ( QMouseEvent *pMouseEvent )
 	m_dragState = DragNone;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	// Which mouse state?
@@ -486,7 +556,7 @@ void qtractorMidiEditTime::mousePressEvent ( QMouseEvent *pMouseEvent )
 void qtractorMidiEditTime::mouseMoveEvent ( QMouseEvent *pMouseEvent )
 {
 	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
 	// Are we already moving/dragging something?
@@ -567,7 +637,7 @@ void qtractorMidiEditTime::mouseReleaseEvent ( QMouseEvent *pMouseEvent )
 //	qtractorScrollView::mouseReleaseEvent(pMouseEvent);
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	// Which mouse state?
@@ -672,7 +742,7 @@ void qtractorMidiEditTime::mouseReleaseEvent ( QMouseEvent *pMouseEvent )
 void qtractorMidiEditTime::mouseDoubleClickEvent ( QMouseEvent *pMouseEvent )
 {
 	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
 	// Direct snap positioning...
@@ -737,7 +807,7 @@ void qtractorMidiEditTime::resetDragState (void)
 	m_dragState  = DragNone;
 	m_dragCursor = DragNone;
 
-	m_pDragMarker = NULL;
+	m_pDragMarker = nullptr;
 
 	// HACK: give focus to track-view... 
 	m_pEditor->editView()->setFocus();
@@ -815,7 +885,7 @@ void qtractorMidiEditTime::showToolTip ( unsigned long iFrame ) const
 		return;
 
 	qtractorTimeScale *pTimeScale = m_pEditor->timeScale();
-	if (pTimeScale == NULL)
+	if (pTimeScale == nullptr)
 		return;
 
 	QString sToolTip;
@@ -864,7 +934,7 @@ void qtractorMidiEditTime::showToolTip ( const QRect& rect ) const
 		return;
 
 	qtractorTimeScale *pTimeScale = m_pEditor->timeScale();
-	if (pTimeScale == NULL)
+	if (pTimeScale == nullptr)
 		return;
 
 	const unsigned long iFrameStart = pTimeScale->frameSnap(
