@@ -129,6 +129,13 @@ public:
 	void setVerticalZoom(unsigned short iVerticalZoom);
 	unsigned short verticalZoom() const;
 
+	// Splitter sizes accessors.
+	void setHorizontalSizes(const QList<int>& sizes);
+	QList<int> horizontalSizes() const;
+
+	void setVerticalSizes(const QList<int>& sizes);
+	QList<int> verticalSizes() const;
+
 	// Local time scale accessors.
 	qtractorTimeScale *timeScale() const;
 	unsigned long timeOffset() const;
@@ -246,9 +253,6 @@ public:
 	// Retrieve current selection.
 	QList<qtractorMidiEvent *> selectedEvents() const;
 
-	// Selectable event predicate.
-	bool isEventSelectable(qtractorMidiEvent *pEvent) const;
-
 	// Whether there's any events beyond the insertion point (edit-tail).
 	bool isInsertable() const;
 
@@ -278,14 +282,14 @@ public:
 
 	// Get event from given contents position.
 	qtractorMidiEvent *eventAt(qtractorScrollView *pScrollView,
-		const QPoint& pos, QRect *pRect = NULL);
+		const QPoint& pos, QRect *pRect = nullptr);
 
 	// Start immediate some drag-edit mode...
 	qtractorMidiEvent *dragEditEvent(qtractorScrollView *pScrollView,
 		const QPoint& pos, const Qt::KeyboardModifiers& modifiers);
 	
 	// Track drag-move-select cursor and mode...
-	qtractorMidiEvent *dragMoveEvent (qtractorScrollView *pScrollView,
+	qtractorMidiEvent *dragMoveEvent(qtractorScrollView *pScrollView,
 		const QPoint& pos, const Qt::KeyboardModifiers& modifiers);
 
 	// Start drag-move-selecting...
@@ -383,15 +387,14 @@ public:
 	static const QStringList& scaleKeyNames();
 	static const QStringList& scaleTypeNames();
 
-	// Scale quantizer method.	
+	// Scale quantizer method.
 	static unsigned char snapToScale(
 		unsigned char note, int iKey, int iScale);
 
-public slots:
-
-	// Redirect selection/change notification.
+	// Redirect selection notification.
 	void selectionChangeNotify();
-	void contentsChangeNotify();
+
+public slots:
 
 	// Redirect note on/off;
 	void sendNote(int iNote, int iVelocity = 0);
@@ -475,7 +478,7 @@ protected:
 	// Apply the event drag-resize (also editing).
 	void resizeEvent(qtractorMidiEvent *pEvent,
 		long iTimeDelta, int iValueDelta,
-		qtractorMidiEditCommand *pEditCommand = NULL);
+		qtractorMidiEditCommand *pEditCommand = nullptr);
 
 	// Update event selection rectangle.
 	void updateEvent(qtractorMidiEvent *pEvent);
@@ -515,6 +518,16 @@ protected:
 	// Specialized drag/time-scale (draft)...
 	struct DragTimeScale;
 
+	// Initialize default names hash maps.
+	static void initDefaultNoteNames();
+	static void initDefaultControllerNames();
+	static void initDefaultRpnNames();
+	static void initDefaultNrpnNames();
+	static void initDefaultControl14Names();
+
+	// Scale key/note resolver.
+	static int scaleTabNote(int iScale, int n);
+
 protected slots:
 
 	// Horizontal zoom view slots.
@@ -527,6 +540,10 @@ protected slots:
 	void verticalZoomOutSlot();
 	void verticalZoomResetSlot();
 
+	// Splitters moved slots.
+	void horizontalSplitterSlot();
+	void verticalSplitterSlot();
+
 	// Command execution notification slot.
 	void updateNotifySlot(unsigned int flags);
 
@@ -548,6 +565,10 @@ private:
 	QColor m_foreground;
 	QColor m_background;
 
+	// The main widget splitters.
+	QSplitter *m_pHSplitter;
+	QSplitter *m_pVSplitter;
+
 	// The main child widgets.
 	QFrame *m_pEditListHeader;
 	qtractorMidiEditList *m_pEditList;
