@@ -1,7 +1,7 @@
 // qtractorMidiEventList.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -108,7 +108,7 @@ class qtractorMidiEventItemDelegate : public QItemDelegate
 public:
 
 	// Constructor.
-	qtractorMidiEventItemDelegate(QObject *pParent = NULL);
+	qtractorMidiEventItemDelegate(QObject *pParent = nullptr);
 
 	// QItemDelegate Interface...
 
