@@ -1,7 +1,7 @@
 // qtractorMidiFile.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -116,7 +116,7 @@ qtractorMidiFile::qtractorMidiFile (void)
 {
 	// SMF instance variables.
 	m_iMode         = None;
-	m_pFile         = NULL;
+	m_pFile         = nullptr;
 	m_iOffset       = 0;
 
 	// Header informational data.
@@ -124,10 +124,10 @@ qtractorMidiFile::qtractorMidiFile (void)
 	m_iTracks       = 0;
 	m_iTicksPerBeat = 0;
 
-	m_pTrackInfo    = NULL;
+	m_pTrackInfo    = nullptr;
 
 	// Special tempo/time-signature map.
-	m_pTempoMap     = NULL;
+	m_pTempoMap     = nullptr;
 }
 
 
@@ -148,7 +148,7 @@ bool qtractorMidiFile::open ( const QString& sFilename, int iMode )
 
 	const QByteArray aFilename = sFilename.toUtf8();
 	m_pFile = ::fopen(aFilename.constData(), iMode == Write ? "w+b" : "rb");
-	if (m_pFile == NULL)
+	if (m_pFile == nullptr)
 		return false;
 
 	m_sFilename = sFilename;
@@ -229,17 +229,17 @@ void qtractorMidiFile::close (void)
 {
 	if (m_pFile) {
 		::fclose(m_pFile);
-		m_pFile = NULL;
+		m_pFile = nullptr;
 	}
 
 	if (m_pTrackInfo) {
 		delete [] m_pTrackInfo;
-		m_pTrackInfo = NULL;
+		m_pTrackInfo = nullptr;
 	}
 
 	if (m_pTempoMap) {
 		delete m_pTempoMap;
-		m_pTempoMap = NULL;
+		m_pTempoMap = nullptr;
 	}
 }
 
@@ -248,9 +248,9 @@ void qtractorMidiFile::close (void)
 bool qtractorMidiFile::readTracks ( qtractorMidiSequence **ppSeqs,
 	unsigned short iSeqs, unsigned short iTrackChannel )
 {
-	if (m_pFile == NULL)
+	if (m_pFile == nullptr)
 		return false;
-	if (m_pTempoMap == NULL)
+	if (m_pTempoMap == nullptr)
 		return false;
 	if (m_iMode != Read)
 		return false;
@@ -391,14 +391,44 @@ bool qtractorMidiFile::readTracks ( qtractorMidiSequence **ppSeqs,
 					// Set the primordial bank patch...
 					switch (data1) {
 					case BANK_MSB:
-						// Bank MSB...
-						bank = (pSeq->bank() < 0 ? 0 : (pSeq->bank() & 0x007f));
-						pSeq->setBank(bank | (data2 << 7));
+						// Bank MSB
+						if (pSeq->bankSelMethod() < 0)
+							pSeq->setBankSelMethod(1);
+						// Bank-select method (MSB)...
+						switch (pSeq->bankSelMethod()) {
+						case 1: // Bank MSB (current)
+							pSeq->setBank(data2);
+							break;
+						case 2: // Bank LSB (previous)
+							pSeq->setBankSelMethod(0);
+							// Fall thru...
+						case 0:
+						default:
+							bank = (pSeq->bank() < 0 ? 0 : (pSeq->bank() & 0x007f));
+							pSeq->setBank(bank | (data2 << 7));
+							break;
+						}
 						break;
 					case BANK_LSB:
-						// Bank LSB...
-						bank = (pSeq->bank() < 0 ? 0 : (pSeq->bank() & 0x3f80));
-						pSeq->setBank(bank | data2);
+						// Bank LSB
+						if (pSeq->bankSelMethod() < 0)
+							pSeq->setBankSelMethod(2);
+						// Bank-select method (LSB)...
+						switch (pSeq->bankSelMethod()) {
+						case 1: // Bank MSB (previous)
+							bank = (pSeq->bank() < 0 ? 0 : (pSeq->bank() & 0x007f));
+							pSeq->setBank((bank << 7) | data2);
+							pSeq->setBankSelMethod(0);
+							break;
+						case 2: // Bank LSB (current)
+							pSeq->setBank(data2);
+							break;
+						case 0: // Normal
+						default:
+							bank = (pSeq->bank() < 0 ? 0 : (pSeq->bank() & 0x3f80));
+							pSeq->setBank(bank | data2);
+							break;
+						}
 						break;
 					default:
 						break;
@@ -406,8 +436,8 @@ bool qtractorMidiFile::readTracks ( qtractorMidiSequence **ppSeqs,
 				}
 				break;
 			case qtractorMidiEvent::PGMCHANGE:
-				data1 = 0;
-				data2 = readInt(1);
+				data1 = readInt(1);
+				data2 = 0x7f;
 				// Check if its channel filtered...
 				if (bChannelEvent) {
 					// Create the new event...
@@ -416,7 +446,7 @@ bool qtractorMidiFile::readTracks ( qtractorMidiSequence **ppSeqs,
 					pSeq->setChannel(iChannel);
 					// Set the primordial program patch...
 					if (pSeq->prog() < 0)
-						pSeq->setProg(data2);
+						pSeq->setProg(data1);
 				}
 				break;
 			case qtractorMidiEvent::CHANPRESS:
@@ -488,7 +518,7 @@ bool qtractorMidiFile::readTracks ( qtractorMidiSequence **ppSeqs,
 						pSeq->setName(
 							QString::fromLatin1((const char *) data).simplified());
 						break;
-					case qtractorMidiEvent::TIME:
+					case qtractorMidiEvent::TIMESIG:
 						// Beats per bar is the numerator of time signature...
 						if ((unsigned short) data[0] > 0) {
 							m_pTempoMap->addNodeTime(iTrackTime,
@@ -496,6 +526,10 @@ bool qtractorMidiFile::readTracks ( qtractorMidiSequence **ppSeqs,
 								(unsigned short) data[1]);
 						}
 						break;
+					case qtractorMidiEvent::KEYSIG:
+						m_pTempoMap->addMarker(iTrackTime, QString(),
+							int(char(data[0])), bool(data[1]));
+						break;
 					case qtractorMidiEvent::MARKER:
 						m_pTempoMap->addMarker(iTrackTime,
 							QString::fromLatin1((const char *) data).simplified());
@@ -546,7 +580,7 @@ bool qtractorMidiFile::readTrack ( qtractorMidiSequence *pSeq,
 // Sequence/track/channel duration reader helper.
 unsigned long qtractorMidiFile::readTrackDuration ( unsigned short iTrackChannel )
 {
-	if (m_pFile == NULL)
+	if (m_pFile == nullptr)
 		return 0;
 	if (m_iMode != Read)
 		return 0;
@@ -639,7 +673,7 @@ unsigned long qtractorMidiFile::readTrackDuration ( unsigned short iTrackChannel
 bool qtractorMidiFile::writeHeader ( unsigned short iFormat,
 	unsigned short iTracks, unsigned short iTicksPerBeat )
 {
-	if (m_pFile == NULL)
+	if (m_pFile == nullptr)
 		return false;
 	if (m_pTempoMap)
 		return false;
@@ -679,16 +713,16 @@ bool qtractorMidiFile::writeHeader ( unsigned short iFormat,
 bool qtractorMidiFile::writeTracks (
 	qtractorMidiSequence **ppSeqs, unsigned short iSeqs )
 {
-	if (m_pFile == NULL)
+	if (m_pFile == nullptr)
 		return false;
-	if (m_pTempoMap == NULL)
+	if (m_pTempoMap == nullptr)
 		return false;
 	if (m_iMode != Write)
 		return false;
 
 #ifdef CONFIG_DEBUG_0
-	if (ppSeqs == NULL)
-		qDebug("qtractorMidiFile::writeTrack(NULL,%u)", iSeqs);
+	if (ppSeqs == nullptr)
+		qDebug("qtractorMidiFile::writeTrack(nullptr,%u)", iSeqs);
 	for (unsigned short iSeq = 0; ppSeqs && iSeq < iSeqs; ++iSeq) {
 		qtractorMidiSequence *pSeq = ppSeqs[iSeq];
 		qDebug("qtractorMidiFile::writeTrack([%u]%p,%u)"
@@ -711,7 +745,7 @@ bool qtractorMidiFile::writeTracks (
 			iSeq = iTrack;
 
 		// Which is just good for track labeling...
-		qtractorMidiSequence *pSeq = NULL; 
+		qtractorMidiSequence *pSeq = nullptr; 
 		if (ppSeqs)
 			pSeq = ppSeqs[iSeq];
 
@@ -741,7 +775,7 @@ bool qtractorMidiFile::writeTracks (
 
 		// Tempo/time-signature map (track 0)
 		// - applicable to SMF format 1 files...
-		if (pSeq == NULL) {
+		if (pSeq == nullptr) {
 			unsigned long iNodeTime = 0;
 			while (pNode) {
 				while (pMarker && pMarker->tick < pNode->tick) {
@@ -809,14 +843,21 @@ bool qtractorMidiFile::writeTracks (
 			if (pSeq->bank() >= 0) {
 				iChannel = pSeq->channel();
 				iStatus  = (qtractorMidiEvent::CONTROLLER | iChannel) & 0xff;
-				writeInt(0); // delta-time=0
-				writeInt(iStatus, 1);
-				writeInt(BANK_MSB, 1);	// Bank MSB.
-				writeInt((pSeq->bank() & 0x3f80) >> 7, 1);
-				writeInt(0); // delta-time=0
-			//	writeInt(iStatus, 1);
-				writeInt(BANK_LSB, 1);	// Bank LSB.
-				writeInt((pSeq->bank() & 0x007f), 1);
+				if (0 >= pSeq->bankSelMethod() || pSeq->bankSelMethod() == 1) {
+					writeInt(0); // delta-time=0
+					writeInt(iStatus, 1);
+					writeInt(BANK_MSB, 1);	// Bank MSB.
+					if (pSeq->bankSelMethod() == 1)
+						writeInt((pSeq->bank() & 0x007f), 1);
+					else
+						writeInt((pSeq->bank() & 0x3f80) >> 7, 1);
+				}
+				if (0 >= pSeq->bankSelMethod() || pSeq->bankSelMethod() == 2) {
+					writeInt(0); // delta-time=0
+					writeInt(iStatus, 1);
+					writeInt(BANK_LSB, 1);	// Bank LSB.
+					writeInt((pSeq->bank() & 0x007f), 1);
+				}
 			}
 
 			// Track/channel program change...
@@ -834,13 +875,13 @@ bool qtractorMidiFile::writeTracks (
 
 				// Find which will be next event to write out,
 				// keeping account onto  sequence merging...
-				pSeq = NULL;
-				pEvent = NULL;
-				pEventItem = NULL;
+				pSeq = nullptr;
+				pEvent = nullptr;
+				pEventItem = nullptr;
 
 				for (iItem = 0; iItem < iItems; ++iItem) {
 					pItem = ppItems[iItem];
-					if (pItem->event &&	(pEventItem == NULL
+					if (pItem->event &&	(pEventItem == nullptr
 						|| iEventTime >= (pItem->event)->time())) {
 						iEventTime = (pItem->event)->time();
 						pEventItem = pItem;
@@ -857,9 +898,17 @@ bool qtractorMidiFile::writeTracks (
 				}
 
 				// Maybe we reached the (partial) end...
-				if (pEvent == NULL)
+				if (pEvent == nullptr)
 					break;
 
+				// Strip out all bank-select/program-changes here...
+				if ((pEvent->type() == qtractorMidiEvent::PGMCHANGE) ||
+					(pEvent->type() == qtractorMidiEvent::CONTROLLER &&
+					(pEvent->controller() == BANK_MSB ||
+					 pEvent->controller() == BANK_LSB))) {
+					continue;
+				}
+
 				// Event (absolute) time converted to file resolution...
 				iTime = pSeq->timep(pEvent->time(), m_iTicksPerBeat);
 
@@ -868,8 +917,8 @@ bool qtractorMidiFile::writeTracks (
 
 					// Get any a note-off event pending...
 					iTimeOff = iTime;
-					pNoteOff = NULL;
-					pNoteOffItem = NULL;
+					pNoteOff = nullptr;
+					pNoteOffItem = nullptr;
 
 					for (iItem = 0; iItem < iItems; ++iItem) {
 						pItem = ppItems[iItem];
@@ -882,7 +931,7 @@ bool qtractorMidiFile::writeTracks (
 					}
 
 					// Was there any?
-					if (pNoteOff == NULL)
+					if (pNoteOff == nullptr)
 						break;
 
 					// - Delta time...
@@ -1019,6 +1068,8 @@ bool qtractorMidiFile::writeTracks (
 					writeInt((pEvent->value() & 0x007f), 1);
 					break;
 				case qtractorMidiEvent::PGMCHANGE:
+					writeInt(pEvent->param(), 1);
+					break;
 				case qtractorMidiEvent::CHANPRESS:
 					writeInt(pEvent->value(), 1);
 					break;
@@ -1051,12 +1102,12 @@ bool qtractorMidiFile::writeTracks (
 
 				// Find which note-off will be next to write out,
 				// always accounting for sequence merging...
-				pNoteOff = NULL;
-				pNoteOffItem = NULL;
+				pNoteOff = nullptr;
+				pNoteOffItem = nullptr;
 
 				for (iItem = 0; iItem < iItems; ++iItem) {
 					pItem = ppItems[iItem];
-					if (pItem->event &&	(pNoteOffItem == NULL
+					if (pItem->event &&	(pNoteOffItem == nullptr
 						|| iTimeOff >= (pItem->event)->time())) {
 						iTimeOff = (pItem->event)->time();
 						pNoteOffItem = pItem;
@@ -1072,7 +1123,7 @@ bool qtractorMidiFile::writeTracks (
 				}
 
 				// Maybe we reached the (whole) end...
-				if (pNoteOff == NULL)
+				if (pNoteOff == nullptr)
 					break;
 
 				// - Delta time...
@@ -1125,7 +1176,7 @@ bool qtractorMidiFile::writeTracks (
 
 bool qtractorMidiFile::writeTrack ( qtractorMidiSequence *pSeq )
 {
-	return writeTracks((pSeq ? &pSeq : NULL), 1);
+	return writeTracks((pSeq ? &pSeq : nullptr), 1);
 }
 
 
@@ -1225,7 +1276,7 @@ void qtractorMidiFile::writeNode (
 		= (pNode->tick > iLastTime ? pNode->tick - iLastTime : 0);
 	qtractorMidiFileTempo::Node *pPrev = pNode->prev();
 
-	if (pPrev == NULL || (pPrev->tempo != pNode->tempo)) {
+	if (pPrev == nullptr || (pPrev->tempo != pNode->tempo)) {
 	#ifdef CONFIG_DEBUG_0
 		qDebug("qtractorMidiFile::writeNode(%lu) time=%lu TEMPO (%g)",
 			iLastTime, iDeltaTime, pNode->tempo);
@@ -1239,7 +1290,7 @@ void qtractorMidiFile::writeNode (
 		iDeltaTime = 0;
 	}
 
-	if (pPrev == NULL ||
+	if (pPrev == nullptr ||
 		pPrev->beatsPerBar != pNode->beatsPerBar ||
 		pPrev->beatDivisor != pNode->beatDivisor) {
 	#ifdef CONFIG_DEBUG_0
@@ -1249,7 +1300,7 @@ void qtractorMidiFile::writeNode (
 		// Time signature change...
 		writeInt(iDeltaTime);
 		writeInt(qtractorMidiEvent::META, 1);
-		writeInt(qtractorMidiEvent::TIME, 1);
+		writeInt(qtractorMidiEvent::TIMESIG, 1);
 		writeInt(4);
 		writeInt(pNode->beatsPerBar, 1);    // Numerator.
 		writeInt(pNode->beatDivisor, 1);    // Denominator.
@@ -1273,11 +1324,22 @@ void qtractorMidiFile::writeMarker (
 #endif
 
 	writeInt(iDeltaTime);
-	writeInt(qtractorMidiEvent::META, 1);
-	writeInt(qtractorMidiEvent::MARKER, 1);
-	writeInt(pMarker->text.length());
-	const QByteArray aMarker = pMarker->text.toLatin1();
-	writeData((unsigned char *) aMarker.constData(), aMarker.length());
+
+	if (pMarker->accidentals || pMarker->mode) {
+		writeInt(qtractorMidiEvent::META, 1);
+		writeInt(qtractorMidiEvent::KEYSIG, 1);
+		writeInt(2);
+		writeInt(pMarker->accidentals, 1); // 1 byte, can be negative...
+		writeInt(pMarker->mode, 1);
+	}
+
+	if (!pMarker->text.isEmpty()) {
+		writeInt(qtractorMidiEvent::META, 1);
+		writeInt(qtractorMidiEvent::MARKER, 1);
+		writeInt(pMarker->text.length());
+		const QByteArray aMarker = pMarker->text.toLatin1();
+		writeData((unsigned char *) aMarker.constData(), aMarker.length());
+	}
 }
 
 
@@ -1323,11 +1385,11 @@ bool qtractorMidiFile::saveCopyFile ( const QString& sNewFilename,
 	qtractorTimeScale ts;
 	unsigned short iTracks;
 	unsigned short iSeq, iSeqs = 0;
-	qtractorMidiSequence **ppSeqs = NULL;
+	qtractorMidiSequence **ppSeqs = nullptr;
 
 	const QString sTrackName("Track %1");
 
-	if (pSeq == NULL)
+	if (pSeq == nullptr)
 		return false;
 
 	if (pTimeScale)
@@ -1352,7 +1414,7 @@ bool qtractorMidiFile::saveCopyFile ( const QString& sNewFilename,
 	if (!file.open(sNewFilename, qtractorMidiFile::Write))
 		return false;
 
-	if (ppSeqs == NULL)
+	if (ppSeqs == nullptr)
 		iSeqs = (iFormat == 0 ? 1 : 2);
 
 	// Write SMF header...
@@ -1375,7 +1437,7 @@ bool qtractorMidiFile::saveCopyFile ( const QString& sNewFilename,
 	} else {
 		// Most probabley this is a brand new file...
 		if (iFormat == 1)
-			file.writeTrack(NULL);
+			file.writeTrack(nullptr);
 		file.writeTrack(pSeq);
 	}
 
