@@ -65,7 +65,7 @@ public:
 	bool runState() const;
 
 	// Wake from executive wait condition.
-	void sync(qtractorMidiSyncItem *pSyncItem = NULL);
+	void sync(qtractorMidiSyncItem *pSyncItem = nullptr);
 
 protected:
 
@@ -177,7 +177,7 @@ void qtractorMidiSyncThread::run (void)
 // Wake from executive wait condition.
 void qtractorMidiSyncThread::sync ( qtractorMidiSyncItem *pSyncItem )
 {
-	if (pSyncItem == NULL) {
+	if (pSyncItem == nullptr) {
 		unsigned int r = m_iSyncRead;
 		unsigned int w = m_iSyncWrite;
 		while (r != w) {
@@ -220,14 +220,14 @@ void qtractorMidiSyncThread::sync ( qtractorMidiSyncItem *pSyncItem )
 // class qtractorMidiSyncItem -- MIDI sync item impl.
 //
 
-qtractorMidiSyncThread *qtractorMidiSyncItem::g_pSyncThread         = NULL;
+qtractorMidiSyncThread *qtractorMidiSyncItem::g_pSyncThread         = nullptr;
 unsigned int            qtractorMidiSyncItem::g_iSyncThreadRefCount = 0;
 
 // Constructor.
 qtractorMidiSyncItem::qtractorMidiSyncItem (void)
 	: m_bWaitSync(false)
 {
-	if (++g_iSyncThreadRefCount == 1 && g_pSyncThread == NULL) {
+	if (++g_iSyncThreadRefCount == 1 && g_pSyncThread == nullptr) {
 		g_pSyncThread = new qtractorMidiSyncThread();
 		g_pSyncThread->start(QThread::HighestPriority);
 	}
@@ -237,7 +237,7 @@ qtractorMidiSyncItem::qtractorMidiSyncItem (void)
 // Destructor.
 qtractorMidiSyncItem::~qtractorMidiSyncItem (void)
 {
-	if (--g_iSyncThreadRefCount == 0 && g_pSyncThread != NULL) {
+	if (--g_iSyncThreadRefCount == 0 && g_pSyncThread != nullptr) {
 		// Try to wake and terminate executive thread,
 		// but give it a bit of time to cleanup...
 		if (g_pSyncThread->isRunning()) do {
@@ -246,7 +246,7 @@ qtractorMidiSyncItem::~qtractorMidiSyncItem (void)
 			g_pSyncThread->sync();
 		} while (!g_pSyncThread->wait(100));
 		delete g_pSyncThread;
-		g_pSyncThread = NULL;
+		g_pSyncThread = nullptr;
 	}
 }
 
@@ -304,24 +304,24 @@ bool qtractorMidiInputBuffer::enqueue (
 // Process buffer (in asynchronous controller thread).
 void qtractorMidiOutputBuffer::processSync (void)
 {
-	if (m_pMidiBus == NULL)
+	if (m_pMidiBus == nullptr)
 		return;
 
 	if (!(m_pMidiBus->busMode() & qtractorBus::Output))
 		return;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	qtractorMidiEngine *pMidiEngine = pSession->midiEngine();
-	if (pMidiEngine == NULL)
+	if (pMidiEngine == nullptr)
 		return;
 
 	const unsigned long iTimeStart = pMidiEngine->timeStartEx();
 	qtractorTimeScale::Cursor cursor(pSession->timeScale());
 
-	qtractorMidiManager *pMidiManager = NULL;
+	qtractorMidiManager *pMidiManager = nullptr;
 	if (m_pMidiBus->pluginList_out())
 		pMidiManager = (m_pMidiBus->pluginList_out())->midiManager();
 	qtractorMidiMonitor *pMidiMonitor = m_pMidiBus->midiMonitor_out();
@@ -403,17 +403,17 @@ qtractorMidiManager::qtractorMidiManager (
 	m_queuedBuffer(iBufferSize),
 	m_postedBuffer(iBufferSize),
 	m_controllerBuffer(iBufferSize >> 2),
-	m_pEventBuffer(NULL), m_iEventCount(0),
+	m_pEventBuffer(nullptr), m_iEventCount(0),
 #ifdef CONFIG_MIDI_PARSER
-	m_pMidiParser(NULL),
+	m_pMidiParser(nullptr),
 #endif
 	m_iEventBuffer(0),
 	m_bAudioOutputBus(pPluginList->isAudioOutputBus()),
 	m_sAudioOutputBusName(pPluginList->audioOutputBusName()),
-	m_pAudioOutputBus(NULL),
+	m_pAudioOutputBus(nullptr),
 	m_bAudioOutputAutoConnect(pPluginList->isAudioOutputAutoConnect()),
 	m_bAudioOutputMonitor(pPluginList->isAudioOutputMonitor()),
-	m_pAudioOutputMonitor(NULL),
+	m_pAudioOutputMonitor(nullptr),
 	m_iCurrentBank(pPluginList->midiBank()),
 	m_iCurrentProg(pPluginList->midiProg()),
 	m_iPendingBankMSB(-1),
@@ -485,7 +485,7 @@ qtractorMidiManager::~qtractorMidiManager (void)
 #ifdef CONFIG_MIDI_PARSER
 	if (m_pMidiParser) {
 		snd_midi_event_free(m_pMidiParser);
-		m_pMidiParser = NULL;
+		m_pMidiParser = nullptr;
 	}
 #endif
 
@@ -704,7 +704,7 @@ void qtractorMidiManager::processSync (void)
 void qtractorMidiManager::reset (void)
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	pSession->lock();
@@ -765,8 +765,8 @@ qtractorMidiManager *qtractorMidiManager::createMidiManager (
 	qtractorPluginList *pPluginList )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
-		return NULL;
+	if (pSession == nullptr)
+		return nullptr;
 
 	qtractorMidiManager *pMidiManager
 		= new qtractorMidiManager(pPluginList);
@@ -783,11 +783,11 @@ qtractorMidiManager *qtractorMidiManager::createMidiManager (
 void qtractorMidiManager::deleteMidiManager (
 	qtractorMidiManager *pMidiManager )
 {
-	if (pMidiManager == NULL)
+	if (pMidiManager == nullptr)
 		return;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 #ifdef CONFIG_DEBUG_0
@@ -846,7 +846,7 @@ void qtractorMidiManager::processEventBuffers (void)
 {
 #ifdef CONFIG_MIDI_PARSER
 
-	if (m_pMidiParser == NULL)
+	if (m_pMidiParser == nullptr)
 		return;
 
 	const unsigned short iInputBuffer = m_iEventBuffer & 1;
@@ -1084,7 +1084,7 @@ void qtractorMidiManager::lv2_events_swap (void)
 			&& lv2_event_is_valid(&eiter)) {
 		unsigned char *pMidiData;
 		LV2_Event *pLv2Event = lv2_event_get(&eiter, &pMidiData);
-		if (pLv2Event == NULL)
+		if (pLv2Event == nullptr)
 			break;
 		if (pLv2Event->type == QTRACTOR_LV2_MIDI_EVENT_ID) {
 			long iMidiData = pLv2Event->size;
@@ -1158,7 +1158,7 @@ void qtractorMidiManager::lv2_atom_buffer_swap (void)
 	while (iMidiEvents < MaxMidiEvents) {
 		unsigned char *pMidiData;
 		LV2_Atom_Event *pLv2AtomEvent = lv2_atom_buffer_get(&aiter, &pMidiData);
-		if (pLv2AtomEvent == NULL)
+		if (pLv2AtomEvent == nullptr)
 			break;
 		if (pLv2AtomEvent->body.type == QTRACTOR_LV2_MIDI_EVENT_ID) {
 			long iMidiData = pLv2AtomEvent->body.size;
@@ -1211,7 +1211,7 @@ void qtractorMidiManager::lv2_atom_buffer_resize ( unsigned int iMinBufferSize )
 		return;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	const bool bPlaying = pSession->isPlaying();
@@ -1273,7 +1273,7 @@ bool qtractorMidiManager::isDefaultAudioOutputMonitor (void)
 void qtractorMidiManager::setAudioOutputBus ( bool bAudioOutputBus )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	pSession->lock();
@@ -1294,7 +1294,7 @@ void qtractorMidiManager::setAudioOutputBus ( bool bAudioOutputBus )
 void qtractorMidiManager::resetAudioOutputBus (void)
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	pSession->lock();
@@ -1317,11 +1317,11 @@ void qtractorMidiManager::resetAudioOutputBus (void)
 void qtractorMidiManager::createAudioOutputBus (void)
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	qtractorAudioEngine *pAudioEngine = pSession->audioEngine();
-	if (pAudioEngine == NULL)
+	if (pAudioEngine == nullptr)
 		return;
 
 	deleteAudioOutputBus();
@@ -1345,7 +1345,7 @@ void qtractorMidiManager::createAudioOutputBus (void)
 			m_pAudioOutputBus = static_cast<qtractorAudioBus *> (
 				pAudioEngine->findOutputBus(m_sAudioOutputBusName));
 		// Otherwise bus gets to be the first available output bus...
-		if (m_pAudioOutputBus == NULL) {
+		if (m_pAudioOutputBus == nullptr) {
 			for (qtractorBus *pBus = (pAudioEngine->buses()).first();
 					pBus; pBus = pBus->next()) {
 				if (pBus->busMode() & qtractorBus::Output) {
@@ -1384,7 +1384,7 @@ void qtractorMidiManager::deleteAudioOutputBus (void)
 	}
 
 	// Done.
-	m_pAudioOutputBus = NULL;
+	m_pAudioOutputBus = nullptr;
 }
 
 
@@ -1392,7 +1392,7 @@ void qtractorMidiManager::deleteAudioOutputBus (void)
 void qtractorMidiManager::setAudioOutputMonitor ( bool bAudioOutputMonitor )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	pSession->lock();
