@@ -84,7 +84,7 @@ void qtractorMidiMeterScale::paintScale ( QPainter *pPainter )
 {
 	qtractorMidiMeter *pMidiMeter
 		= static_cast<qtractorMidiMeter *> (meter());
-	if (pMidiMeter == NULL)
+	if (pMidiMeter == nullptr)
 		return;
 
 	const int h = QWidget::height() - 4;
@@ -130,11 +130,11 @@ void qtractorMidiMeterValue::refresh ( unsigned long iStamp )
 {
 	qtractorMidiMeter *pMidiMeter
 		= static_cast<qtractorMidiMeter *> (meter());
-	if (pMidiMeter == NULL)
+	if (pMidiMeter == nullptr)
 		return;
 
 	qtractorMidiMonitor *pMidiMonitor = pMidiMeter->midiMonitor();
-	if (pMidiMonitor == NULL)
+	if (pMidiMonitor == nullptr)
 		return;
 
 	const float fValue = pMidiMonitor->value_stamp(iStamp);
@@ -178,7 +178,7 @@ void qtractorMidiMeterValue::paintEvent ( QPaintEvent * )
 {
 	qtractorMidiMeter *pMidiMeter
 		= static_cast<qtractorMidiMeter *> (meter());
-	if (pMidiMeter == NULL)
+	if (pMidiMeter == nullptr)
 		return;
 
 	QPainter painter(this);
@@ -258,11 +258,11 @@ void qtractorMidiMeterLed::refresh ( unsigned long iStamp )
 {
 	qtractorMidiMeter *pMidiMeter
 		= static_cast<qtractorMidiMeter *> (meter());
-	if (pMidiMeter == NULL)
+	if (pMidiMeter == nullptr)
 		return;
 
 	qtractorMidiMonitor *pMidiMonitor = pMidiMeter->midiMonitor();
-	if (pMidiMonitor == NULL)
+	if (pMidiMonitor == nullptr)
 		return;
 
 	// Take care of the MIDI LED status...
@@ -408,7 +408,7 @@ qtractorMidiComboMeter::qtractorMidiComboMeter (
 	: QWidget(pParent)
 {
 	m_pMidiMeter = new qtractorMidiMeter(pMidiMonitor);
-	m_pAudioMeter = NULL;
+	m_pAudioMeter = nullptr;
 
 	QHBoxLayout *pHBoxLayout = new QHBoxLayout();
 	pHBoxLayout->setMargin(0);
@@ -423,10 +423,17 @@ qtractorMidiComboMeter::qtractorMidiComboMeter (
 // Default destructor.
 qtractorMidiComboMeter::~qtractorMidiComboMeter (void)
 {
-	if (m_pAudioMeter)
-		delete m_pAudioMeter;
+	if (m_pAudioMeter) {
+		// Take care of those audio meters on MIDI tracks...
+		qtractorAudioOutputMonitor *pAudioOutputMonitor
+			= static_cast<qtractorAudioOutputMonitor *> (m_pAudioMeter->audioMonitor());
+		if (pAudioOutputMonitor)
+			pAudioOutputMonitor->removeAudioMeter(m_pAudioMeter);
+		// We're probably good now...
+		//delete m_pAudioMeter;
+	}
 
-	delete m_pMidiMeter;
+	//delete m_pMidiMeter;
 
 	// No need to delete child widgets, Qt does it all for us
 }
@@ -450,7 +457,7 @@ qtractorAudioMeter *qtractorMidiComboMeter::audioMeter (void) const
 void qtractorMidiComboMeter::reset (void)
 {
 	qtractorMidiMonitor *pMidiMonitor = m_pMidiMeter->midiMonitor();
-	if (pMidiMonitor == NULL)
+	if (pMidiMonitor == nullptr)
 		return;
 
 	m_pMidiMeter->reset();
@@ -501,7 +508,7 @@ void qtractorMidiComboMeter::setAudioOutputMonitor (
 	}
 	else
 	if (pAudioOutputMonitor) {
-		m_pAudioMeter = new qtractorAudioMeter(pAudioOutputMonitor, parentWidget());
+		m_pAudioMeter = new qtractorAudioMeter(pAudioOutputMonitor);
 		pAudioOutputMonitor->addAudioMeter(m_pAudioMeter);
 		QWidget::layout()->addWidget(m_pAudioMeter);
 		m_pAudioMeter->show();
@@ -515,7 +522,7 @@ qtractorAudioOutputMonitor *qtractorMidiComboMeter::audioOutputMonitor (void) co
 	if (m_pAudioMeter)
 		return static_cast<qtractorAudioOutputMonitor *> (m_pAudioMeter->audioMonitor());
 	else
-		return NULL;
+		return nullptr;
 }
 
 
@@ -613,7 +620,7 @@ qtractorMidiMixerMeter::~qtractorMidiMixerMeter (void)
 void qtractorMidiMixerMeter::reset (void)
 {
 	qtractorMidiMonitor *pMidiMonitor = m_pMidiMeter->midiMonitor();
-	if (pMidiMonitor == NULL)
+	if (pMidiMonitor == nullptr)
 		return;
 
 	m_pMidiMeter->reset();
