@@ -1,7 +1,7 @@
 // qtractorMixer.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -29,6 +29,8 @@
 #include "qtractorAudioMonitor.h"
 #include "qtractorMidiMonitor.h"
 
+#include "qtractorMidiManager.h"
+
 #include "qtractorObserverWidget.h"
 
 #include "qtractorOptions.h"
@@ -42,6 +44,7 @@
 
 #include "qtractorMidiControlObserver.h"
 
+#include "qtractorPlugin.h"
 #include "qtractorCurve.h"
 
 #include "qtractorMainForm.h"
@@ -104,7 +107,7 @@ void qtractorMonitorButton::initMonitorButton (void)
 void qtractorMonitorButton::setTrack ( qtractorTrack *pTrack )
 {
 	m_pTrack = pTrack;
-	m_pBus = NULL;
+	m_pBus = nullptr;
 
 	QPushButton::setToolTip(tr("Monitor (rec)"));
 
@@ -116,7 +119,7 @@ void qtractorMonitorButton::setTrack ( qtractorTrack *pTrack )
 void qtractorMonitorButton::setBus ( qtractorBus *pBus )
 {
 	m_pBus = pBus;
-	m_pTrack = NULL;
+	m_pTrack = nullptr;
 	
 	QPushButton::setToolTip(tr("Monitor (thru)"));
 
@@ -181,7 +184,7 @@ class qtractorMixerStrip::IconLabel : public QLabel
 public:
 
 	// Constructor.
-	IconLabel(QWidget *pParent = NULL) : QLabel(pParent) {}
+	IconLabel(QWidget *pParent = nullptr) : QLabel(pParent) {}
 
 	// Icon accessors.
 	void setIcon(const QIcon& icon)
@@ -215,7 +218,7 @@ private:
 qtractorMixerStrip::qtractorMixerStrip (
 	qtractorMixerRack *pRack, qtractorBus *pBus, qtractorBus::BusMode busMode )
 	: QFrame(pRack->workspace()), m_pRack(pRack),
-		m_pBus(pBus), m_busMode(busMode), m_pTrack(NULL)
+		m_pBus(pBus), m_busMode(busMode), m_pTrack(nullptr)
 {
 	initMixerStrip();
 }
@@ -223,7 +226,7 @@ qtractorMixerStrip::qtractorMixerStrip (
 qtractorMixerStrip::qtractorMixerStrip (
 	qtractorMixerRack *pRack, qtractorTrack *pTrack )
 	: QFrame(pRack->workspace()), m_pRack(pRack),
-		m_pBus(NULL), m_busMode(qtractorBus::None), m_pTrack(pTrack)
+		m_pBus(nullptr), m_busMode(qtractorBus::None), m_pTrack(pTrack)
 {
 	initMixerStrip();
 }
@@ -232,13 +235,28 @@ qtractorMixerStrip::qtractorMixerStrip (
 // Default destructor.
 qtractorMixerStrip::~qtractorMixerStrip (void)
 {
+	// Take special care to nullify the audio output monitor
+	// on MIDI track or buses, avoid its removal at meter's dtor...
+	qtractorTrack::TrackType meterType = qtractorTrack::None;
+	if (m_pTrack)
+		meterType = m_pTrack->trackType();
+	else
+	if (m_pBus)
+		meterType = m_pBus->busType();
+	if (meterType == qtractorTrack::Midi) {
+		qtractorMidiMixerMeter *pMidiMixerMeter
+			= static_cast<qtractorMidiMixerMeter *> (m_pMixerMeter);
+		if (pMidiMixerMeter)
+			pMidiMixerMeter->setAudioOutputMonitor(nullptr);
+	}
+
 	// No need to delete child widgets, Qt does it all for us
 #if 0
 	if (m_pMidiLabel)
 		delete m_pMidiLabel;
 
-	if (m_pMeter)
-		delete m_pMeter;
+	if (m_pMixerMeter)
+		delete m_pMixerMeter;
 
 	if (m_pSoloButton)
 		delete m_pSoloButton;
@@ -323,7 +341,7 @@ void qtractorMixerStrip::initMixerStrip (void)
 		m_pButtonLayout->addWidget(m_pRecordButton);
 		m_pButtonLayout->addWidget(m_pMuteButton);
 		m_pButtonLayout->addWidget(m_pSoloButton);
-		m_pBusButton = NULL;
+		m_pBusButton = nullptr;
 	}
 	else
 	if (m_pBus) {
@@ -345,22 +363,22 @@ void qtractorMixerStrip::initMixerStrip (void)
 		QObject::connect(m_pBusButton,
 			SIGNAL(clicked()),
 			SLOT(busButtonSlot()));
-		m_pRecordButton = NULL;
-		m_pMuteButton   = NULL;
-		m_pSoloButton   = NULL;
+		m_pRecordButton = nullptr;
+		m_pMuteButton   = nullptr;
+		m_pSoloButton   = nullptr;
 	}
 
 	m_pLayout->addWidget(m_pMonitorButton);
 	m_pLayout->addLayout(m_pButtonLayout);
 	
 	// Now, there's whether we are Audio or MIDI related...
-	m_pMixerMeter = NULL;
-	m_pMidiLabel = NULL;
+	m_pMixerMeter = nullptr;
+	m_pMidiLabel = nullptr;
 	int iFixedWidth = 54;
 	switch (meterType) {
 	case qtractorTrack::Audio: {
 		// Type cast for proper audio monitor...
-		qtractorAudioMonitor *pAudioMonitor = NULL;
+		qtractorAudioMonitor *pAudioMonitor = nullptr;
 		if (m_pTrack) {
 			pAudioMonitor
 				= static_cast<qtractorAudioMonitor *> (m_pTrack->monitor());
@@ -391,8 +409,8 @@ void qtractorMixerStrip::initMixerStrip (void)
 	}
 	case qtractorTrack::Midi: {
 		// Type cast for proper MIDI monitor...
-		qtractorMidiMonitor *pMidiMonitor = NULL;
-		qtractorMidiBus *pMidiBus = NULL;
+		qtractorMidiMonitor *pMidiMonitor = nullptr;
+		qtractorMidiBus *pMidiBus = nullptr;
 		if (m_pTrack) {
 			pMidiMonitor
 				= static_cast<qtractorMidiMonitor *> (m_pTrack->monitor());
@@ -416,28 +434,40 @@ void qtractorMixerStrip::initMixerStrip (void)
 		// Have we a MIDI monitor/meter?...
 		if (pMidiMonitor) {
 			iFixedWidth += 24;
-			m_pMixerMeter = new qtractorMidiMixerMeter(pMidiMonitor, this);
+			qtractorMidiMixerMeter *pMidiMixerMeter
+				= new qtractorMidiMixerMeter(pMidiMonitor, this);
 			// MIDI Tracks might need to show something,
 			// like proper MIDI channel settings...
 			if (m_pTrack) {
 				m_pMidiLabel = new QLabel(/*m_pMeter->topWidget()*/);
-		//		m_pMidiLabel->setFont(font2);
+			//	m_pMidiLabel->setFont(font2);
 				m_pMidiLabel->setAlignment(
 					Qt::AlignHCenter | Qt::AlignVCenter);
-				m_pMixerMeter->topLayout()->insertWidget(1, m_pMidiLabel);
+				pMidiMixerMeter->topLayout()->insertWidget(1, m_pMidiLabel);
 				updateMidiLabel();
 			}
 			// No panning on MIDI bus monitors and on duplex ones
 			// only on the output buses should be enabled...
 			if (pMidiBus) {
-				if ((m_busMode & qtractorBus::Input) &&
-					(m_pBus->busMode() & qtractorBus::Output)) {
-					m_pMixerMeter->panSlider()->setEnabled(false);
-					m_pMixerMeter->panSpinBox()->setEnabled(false);
-					m_pMixerMeter->gainSlider()->setEnabled(false);
-					m_pMixerMeter->gainSpinBox()->setEnabled(false);
+				if ((m_busMode & qtractorBus::Input)
+					&& (m_pBus->busMode() & qtractorBus::Output)) {
+					pMidiMixerMeter->panSlider()->setEnabled(false);
+					pMidiMixerMeter->panSpinBox()->setEnabled(false);
+					pMidiMixerMeter->gainSlider()->setEnabled(false);
+					pMidiMixerMeter->gainSpinBox()->setEnabled(false);
 				}
 			}
+			// Apply the combo-meter posssibility...
+			qtractorMidiManager *pMidiManager = nullptr;
+			qtractorPluginList *pPluginList = m_pPluginListView->pluginList();
+			if (pPluginList)
+				pMidiManager = pPluginList->midiManager();
+			if (pMidiManager && pMidiManager->isAudioOutputMonitor()) {
+				pMidiMixerMeter->setAudioOutputMonitor(
+					pMidiManager->audioOutputMonitor());
+			}
+			// Ready.
+			m_pMixerMeter = pMidiMixerMeter;
 		}
 		break;
 	}
@@ -512,6 +542,33 @@ void qtractorMixerStrip::setMonitor ( qtractorMonitor *pMonitor )
 			}
 		}
 	}
+	else
+	if (meterType == qtractorTrack::Midi) {
+		qtractorMidiMixerMeter *pMidiMixerMeter
+			= static_cast<qtractorMidiMixerMeter *> (m_pMixerMeter);
+		if (pMidiMixerMeter) {
+			qtractorPluginList *pPluginList = nullptr;
+			if (m_pBus) {
+				if (m_busMode & qtractorBus::Input)
+					pPluginList = m_pBus->pluginList_in();
+				else
+					pPluginList = m_pBus->pluginList_in();
+			}
+			else
+			if (m_pTrack)
+				pPluginList = m_pTrack->pluginList();
+			if (pPluginList) {
+				qtractorMidiManager *pMidiManager
+					= pPluginList->midiManager();
+				if (pMidiManager && pMidiManager->isAudioOutputMonitor()) {
+					pMidiMixerMeter->setAudioOutputMonitor(
+						pMidiManager->audioOutputMonitor());
+				} else {
+					pMidiMixerMeter->setAudioOutputMonitor(nullptr);
+				}
+			}
+		}
+	}
 
 	if (m_pMixerMeter)
 		m_pMixerMeter->setMonitor(pMonitor);
@@ -519,7 +576,7 @@ void qtractorMixerStrip::setMonitor ( qtractorMonitor *pMonitor )
 
 qtractorMonitor *qtractorMixerStrip::monitor (void) const
 {
-	return (m_pMixerMeter ? m_pMixerMeter->monitor() : NULL);
+	return (m_pMixerMeter ? m_pMixerMeter->monitor() : nullptr);
 }
 
 
@@ -578,10 +635,10 @@ void qtractorMixerStrip::updateName (void)
 // MIDI (channel) label updater.
 void qtractorMixerStrip::updateMidiLabel (void)
 {
-	if (m_pTrack == NULL)
+	if (m_pTrack == nullptr)
 		return;
 
-	if (m_pMidiLabel == NULL)
+	if (m_pMidiLabel == nullptr)
 		return;
 
 	QString sOmni;
@@ -596,9 +653,9 @@ void qtractorMixerStrip::updateMidiLabel (void)
 void qtractorMixerStrip::clear (void)
 {
 	m_pPluginListView->setEnabled(false);
-	m_pPluginListView->setPluginList(NULL);
+	m_pPluginListView->setPluginList(nullptr);
 
-	m_pRack->updateStrip(this, NULL);
+	m_pRack->updateStrip(this, nullptr);
 }
 
 
@@ -606,49 +663,21 @@ void qtractorMixerStrip::clear (void)
 void qtractorMixerStrip::setBus ( qtractorBus *pBus )
 {
 	// Must be actual bus...
-	if (m_pBus == NULL || pBus == NULL)
+	if (m_pBus == nullptr || pBus == nullptr)
 		return;
 
 	m_pBus = pBus;
 
 	if (m_busMode & qtractorBus::Input) {
 		m_pRack->updateStrip(this, m_pBus->monitor_in());
+		m_pPluginListView->setPluginList(m_pBus->pluginList_in());
 	} else {
 		m_pRack->updateStrip(this, m_pBus->monitor_out());
+		m_pPluginListView->setPluginList(m_pBus->pluginList_out());
 	}
 
-	switch (m_pBus->busType()) {
-	case qtractorTrack::Audio: {
-		qtractorAudioBus *pAudioBus
-			= static_cast<qtractorAudioBus *> (m_pBus);
-		if (pAudioBus) {
-			if (m_busMode & qtractorBus::Input) {
-				m_pPluginListView->setPluginList(pAudioBus->pluginList_in());
-			} else {
-				m_pPluginListView->setPluginList(pAudioBus->pluginList_out());
-			}
-		}
-		m_pPluginListView->setEnabled(true);
-		break;
-	}
-	case qtractorTrack::Midi: {
-		qtractorMidiBus *pMidiBus
-			= static_cast<qtractorMidiBus *> (m_pBus);
-		if (pMidiBus) {
-			if (m_busMode & qtractorBus::Input) {
-				m_pPluginListView->setPluginList(pMidiBus->pluginList_in());
-			} else {
-				m_pPluginListView->setPluginList(pMidiBus->pluginList_out());
-			}
-		}
-		m_pPluginListView->setEnabled(true);
-		break;
-	}
-	case qtractorTrack::None:
-	default:
-		break;
-	}
-	
+	m_pPluginListView->setEnabled(true);
+
 	m_pMonitorButton->setBus(m_pBus);
 
 	updateName();
@@ -659,7 +688,7 @@ void qtractorMixerStrip::setBus ( qtractorBus *pBus )
 void qtractorMixerStrip::setTrack ( qtractorTrack *pTrack )
 {
 	// Must be actual track...
-	if (m_pTrack == NULL || pTrack == NULL)
+	if (m_pTrack == nullptr || pTrack == nullptr)
 		return;
 
 	m_pTrack = pTrack;
@@ -714,7 +743,8 @@ void qtractorMixerStrip::setSelected ( bool bSelected )
 		m_pMuteButton->setPalette(pal);
 	if (m_pSoloButton)
 		m_pSoloButton->setPalette(pal);
-	m_pMixerMeter->setPalette(pal);
+	if (m_pMixerMeter)
+		m_pMixerMeter->setPalette(pal);
 	pal.setBrush(QPalette::Window, grad);
 #else
 	if (m_bSelected) {
@@ -752,7 +782,7 @@ void qtractorMixerStrip::mousePressEvent ( QMouseEvent *pMouseEvent )
 void qtractorMixerStrip::mouseDoubleClickEvent ( QMouseEvent */*pMouseEvent*/ )
 {
 	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
 	if (m_pTrack) {
@@ -766,11 +796,11 @@ void qtractorMixerStrip::mouseDoubleClickEvent ( QMouseEvent */*pMouseEvent*/ )
 // Bus connections dispatcher.
 void qtractorMixerStrip::busConnections ( qtractorBus::BusMode busMode )
 {
-	if (m_pBus == NULL)
+	if (m_pBus == nullptr)
 		return;
 
 	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
 	// Here we go...
@@ -781,11 +811,11 @@ void qtractorMixerStrip::busConnections ( qtractorBus::BusMode busMode )
 // Bus pass-through dispatcher.
 void qtractorMixerStrip::busMonitor ( bool bMonitor )
 {
-	if (m_pBus == NULL)
+	if (m_pBus == nullptr)
 		return;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	// Here we go...
@@ -797,11 +827,11 @@ void qtractorMixerStrip::busMonitor ( bool bMonitor )
 // Track monitor dispatcher.
 void qtractorMixerStrip::trackMonitor ( bool bMonitor )
 {
-	if (m_pTrack == NULL)
+	if (m_pTrack == nullptr)
 		return;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	// Here we go...
@@ -820,7 +850,7 @@ void qtractorMixerStrip::busButtonSlot (void)
 // Pan-meter slider value change slot.
 void qtractorMixerStrip::panningChangedSlot ( float fPanning )
 {
-	if (m_pMixerMeter == NULL)
+	if (m_pMixerMeter == nullptr)
 		return;
 
 #ifdef CONFIG_DEBUG_0
@@ -828,7 +858,7 @@ void qtractorMixerStrip::panningChangedSlot ( float fPanning )
 #endif
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	// Put it in the form of an undoable command...
@@ -845,7 +875,7 @@ void qtractorMixerStrip::panningChangedSlot ( float fPanning )
 // Gain-meter slider value change slot.
 void qtractorMixerStrip::gainChangedSlot ( float fGain )
 {
-	if (m_pMixerMeter == NULL)
+	if (m_pMixerMeter == nullptr)
 		return;
 
 #ifdef CONFIG_DEBUG_0
@@ -853,7 +883,7 @@ void qtractorMixerStrip::gainChangedSlot ( float fGain )
 #endif
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	// Put it in the form of an undoable command...
@@ -867,6 +897,49 @@ void qtractorMixerStrip::gainChangedSlot ( float fGain )
 }
 
 
+// Update a MIDI mixer strip, given its MIDI manager handle.
+void qtractorMixerStrip::updateMidiManager ( qtractorMidiManager *pMidiManager )
+{
+	qtractorMidiMixerMeter *pMidiMixerMeter
+		= static_cast<qtractorMidiMixerMeter *> (m_pMixerMeter);
+	if (pMidiMixerMeter == nullptr)
+		return;
+
+	// Apply the combo-meter posssibility...
+	if (pMidiManager && pMidiManager->isAudioOutputMonitor()) {
+		pMidiMixerMeter->setAudioOutputMonitor(
+			pMidiManager->audioOutputMonitor());
+	} else {
+		pMidiMixerMeter->setAudioOutputMonitor(nullptr);
+	}
+}
+
+
+// Retrieve the MIDI manager from a mixer strip, if any....
+qtractorMidiManager *qtractorMixerStrip::midiManager (void) const
+{
+	qtractorPluginList *pPluginList = nullptr;
+
+	if (m_pTrack && m_pTrack->trackType() == qtractorTrack::Midi) {
+		pPluginList = m_pTrack->pluginList();
+	}
+	else
+	if (m_pBus && m_pBus->busType() == qtractorTrack::Midi) {
+		if ((m_busMode & qtractorBus::Input) &&
+			(m_pBus->busMode() & qtractorBus::Input)) {
+			pPluginList = m_pBus->pluginList_in();
+		}
+		else
+		if ((m_busMode & qtractorBus::Output) &&
+			(m_pBus->busMode() & qtractorBus::Output)) {
+			pPluginList = m_pBus->pluginList_out();
+		}
+	}
+
+	return (pPluginList ? pPluginList->midiManager() : nullptr);
+}
+
+
 //----------------------------------------------------------------------------
 // qtractorMixerRackWidget -- Meter bridge rack widget impl.
 
@@ -925,11 +998,11 @@ void qtractorMixerRackWidget::contextMenuEvent (
 	QContextMenuEvent *pContextMenuEvent )
 {
 	// Maybe it's a track strip
-	qtractorBus *pBus = NULL;
+	qtractorBus *pBus = nullptr;
 	qtractorMixerStrip *pSelectedStrip = m_pRack->selectedStrip();
 	if (pSelectedStrip)
 		pBus = pSelectedStrip->bus();
-	if (pBus == NULL) {
+	if (pBus == nullptr) {
 		qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
 		if (pMainForm) {
 			pMainForm->stabilizeForm();
@@ -973,7 +1046,7 @@ void qtractorMixerRackWidget::contextMenuEvent (
 void qtractorMixerRackWidget::mousePressEvent ( QMouseEvent *pMouseEvent )
 {
 	if (!m_pWorkspaceWidget->rect().contains(pMouseEvent->pos()))
-		m_pRack->setSelectedStrip(NULL);
+		m_pRack->setSelectedStrip(nullptr);
 
 	QScrollArea::mousePressEvent(pMouseEvent);
 }
@@ -1051,7 +1124,6 @@ public:
 };
 
 
-
 //----------------------------------------------------------------------------
 // qtractorMixerRack -- Mixer strip rack.
 
@@ -1059,7 +1131,7 @@ public:
 qtractorMixerRack::qtractorMixerRack (
 	qtractorMixer *pMixer, const QString& sTitle )
 	: QDockWidget(sTitle, pMixer), m_pMixer(pMixer),
-		m_bSelectEnabled(false), m_pSelectedStrip(NULL),
+		m_bSelectEnabled(false), m_pSelectedStrip(nullptr),
 		m_pRackWidget(new qtractorMixerRackWidget(this))
 {
 	QDockWidget::setObjectName(sTitle);	// TODO: make this an unique-id.
@@ -1110,15 +1182,15 @@ void qtractorMixerRack::removeStrip ( qtractorMixerStrip *pStrip )
 {
 	// Don't let current selection hanging...
 	if (m_pSelectedStrip == pStrip)
-		m_pSelectedStrip = NULL;
+		m_pSelectedStrip = nullptr;
 
 	// Remove this from the workspace layout...
 	m_pRackWidget->removeStrip(pStrip);
 
 	pStrip->hide();
 
-	qtractorMonitor *pMonitor = pStrip->meter()->monitor();
-	if (findStrip(pMonitor) == pStrip) {
+	qtractorMonitor *pMonitor = pStrip->monitor();
+	if (pMonitor) {
 		m_strips.remove(pMonitor);
 		delete pStrip;
 	}
@@ -1128,9 +1200,9 @@ void qtractorMixerRack::removeStrip ( qtractorMixerStrip *pStrip )
 
 
 // Find a mixer strip, given its monitor handle.
-qtractorMixerStrip *qtractorMixerRack::findStrip ( qtractorMonitor *pMonitor )
+qtractorMixerStrip *qtractorMixerRack::findStrip ( qtractorMonitor *pMonitor ) const
 {
-	return m_strips.value(pMonitor, NULL);
+	return m_strips.value(pMonitor, nullptr);
 }
 
 
@@ -1138,10 +1210,10 @@ qtractorMixerStrip *qtractorMixerRack::findStrip ( qtractorMonitor *pMonitor )
 void qtractorMixerRack::updateStrip (
 	qtractorMixerStrip *pStrip, qtractorMonitor *pMonitor )
 {
-	qtractorMonitor *pOldMonitor = pStrip->meter()->monitor();
-	if (findStrip(pOldMonitor) == pStrip)
+	qtractorMonitor *pOldMonitor = pStrip->monitor();
+	if (pOldMonitor)
 		m_strips.remove(pOldMonitor);
-	
+
 	pStrip->setMonitor(pMonitor);
 
 	if (pMonitor)
@@ -1152,7 +1224,7 @@ void qtractorMixerRack::updateStrip (
 // Complete rack recycle.
 void qtractorMixerRack::clear (void)
 {
-	m_pSelectedStrip = NULL;
+	m_pSelectedStrip = nullptr;
 
 	qDeleteAll(m_strips);
 	m_strips.clear();
@@ -1167,7 +1239,7 @@ void qtractorMixerRack::setSelectEnabled ( bool bSelectEnabled )
 	if (m_pSelectedStrip) {
 		if (!m_bSelectEnabled)
 			m_pSelectedStrip->setSelected(false);
-		m_pSelectedStrip = NULL;
+		m_pSelectedStrip = nullptr;
 	}
 }
 
@@ -1207,7 +1279,7 @@ void qtractorMixerRack::cleanStrips ( int iMark )
 			m_pRackWidget->removeStrip(pStrip);
 			// Don't let current selection hanging...
 			if (m_pSelectedStrip == pStrip)
-				m_pSelectedStrip = NULL;
+				m_pSelectedStrip = nullptr;
 			// Hide strip...
 			pStrip->hide();
 			// Remove from list...
@@ -1262,6 +1334,49 @@ void qtractorMixerRack::busPropertiesSlot (void)
 }
 
 
+// Find a mixer strip, given its MIDI-manager handle.
+qtractorMixerStrip *qtractorMixerRack::findMidiManagerStrip (
+	qtractorMidiManager *pMidiManager ) const
+{
+	if (pMidiManager == nullptr)
+		return nullptr;
+
+	Strips::ConstIterator strip = m_strips.constBegin();
+	const Strips::ConstIterator& strip_end = m_strips.constEnd();
+	for ( ; strip != strip_end; ++strip) {
+		qtractorMixerStrip *pStrip = strip.value();
+		if (pStrip->midiManager() == pMidiManager)
+			return pStrip;
+	}
+
+	return nullptr;
+}
+
+
+// Find all the MIDI mixer strip, given an audio output bus handle.
+QList<qtractorMixerStrip *> qtractorMixerRack::findAudioOutputBusStrips (
+	qtractorAudioBus *pAudioOutputBus ) const
+{
+	QList<qtractorMixerStrip *> strips;
+
+	if (pAudioOutputBus == nullptr)
+		return strips;
+
+	Strips::ConstIterator strip = m_strips.constBegin();
+	const Strips::ConstIterator& strip_end = m_strips.constEnd();
+	for ( ; strip != strip_end; ++strip) {
+		qtractorMixerStrip *pStrip = strip.value();
+		qtractorMidiManager *pMidiManager = pStrip->midiManager();
+		if (pMidiManager &&
+			pMidiManager->audioOutputBus() == pAudioOutputBus) {
+			strips.append(pStrip);
+		}
+	}
+
+	return strips;
+}
+
+
 //----------------------------------------------------------------------------
 // qtractorMixer -- Mixer widget.
 
@@ -1282,10 +1397,10 @@ qtractorMixer::qtractorMixer ( QWidget *pParent, Qt::WindowFlags wflags )
 	QMainWindow::setMinimumHeight(320);
 
 	// Finally set the default caption and tooltip.
-	const QString& sCaption = tr("Mixer") + " - " QTRACTOR_TITLE;
-	QMainWindow::setWindowTitle(sCaption);
+	const QString& sTitle = tr("Mixer");
+	QMainWindow::setWindowTitle(sTitle);
 	QMainWindow::setWindowIcon(QIcon(":/images/viewMixer.png"));
-	QMainWindow::setToolTip(sCaption);
+	QMainWindow::setToolTip(sTitle);
 
 	QMainWindow::addDockWidget(Qt::LeftDockWidgetArea,  m_pInputRack);
 	QMainWindow::addDockWidget(Qt::RightDockWidgetArea, m_pOutputRack);
@@ -1383,7 +1498,7 @@ void qtractorMixer::updateBusStrip ( qtractorMixerRack *pRack,
 			pBus->monitor_in() : pBus->monitor_out());
 
 	qtractorMixerStrip *pStrip = pRack->findStrip(pMonitor);
-	if (pStrip == NULL) {
+	if (pStrip == nullptr) {
 		pRack->addStrip(new qtractorMixerStrip(pRack, pBus, busMode));
 	} else {
 		pStrip->setMark(0);
@@ -1402,8 +1517,8 @@ void qtractorMixer::updateBusStrip ( qtractorMixerRack *pRack,
 		if (pAudioBus) {
 			pAudioBus->applyCurveFile(busMode,
 				(busMode == qtractorBus::Input
-			       ? pAudioBus->curveFile_in()
-			       : pAudioBus->curveFile_out()));
+					? pAudioBus->curveFile_in()
+					: pAudioBus->curveFile_out()));
 		}
 		break;
 	case qtractorTrack::Midi:
@@ -1411,8 +1526,8 @@ void qtractorMixer::updateBusStrip ( qtractorMixerRack *pRack,
 		if (pMidiBus) {
 			pMidiBus->applyCurveFile(busMode,
 				(busMode == qtractorBus::Input
-			         ? pMidiBus->curveFile_in()
-			         : pMidiBus->curveFile_out()));
+					? pMidiBus->curveFile_in()
+					: pMidiBus->curveFile_out()));
 		}
 		break;
 	default:
@@ -1425,7 +1540,7 @@ void qtractorMixer::updateBusStrip ( qtractorMixerRack *pRack,
 void qtractorMixer::updateTrackStrip ( qtractorTrack *pTrack, bool bReset )
 {
 	qtractorMixerStrip *pStrip = m_pTrackRack->findStrip(pTrack->monitor());
-	if (pStrip == NULL) {
+	if (pStrip == nullptr) {
 		m_pTrackRack->addStrip(new qtractorMixerStrip(m_pTrackRack, pTrack));
 	} else {
 		pStrip->setMark(0);
@@ -1451,7 +1566,7 @@ void qtractorMixer::updateTrackStrip ( qtractorTrack *pTrack, bool bReset )
 void qtractorMixer::updateBuses ( bool bReset )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	if (bReset) {
@@ -1489,7 +1604,7 @@ void qtractorMixer::updateBuses ( bool bReset )
 void qtractorMixer::updateTracks ( bool bReset )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	if (bReset)
@@ -1506,6 +1621,32 @@ void qtractorMixer::updateTracks ( bool bReset )
 }
 
 
+// Update a MIDI mixer strip, given its MIDI manager handle.
+void qtractorMixer::updateMidiManagerStrip ( qtractorMidiManager *pMidiManager )
+{
+	qtractorMixerStrip *
+		pStrip = m_pTrackRack->findMidiManagerStrip(pMidiManager);
+	if (pStrip == nullptr)
+		pStrip = m_pOutputRack->findMidiManagerStrip(pMidiManager);
+	if (pStrip == nullptr)
+		pStrip = m_pInputRack->findMidiManagerStrip(pMidiManager);
+	if (pStrip)
+		pStrip->updateMidiManager(pMidiManager);
+}
+
+
+// Find a MIDI mixer strip, given its MIDI manager handle.
+QList<qtractorMixerStrip *> qtractorMixer::findAudioOutputBusStrips (
+	qtractorAudioBus *pAudioOutputBus ) const
+{
+	QList<qtractorMixerStrip *> strips;
+	strips.append(m_pTrackRack->findAudioOutputBusStrips(pAudioOutputBus));
+	strips.append(m_pOutputRack->findAudioOutputBusStrips(pAudioOutputBus));
+	strips.append(m_pInputRack->findAudioOutputBusStrips(pAudioOutputBus));
+	return strips;
+}
+
+
 // Complete mixer recycle.
 void qtractorMixer::clear (void)
 {
