@@ -60,28 +60,40 @@ static inline float pow10f2 ( float x )
 	{ return ::powf(10.0f, 0.05f * x); }
 
 
-// Translatable macro contextualizer.
-#undef  _TR
-#define _TR(x) QT_TR_NOOP(x)
-
+//----------------------------------------------------------------------------
 // Available session formats/ext-suffixes.
-static struct
+
+static QHash<QString, QString> g_sessionFormats;
+
+
+void qtractorOptionsForm::initSessionFormats (void)
 {
-	const char *name;
-	const char *ext;
+	static struct SessionFormat
+	{
+		const char *name;
+		const char *ext;
 
-} g_aSessionFormats[] = {
+	} s_aSessionFormats[] = {
 
-	{ _TR("XML Default (*.%1)"), "qtr" },
-	{ _TR("XML Regular (*.%1)"), "qts" },
-	{ _TR("ZIP Archive (*.%1)"), "qtz" },
+		{ QT_TR_NOOP("XML Default (*.%1)"), "qtr" },
+		{ QT_TR_NOOP("XML Regular (*.%1)"), "qts" },
+		{ QT_TR_NOOP("ZIP Archive (*.%1)"), "qtz" },
 
-	{ NULL, NULL }
-};
+		{ nullptr, nullptr }
+	};
+
+	if (g_sessionFormats.isEmpty()) {
+		for (int i = 0; s_aSessionFormats[i].name; ++i) {
+			SessionFormat& sf = s_aSessionFormats[i];
+			g_sessionFormats.insert(sf.ext, tr(sf.name));
+		}
+	}
+
+}
 
 
 // Default (empty/blank) name.
-static const char *g_pszDefName = _TR("(default)");
+static const char *g_pszDefName = QT_TRANSLATE_NOOP("qtractorOptionsForm", "(default)");
 
 
 //----------------------------------------------------------------------------
@@ -99,10 +111,10 @@ qtractorOptionsForm::qtractorOptionsForm (
 	QDialog::setWindowModality(Qt::ApplicationModal);
 
 	// No settings descriptor initially (the caller will set it).
-	m_pOptions = NULL;
+	m_pOptions = nullptr;
 
 	// Have some deafult time-scale for instance...
-	m_pTimeScale = NULL;
+	m_pTimeScale = nullptr;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
 	if (pSession) {
@@ -113,10 +125,21 @@ qtractorOptionsForm::qtractorOptionsForm (
 	}
 
 	// Populate the session format combo-box.
+	initSessionFormats();
+
 	m_ui.SessionFormatComboBox->clear();
-	for (int i = 0; g_aSessionFormats[i].ext; ++i) {
-		m_ui.SessionFormatComboBox->addItem(
-			tr(g_aSessionFormats[i].name).arg(g_aSessionFormats[i].ext));
+	QHash<QString, QString>::ConstIterator sf_iter
+		= g_sessionFormats.constBegin();
+	const QHash<QString, QString>::ConstIterator& sf_end
+		= g_sessionFormats.constEnd();
+	int iSessionFormat = 0;
+	for ( ; sf_iter != sf_end; ++sf_iter) {
+		const QString& sSessionExt = sf_iter.key();
+		const QString& sSessionFormat = sf_iter.value();
+		m_ui.SessionFormatComboBox->insertItem(
+			iSessionFormat++,
+			sSessionFormat.arg(sSessionExt),
+			sSessionExt);
 	}
 
 	// Populate the capture file type combo-box.
@@ -536,7 +559,7 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 	m_pOptions->loadComboBoxHistory(m_ui.Lv2PresetDirComboBox);
 
 	// Time-scale related options...
-	qtractorTimeScale::DisplayFormat displayFormat
+	const qtractorTimeScale::DisplayFormat displayFormat
 		= qtractorTimeScale::DisplayFormat(m_pOptions->iDisplayFormat);
 	if (m_pTimeScale)
 		m_pTimeScale->setDisplayFormat(displayFormat);
@@ -692,8 +715,10 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 		m_ui.BaseFontSizeComboBox->setCurrentIndex(0);
 
 	// Session options...
-	m_ui.SessionFormatComboBox->setCurrentIndex(
-		sessionFormatFromExt(m_pOptions->sSessionExt));
+	int iSessionFormat = m_ui.SessionFormatComboBox->findData(m_pOptions->sSessionExt);
+	if (iSessionFormat < 0)
+		iSessionFormat = 0;
+	m_ui.SessionFormatComboBox->setCurrentIndex(iSessionFormat);
 	m_ui.SessionTemplateCheckBox->setChecked(m_pOptions->bSessionTemplate);
 	m_ui.SessionTemplatePathComboBox->setEditText(m_pOptions->sSessionTemplatePath);
 	m_ui.SessionBackupCheckBox->setChecked(m_pOptions->bSessionBackup);
@@ -848,8 +873,8 @@ void qtractorOptionsForm::accept (void)
 		// Session options...
 		m_pOptions->bSessionTemplate     = m_ui.SessionTemplateCheckBox->isChecked();
 		m_pOptions->sSessionTemplatePath = m_ui.SessionTemplatePathComboBox->currentText();
-		m_pOptions->sSessionExt = sessionExtFromFormat(
-			m_ui.SessionFormatComboBox->currentIndex());
+		const int iSessionFormat         = m_ui.SessionFormatComboBox->currentIndex();
+		m_pOptions->sSessionExt          = m_ui.SessionFormatComboBox->itemData(iSessionFormat).toString();
 		m_pOptions->bSessionBackup       = m_ui.SessionBackupCheckBox->isChecked();
 		m_pOptions->iSessionBackupMode   = m_ui.SessionBackupModeComboBox->currentIndex();
 		m_pOptions->bAutoSaveEnabled     = m_ui.SessionAutoSaveCheckBox->isChecked();
@@ -917,7 +942,7 @@ void qtractorOptionsForm::reject (void)
 		if (m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->isEnabled())
 			buttons |= QMessageBox::Apply;
 		switch (QMessageBox::warning(this,
-			tr("Warning") + " - " QTRACTOR_TITLE,
+			tr("Warning"),
 			tr("Some settings have been changed.\n\n"
 			"Do you want to apply the changes?"),
 			buttons)) {
@@ -948,7 +973,7 @@ void qtractorOptionsForm::changed (void)
 void qtractorOptionsForm::chooseMetroBarFilename (void)
 {
 	QString sFilename = getOpenAudioFileName(
-		tr("Metronome Bar Audio File") + " - " QTRACTOR_TITLE,
+		tr("Metronome Bar Audio File"),
 		m_ui.MetroBarFilenameComboBox->currentText());
 
 	if (sFilename.isEmpty())
@@ -962,7 +987,7 @@ void qtractorOptionsForm::chooseMetroBarFilename (void)
 void qtractorOptionsForm::chooseMetroBeatFilename (void)
 {
 	QString sFilename = getOpenAudioFileName(
-		tr("Metronome Beat Audio File") + " - " QTRACTOR_TITLE,
+		tr("Metronome Beat Audio File"),
 		m_ui.MetroBeatFilenameComboBox->currentText());
 
 	if (sFilename.isEmpty())
@@ -1005,7 +1030,7 @@ void qtractorOptionsForm::updateMetroNoteNames (void)
 // Display format has changed.
 void qtractorOptionsForm::displayFormatChanged ( int iDisplayFormat )
 {
-	qtractorTimeScale::DisplayFormat displayFormat
+	const qtractorTimeScale::DisplayFormat displayFormat
 		= qtractorTimeScale::DisplayFormat(iDisplayFormat);
 
 	m_ui.AudioMetroOffsetSpinBox->setDisplayFormat(displayFormat);
@@ -1052,14 +1077,17 @@ void qtractorOptionsForm::resetCustomColorThemes (
 {
 	m_ui.CustomColorThemeComboBox->clear();
 	m_ui.CustomColorThemeComboBox->addItem(
-		QString::fromLatin1(g_pszDefName));
+		tr(g_pszDefName));
 	m_ui.CustomColorThemeComboBox->addItems(
 		qtractorPaletteForm::namedPaletteList(&m_pOptions->settings()));
 
 	int iCustomColorTheme = 0;
-	if (!sCustomColorTheme.isEmpty())
+	if (!sCustomColorTheme.isEmpty()) {
 		iCustomColorTheme = m_ui.CustomColorThemeComboBox->findText(
 			sCustomColorTheme);
+		if (iCustomColorTheme < 0)
+			iCustomColorTheme = 0;
+	}
 	m_ui.CustomColorThemeComboBox->setCurrentIndex(iCustomColorTheme);
 }
 
@@ -1070,14 +1098,17 @@ void qtractorOptionsForm::resetCustomStyleThemes (
 {
 	m_ui.CustomStyleThemeComboBox->clear();
 	m_ui.CustomStyleThemeComboBox->addItem(
-		QString::fromLatin1(g_pszDefName));
+		tr(g_pszDefName));
 	m_ui.CustomStyleThemeComboBox->addItems(
 		QStyleFactory::keys());
 
 	int iCustomStyleTheme = 0;
-	if (!sCustomStyleTheme.isEmpty())
+	if (!sCustomStyleTheme.isEmpty()) {
 		iCustomStyleTheme = m_ui.CustomStyleThemeComboBox->findText(
 			sCustomStyleTheme);
+		if (iCustomStyleTheme < 0)
+			iCustomStyleTheme = 0;
+	}
 	m_ui.CustomStyleThemeComboBox->setCurrentIndex(iCustomStyleTheme);
 }
 
@@ -1126,10 +1157,10 @@ void qtractorOptionsForm::changeMidiMeterColor ( const QString& sColor )
 void qtractorOptionsForm::chooseAudioMeterColor (void)
 {
 	const QString& sTitle
-		= tr("Audio Meter Color") + " - " QTRACTOR_TITLE;
+		= tr("Audio Meter Color");
 
-	QWidget *pParentWidget = NULL;
-	QColorDialog::ColorDialogOptions options = 0;
+	QWidget *pParentWidget = nullptr;
+	QColorDialog::ColorDialogOptions options = nullptr;
 	if (m_pOptions && m_pOptions->bDontUseNativeDialogs) {
 		options |= QColorDialog::DontUseNativeDialog;
 		pParentWidget = QWidget::window();
@@ -1148,10 +1179,10 @@ void qtractorOptionsForm::chooseAudioMeterColor (void)
 void qtractorOptionsForm::chooseMidiMeterColor (void)
 {
 	const QString& sTitle
-		= tr("MIDI Meter Color") + " - " QTRACTOR_TITLE;
+		= tr("MIDI Meter Color");
 
-	QWidget *pParentWidget = NULL;
-	QColorDialog::ColorDialogOptions options = 0;
+	QWidget *pParentWidget = nullptr;
+	QColorDialog::ColorDialogOptions options = nullptr;
 	if (m_pOptions && m_pOptions->bDontUseNativeDialogs) {
 		options |= QColorDialog::DontUseNativeDialog;
 		pParentWidget = QWidget::window();
@@ -1195,7 +1226,7 @@ void qtractorOptionsForm::updateColorText (
 // Change plugin type.
 void qtractorOptionsForm::choosePluginType ( int iPluginType )
 {
-	if (m_pOptions == NULL)
+	if (m_pOptions == nullptr)
 		return;
 
 	QStringList paths;
@@ -1244,9 +1275,9 @@ void qtractorOptionsForm::choosePluginPath (void)
 	QString sPluginPath;
 
 	const QString& sTitle
-		= tr("Plug-in Directory") + " - " QTRACTOR_TITLE;
+		= tr("Plug-in Directory");
 
-	QWidget *pParentWidget = NULL;
+	QWidget *pParentWidget = nullptr;
 	QFileDialog::Options options = QFileDialog::ShowDirsOnly;
 	if (m_pOptions->bDontUseNativeDialogs) {
 		options |= QFileDialog::DontUseNativeDialog;
@@ -1484,9 +1515,9 @@ void qtractorOptionsForm::chooseLv2PresetDir (void)
 		sLv2PresetDir = QDir::homePath() + QDir::separator() + ".lv2";
 
 	const QString& sTitle
-		= tr("LV2 Presets Directory") + " - " QTRACTOR_TITLE;
+		= tr("LV2 Presets Directory");
 
-	QWidget *pParentWidget = NULL;
+	QWidget *pParentWidget = nullptr;
 	QFileDialog::Options options = QFileDialog::ShowDirsOnly;
 	if (m_pOptions->bDontUseNativeDialogs) {
 		options |= QFileDialog::DontUseNativeDialog;
@@ -1525,10 +1556,10 @@ void qtractorOptionsForm::chooseLv2PresetDir (void)
 void qtractorOptionsForm::chooseMessagesFont (void)
 {
 	const QString& sTitle
-		= tr("Messages Font") + " - " QTRACTOR_TITLE;
+		= tr("Messages Font");
 
-	QWidget *pParentWidget = NULL;
-	QFontDialog::FontDialogOptions options = 0;
+	QWidget *pParentWidget = nullptr;
+	QFontDialog::FontDialogOptions options = nullptr;
 	if (m_pOptions->bDontUseNativeDialogs) {
 		options |= QFontDialog::DontUseNativeDialog;
 		pParentWidget = QWidget::window();
@@ -1553,15 +1584,15 @@ void qtractorOptionsForm::chooseMessagesLogPath (void)
 
 	const QString  sExt("log");
 	const QString& sTitle
-		= tr("Messages Log") + " - " QTRACTOR_TITLE;
+		= tr("Messages Log");
 
 	QStringList filters;
 	filters.append(tr("Log files (*.%1)").arg(sExt));
 	filters.append(tr("All files (*.*)"));
 	const QString& sFilter = filters.join(";;");
 
-	QWidget *pParentWidget = NULL;
-	QFileDialog::Options options = 0;
+	QWidget *pParentWidget = nullptr;
+	QFileDialog::Options options = nullptr;
 	if (m_pOptions->bDontUseNativeDialogs) {
 		options |= QFileDialog::DontUseNativeDialog;
 		pParentWidget = QWidget::window();
@@ -1569,7 +1600,7 @@ void qtractorOptionsForm::chooseMessagesLogPath (void)
 #if 1//QT_VERSION < QT_VERSION_CHECK(4, 4, 0)
 	// Ask for the filename to open...
 	sFilename = QFileDialog::getSaveFileName(pParentWidget,
-		sTitle, m_ui.MessagesLogPathComboBox->currentText(), sFilter, NULL, options);
+		sTitle, m_ui.MessagesLogPathComboBox->currentText(), sFilter, nullptr, options);
 #else
 	// Construct open-file dialog...
 	QFileDialog fileDialog(pParentWidget,
@@ -1599,15 +1630,15 @@ void qtractorOptionsForm::chooseSessionTemplatePath (void)
 
 	const QString  sExt("qtt");
 	const QString& sTitle
-		= tr("Session Template") + " - " QTRACTOR_TITLE;
+		= tr("Session Template");
 
 	QStringList filters;
 	filters.append(tr("Session template files (*.qtr *.qts *.%1)").arg(sExt));
 	filters.append(tr("All files (*.*)"));
 	const QString& sFilter = filters.join(";;");
 
-	QWidget *pParentWidget = NULL;
-	QFileDialog::Options options = 0;
+	QWidget *pParentWidget = nullptr;
+	QFileDialog::Options options = nullptr;
 	if (m_pOptions->bDontUseNativeDialogs) {
 		options |= QFileDialog::DontUseNativeDialog;
 		pParentWidget = QWidget::window();
@@ -1615,7 +1646,7 @@ void qtractorOptionsForm::chooseSessionTemplatePath (void)
 #if 1//QT_VERSION < QT_VERSION_CHECK(4, 4, 0)
 	// Ask for the filename to open...
 	sFilename = QFileDialog::getOpenFileName(pParentWidget,
-		sTitle, m_ui.SessionTemplatePathComboBox->currentText(), sFilter, NULL, options);
+		sTitle, m_ui.SessionTemplatePathComboBox->currentText(), sFilter, nullptr, options);
 #else
 	// Construct open-files dialog...
 	QFileDialog fileDialog(pParentWidget,
@@ -1767,8 +1798,8 @@ QString qtractorOptionsForm::getOpenAudioFileName (
 
 	QString sAudioFile;
 
-	QWidget *pParentWidget = NULL;
-	QFileDialog::Options options = 0;
+	QWidget *pParentWidget = nullptr;
+	QFileDialog::Options options = nullptr;
 	if (m_pOptions->bDontUseNativeDialogs) {
 		options |= QFileDialog::DontUseNativeDialog;
 		pParentWidget = QWidget::window();
@@ -1776,7 +1807,7 @@ QString qtractorOptionsForm::getOpenAudioFileName (
 #if 1//QT_VERSION < QT_VERSION_CHECK(4, 4, 0)
 	// Ask for the filename to open...
 	sAudioFile = QFileDialog::getOpenFileName(pParentWidget,
-		sTitle, sFilename, sFilter, NULL, options);
+		sTitle, sFilename, sFilter, nullptr, options);
 #else
 	// Construct open-file dialog...
 	QFileDialog fileDialog(pParentWidget, sTitle, sFilename, sFilter);
@@ -1799,29 +1830,5 @@ QString qtractorOptionsForm::getOpenAudioFileName (
 }
 
 
-// Session format ext/suffix helpers.
-int qtractorOptionsForm::sessionFormatFromExt ( const QString& sSessionExt ) const
-{
-	int iSessionFormat = 0;
-
-	for (int i = 1; g_aSessionFormats[i].ext; ++i) {
-		if (g_aSessionFormats[i].ext == sSessionExt) {
-			iSessionFormat = i;
-			break;
-		}
-	}
-
-	return iSessionFormat;
-}
-
-QString qtractorOptionsForm::sessionExtFromFormat ( int iSessionFormat ) const
-{
-	if (iSessionFormat < 0 || iSessionFormat > 2)
-		iSessionFormat = 0;
-
-	return g_aSessionFormats[iSessionFormat].ext;
-}
-
-
 // end of qtractorOptionsForm.cpp
 
