@@ -1,7 +1,7 @@
 // qtractorOptionsForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -47,6 +47,9 @@ public:
 	void setOptions(qtractorOptions *pOptions);
 	qtractorOptions *options() const;
 
+	// Spacial custom color themes dirty flag.
+	bool isDirtyCustomColorThemes() const;
+
 protected slots:
 
 	void accept();
@@ -56,6 +59,7 @@ protected slots:
 	void chooseMetroBeatFilename();
 	void updateMetroNoteNames();
 	void displayFormatChanged(int iDisplayFormat);
+	void editCustomColorThemes();
 	void changeAudioMeterLevel(int iColor);
 	void changeMidiMeterLevel(int iColor);
 	void changeAudioMeterColor(const QString& sColor);
@@ -87,9 +91,12 @@ protected:
 	// Special combo-box color item helpers.
 	void updateColorText(QLineEdit *pLineEdit, const QColor& color);
 
-	// Session format ext/suffix helpers.
-	int sessionFormatFromExt(const QString& sSessionExt) const;
-	QString sessionExtFromFormat(int iSessionFormat) const;
+	// Custom color/style themes settlers.
+	void resetCustomColorThemes(const QString& sCustomColorTheme);
+	void resetCustomStyleThemes(const QString& sCustomStyleTheme);
+
+	// Session format ext/suffix table initializer.
+	static void initSessionFormats();
 
 private:
 
@@ -107,6 +114,9 @@ private:
 	QColor m_audioMeterColors[AudioMeterColors];
 	QColor m_midiMeterColors[MidiMeterColors];
 
+	// Custom color themes flag.
+	int m_iDirtyCustomColorThemes;
+
 	// Plug-ins path cache.
 	QStringList m_ladspaPaths;
 	QStringList m_dssiPaths;
