@@ -1,7 +1,7 @@
 // qtractorPluginListView.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
 
 #include <QListWidget>
 
+
 // Forward declarations.
 class qtractorPlugin;
 class qtractorPluginList;
@@ -128,18 +129,23 @@ public slots:
 	void removePlugin();
 	void moveUpPlugin();
 	void moveDownPlugin();
+
+protected slots:
+
+	// Generic interaction slots.
+	void activatePlugin();
+	void activateAllPlugins();
+	void deactivateAllPlugins();
+	void removeAllPlugins();
+
 	void loadPresetPlugin();
 	void directAccessPlugin();
 	void propertiesPlugin();
 	void editPlugin();
 
-protected slots:
-
-	// User interaction slots.
-	void activatePlugin();
-	void activateAllPlugins();
-	void deactivateAllPlugins();
-	void removeAllPlugins();
+	// Import/export plugin-list slots.
+	void importPlugins();
+	void exportPlugins();
 
 	// Audio inserts specific slots.
 	void addAudioInsertPlugin();
@@ -158,6 +164,7 @@ protected slots:
 	void audioOutputBus();
 	void audioOutputBusName();
 	void audioOutputAutoConnect();
+	void audioOutputMonitor();
 
 	// Drop item slots.
 	void dropMove();
