@@ -1,7 +1,7 @@
 // qtractorPluginSelectForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -47,7 +47,7 @@ qtractorPluginSelectForm::qtractorPluginSelectForm (
 	// Window modality (let plugin/tool windows rave around).
 	QDialog::setWindowModality(Qt::WindowModal);
 
-	m_pPluginList = NULL;
+	m_pPluginList = nullptr;
 
 	// Populate plugin type hints...
 	m_ui.PluginTypeComboBox->addItem(
@@ -122,9 +122,14 @@ qtractorPluginSelectForm::qtractorPluginSelectForm (
 		pOptions->loadWidgetGeometry(this, true);
 
 	// UI signal/slot connections...
+#if QT_VERSION < QT_VERSION_CHECK(5, 2, 0)
 	QObject::connect(m_ui.PluginResetToolButton,
 		SIGNAL(clicked()),
 		SLOT(reset()));
+#else
+	m_ui.PluginResetToolButton->hide();
+	m_ui.PluginSearchComboBox->lineEdit()->setClearButtonEnabled(true);
+#endif
 	QObject::connect(m_ui.PluginSearchComboBox,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(refresh()));
@@ -272,7 +277,7 @@ void qtractorPluginSelectForm::refresh (void)
 
 	qtractorPluginFactory *pPluginFactory
 		= qtractorPluginFactory::getInstance();
-	if (pPluginFactory == NULL)
+	if (pPluginFactory == nullptr)
 		return;
 
 	// FIXME: Should this be a global (singleton) registry?
@@ -291,7 +296,7 @@ void qtractorPluginSelectForm::refresh (void)
 		QApplication::restoreOverrideCursor();
 	}
 
-	if (m_pPluginList == NULL) {
+	if (m_pPluginList == nullptr) {
 		stabilize();
 		return;
 	}
