@@ -51,6 +51,8 @@
 
 #include <QDomDocument>
 
+#include <QElapsedTimer>
+
 #include <stdlib.h>
 
 
@@ -84,7 +86,7 @@ qtractorSession::Properties& qtractorSession::Properties::copy (
 // qtractorSession -- Session container.
 
 // pSeudo-singleton instance pointer.
-qtractorSession *qtractorSession::g_pSession = NULL;
+qtractorSession *qtractorSession::g_pSession = nullptr;
 
 
 // Pseudo-singleton instance accessor (static).
@@ -142,7 +144,7 @@ qtractorSession::~qtractorSession (void)
 
 	delete m_pFiles;
 
-	g_pSession = NULL;
+	g_pSession = nullptr;
 }
 
 
@@ -240,7 +242,7 @@ void qtractorSession::clear (void)
 
 	m_pAudioPeakFactory->sync();
 
-	m_pCurrentTrack = NULL;
+	m_pCurrentTrack = nullptr;
 
 	m_tracks.clear();
 	m_cursors.clear();
@@ -746,6 +748,15 @@ void qtractorSession::updateTimeScale (void)
 }
 
 
+void qtractorSession::updateTimeScaleEx (void)
+{
+	updateTimeScale();
+
+	if (m_pAudioEngine)
+		m_pAudioEngine->resetTimebase();
+}
+
+
 // Update time resolution divisor factors.
 void qtractorSession::updateTimeResolution (void) 
 {
@@ -1139,10 +1150,10 @@ void qtractorSession::stabilize ( int msecs )
 #endif
 
 	// Wait a litle bit before continue...
-	QTime t;
-	t.start();
+	QElapsedTimer timer;
+	timer.start();
 
-	while (t.elapsed() < msecs) {
+	while (timer.elapsed() < msecs) {
 		QThread::yieldCurrentThread();
 		QApplication::processEvents(/* QEventLoop::ExcludeUserInputEvents */);
 	}
@@ -1497,10 +1508,10 @@ unsigned long qtractorSession::frameTimeEx (void) const
 // Sanitize a given name.
 QString qtractorSession::sanitize ( const QString& s )
 {
-//	return s.simplified().replace(QRegExp("[\\s|\\.|\\-|/]+"), "_");
+//	return s.simplified().replace(QRegExp("[\\s|\\.|\\-|/]+"), '_');
 	const QChar space(' ');
 	const QRegExp regex("[^\\w]+");
-	return QString(s).replace(regex, space).simplified().replace(space, "_");
+	return QString(s).replace(regex, space).simplified().replace(space, '_');
 }
 
 
@@ -1649,7 +1660,7 @@ void qtractorSession::trackRecord (
 
 	// Just ditch the in-record clip...
 	if (!bRecord) {
-		pTrack->setClipRecord(NULL);
+		pTrack->setClipRecord(nullptr);
 		// Check whether we set recording off...
 		if (recordTracks() < 1)
 			setRecording(false);
@@ -2000,14 +2011,14 @@ void qtractorSession::process_curve ( unsigned long iFrame )
 // Find track of specific curve-list.
 qtractorTrack *qtractorSession::findTrack ( qtractorCurveList *pCurveList ) const
 {
-	return m_curves.value(pCurveList, NULL);
+	return m_curves.value(pCurveList, nullptr);
 }
 
 
 // Find track of specific name.
 qtractorTrack *qtractorSession::findTrack ( const QString& sTrackName ) const
 {
-	return m_trackNames.value(sTrackName, NULL);
+	return m_trackNames.value(sTrackName, nullptr);
 }
 
 
@@ -2103,20 +2114,20 @@ bool qtractorSession::loadElement (
 				if (eList.isNull())
 					continue;
 				if (eList.tagName() == "audio-list") {
-					qtractorAudioListView *pAudioList = NULL;
+					qtractorAudioListView *pAudioList = nullptr;
 					if (pDocument->files())
 						pAudioList = pDocument->files()->audioListView();
-					if (pAudioList == NULL)
+					if (pAudioList == nullptr)
 						return false;
 					if (!pAudioList->loadElement(pDocument, &eList))
 						return false;
 				}
 				else
 				if (eList.tagName() == "midi-list") {
-					qtractorMidiListView *pMidiList = NULL;
+					qtractorMidiListView *pMidiList = nullptr;
 					if (pDocument->files())
 						pMidiList = pDocument->files()->midiListView();
-					if (pMidiList == NULL)
+					if (pMidiList == nullptr)
 						return false;
 					if (!pMidiList->loadElement(pDocument, &eList))
 						return false;
@@ -2204,12 +2215,14 @@ bool qtractorSession::loadElement (
 				QDomElement eMarker = nMarker.toElement();
 				if (eMarker.isNull())
 					continue;
-				// Load markers...
+				// Load markers/key-signatures...
 				if (eMarker.tagName() == "marker") {
 					const unsigned long iFrame
 						= eMarker.attribute("frame").toULong();
 					QString sText;
 					QColor rgbColor = Qt::darkGray;
+					int iAccidentals = 0;
+					int iMode = 0;
 					for (QDomNode nItem = eMarker.firstChild();
 							!nItem.isNull();
 								nItem = nItem.nextSibling()) {
@@ -2221,12 +2234,21 @@ bool qtractorSession::loadElement (
 							sText = eItem.text();
 						else if (eItem.tagName() == "color")
 							rgbColor.setNamedColor(eItem.text());
+						else if (eItem.tagName() == "accidentals")
+							iAccidentals = eItem.text().toInt();
+						else if (eItem.tagName() == "mode")
+							iMode = eItem.text().toInt();
 					}
 					// Add new marker...
 					if (!sText.isEmpty()) {
 						qtractorSession::timeScale()->addMarker(
 							iFrame, sText, rgbColor);
 					}
+					// Or/and key-signature...
+					if (iAccidentals || iMode) {
+						qtractorSession::timeScale()->addKeySignature(
+							iFrame, iAccidentals, iMode);
+					}
 				}
 			}
 		}
@@ -2343,10 +2365,10 @@ bool qtractorSession::saveElement (
 		// Audio files...
 		QDomElement eAudioList
 			= pDocument->document()->createElement("audio-list");
-		qtractorAudioListView *pAudioList = NULL;
+		qtractorAudioListView *pAudioList = nullptr;
 		if (pDocument->files())
 			pAudioList = pDocument->files()->audioListView();
-		if (pAudioList == NULL)
+		if (pAudioList == nullptr)
 			return false;
 		if (!pAudioList->saveElement(pDocument, &eAudioList))
 			return false;
@@ -2354,10 +2376,10 @@ bool qtractorSession::saveElement (
 		// MIDI files...
 		QDomElement eMidiList
 			= pDocument->document()->createElement("midi-list");
-		qtractorMidiListView *pMidiList = NULL;
+		qtractorMidiListView *pMidiList = nullptr;
 		if (pDocument->files())
 			pMidiList = pDocument->files()->midiListView();
-		if (pMidiList == NULL)
+		if (pMidiList == nullptr)
 			return false;
 		if (!pMidiList->saveElement(pDocument, &eMidiList))
 			return false;
@@ -2405,7 +2427,7 @@ bool qtractorSession::saveElement (
 		pElement->appendChild(eTempoMap);
 	}
 
-	// Save location markers, if any...
+	// Save location markers/key-signatures, if any...
 	qtractorTimeScale::Marker *pMarker
 		= qtractorSession::timeScale()->markers().first();
 	if (pMarker) {
@@ -2413,8 +2435,16 @@ bool qtractorSession::saveElement (
 		while (pMarker) {
 			QDomElement eMarker = pDocument->document()->createElement("marker");
 			eMarker.setAttribute("frame", QString::number(pMarker->frame));
-			pDocument->saveTextElement("text", pMarker->text, &eMarker);
-			pDocument->saveTextElement("color", pMarker->color.name(), &eMarker);
+			if (!pMarker->text.isEmpty()) {
+				pDocument->saveTextElement("text", pMarker->text, &eMarker);
+				pDocument->saveTextElement("color", pMarker->color.name(), &eMarker);
+			}
+			if (pMarker->accidentals || pMarker->mode) {
+				pDocument->saveTextElement("accidentals",
+					QString::number(pMarker->accidentals), &eMarker);
+				pDocument->saveTextElement("mode",
+					QString::number(pMarker->mode), &eMarker);
+			}
 			eMarkers.appendChild(eMarker);
 			pMarker = pMarker->next();
 		}
@@ -2461,11 +2491,11 @@ void qtractorSession::renameSession (
 	if (sOldName == sNewName)
 		return;
 
-	qtractorFiles *pFiles = NULL;
+	qtractorFiles *pFiles = nullptr;
 	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
 	if (pMainForm)
 		pFiles = pMainForm->files();
-	if (pFiles == NULL)
+	if (pFiles == nullptr)
 		return;
 
 	// Lock it up...
@@ -2477,7 +2507,7 @@ void qtractorSession::renameSession (
 	for (qtractorTrack *pTrack = m_tracks.first();
 			pTrack; pTrack = pTrack->next()) {
 		// Refer to a proper files-view...
-		qtractorFileListView *pFileListView = NULL;
+		qtractorFileListView *pFileListView = nullptr;
 		qtractorFileList::Type iFileType = qtractorFileList::Audio;
 		if (pTrack->trackType() == qtractorTrack::Midi) {
 			pFileListView = pFiles->midiListView();
@@ -2531,7 +2561,7 @@ void qtractorSession::renameSession (
 				}
 				// Manage files-view item...
 				if (pFileListView) {
-					qtractorFileGroupItem *pGroupItem = NULL;
+					qtractorFileGroupItem *pGroupItem = nullptr;
 					qtractorFileListItem *pFileItem
 						= pFileListView->findFileItem(sOldFilePath);
 					if (pFileItem) {
