@@ -170,6 +170,7 @@ public:
 
 	// Update time scale divisor factors.
 	void updateTimeScale();
+	void updateTimeScaleEx();
 
 	// Update time resolution divisor factors.
 	void updateTimeResolution(); 
@@ -181,7 +182,7 @@ public:
 	const qtractorList<qtractorTrack>& tracks() const;
 
 	void addTrack(qtractorTrack *pTrack);
-	void insertTrack(qtractorTrack *pTrack, qtractorTrack *pPrevTrack = NULL);
+	void insertTrack(qtractorTrack *pTrack, qtractorTrack *pPrevTrack = nullptr);
 	void moveTrack(qtractorTrack *pTrack, qtractorTrack *pNextTrack);
 	void updateTrack(qtractorTrack *pTrack);
 	void unlinkTrack(qtractorTrack *pTrack);
