@@ -1,7 +1,7 @@
 // qtractorSessionForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -41,16 +41,23 @@ public:
 	// Destructor.
 	~qtractorSessionForm();
 
-    void setSession(qtractorSession *pSession);
-    const qtractorSession::Properties& properties();
+	void setSession(qtractorSession *pSession);
+	const qtractorSession::Properties& properties();
 
 protected slots:
 
-    void accept();
-    void reject();
-    void changed();
-    void stabilizeForm();
-    void browseSessionDir();
+	void accept();
+	void reject();
+	void changed();
+
+	void changeSessionName(const QString& sSessionName);
+	void changeSessionDir(const QString& sSessionDir);
+	void finishSessionDir();
+	void browseSessionDir();
+
+protected:
+
+	void stabilizeForm();
 
 private:
 
