@@ -1,7 +1,7 @@
 // qtractorTimeScale.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -20,7 +20,6 @@
 *****************************************************************************/
 
 #include "qtractorTimeScale.h"
-#include <QObject>
 
 
 //----------------------------------------------------------------------
@@ -69,6 +68,9 @@ void qtractorTimeScale::clear (void)
 	m_iTicksPerBeat   = 960;
 	m_iPixelsPerBeat  = 32;
 
+	m_iBeatsPerBar2   = 0;
+	m_iBeatDivisor2   = 0;
+
 	// Clear/reset tempo-map...
 	reset();
 }
@@ -114,13 +116,15 @@ qtractorTimeScale& qtractorTimeScale::copy ( const qtractorTimeScale& ts )
 		m_nodes.setAutoDelete(true);
 		m_markers.setAutoDelete(true);
 
-		m_iSampleRate     = ts.m_iSampleRate;
 		m_iSnapPerBeat    = ts.m_iSnapPerBeat;
 		m_iHorizontalZoom = ts.m_iHorizontalZoom;
 		m_iVerticalZoom   = ts.m_iVerticalZoom;
 
 		m_displayFormat   = ts.m_displayFormat;
 
+		m_iBeatsPerBar2   = ts.m_iBeatsPerBar2;
+		m_iBeatDivisor2   = ts.m_iBeatDivisor2;
+
 		// Sync/copy tempo-map nodes...
 		sync(ts);
 	}
@@ -190,12 +194,55 @@ float qtractorTimeScale::Node::tempoEx ( unsigned short iBeatType ) const
 unsigned long qtractorTimeScale::Node::tickSnap (
 	unsigned long iTick, unsigned short p ) const
 {
+#if 0
 	unsigned long iTickSnap = iTick - tick;
 	if (ts->snapPerBeat() > 0) {
 		const unsigned long q = ticksPerBeat / ts->snapPerBeat();
 		iTickSnap = q * ((iTickSnap + (q >> p)) / q);
 	}
 	return tick + iTickSnap;
+#else
+	const unsigned short iTicksPerBar
+		= ticksPerBeat * beatsPerBar;
+	const unsigned long iTickFromBar
+		= tick + iTicksPerBar * ((iTick - tick) / iTicksPerBar);
+
+	const unsigned short iBeatsPerBar2 = beatsPerBar2();
+	unsigned short iTicksPerBeat2 = iTicksPerBar / iBeatsPerBar2;
+
+	unsigned long iTickSnap = iTick - iTickFromBar;
+	if (ts->snapPerBeat() > 0) {
+		const unsigned long q = iTicksPerBeat2 / ts->snapPerBeat();
+		iTickSnap = q * ((iTickSnap + (q >> p)) / q);
+	}
+
+	return iTickFromBar + iTickSnap;
+#endif
+}
+
+
+// Alternate (secondary) time-sig helper methods
+unsigned short qtractorTimeScale::Node::beatsPerBar2 (void) const
+{
+	unsigned short iBeatsPerBar2 = ts->beatsPerBar2();
+	if (iBeatsPerBar2 < 1)
+		iBeatsPerBar2 = beatsPerBar;
+
+	const unsigned short iBeatDivisor2 = ts->beatDivisor2();
+	if (iBeatDivisor2 > 0) {
+		if (beatDivisor > iBeatDivisor2)
+			iBeatsPerBar2 >>= (beatDivisor - iBeatDivisor2);
+		else
+		if (beatDivisor < iBeatDivisor2)
+			iBeatsPerBar2 <<= (iBeatDivisor2 - beatDivisor);
+	}
+
+	return iBeatsPerBar2;
+}
+
+unsigned short qtractorTimeScale::Node::ticksPerBeat2 (void) const
+{
+	return (ticksPerBeat * beatsPerBar) / beatsPerBar2();
 }
 
 
@@ -210,10 +257,10 @@ void qtractorTimeScale::Cursor::reset ( qtractorTimeScale::Node *pNode )
 qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekFrame (
 	unsigned long iFrame )
 {
-	if (node == 0) {
+	if (node == nullptr) {
 		node = ts->nodes().first();
-		if (node == 0)
-			return 0;
+		if (node == nullptr)
+			return nullptr;
 	}
 
 	if (iFrame > node->frame) {
@@ -226,7 +273,7 @@ qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekFrame (
 		// Seek frame backward...
 		while (node && node->frame > iFrame)
 			node = node->prev();
-		if (node == 0)
+		if (node == nullptr)
 			node = ts->nodes().first();
 	}
 
@@ -238,10 +285,10 @@ qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekFrame (
 qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekBar (
 	unsigned short iBar )
 {
-	if (node == 0) {
+	if (node == nullptr) {
 		node = ts->nodes().first();
-		if (node == 0)
-			return 0;
+		if (node == nullptr)
+			return nullptr;
 	}
 
 	if (iBar > node->bar) {
@@ -254,7 +301,7 @@ qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekBar (
 		// Seek bar backward...
 		while (node && node->bar > iBar)
 			node = node->prev();
-		if (node == 0)
+		if (node == nullptr)
 			node = ts->nodes().first();
 	}
 
@@ -266,10 +313,10 @@ qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekBar (
 qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekBeat (
 	unsigned int iBeat )
 {
-	if (node == 0) {
+	if (node == nullptr) {
 		node = ts->nodes().first();
-		if (node == 0)
-			return 0;
+		if (node == nullptr)
+			return nullptr;
 	}
 
 	if (iBeat > node->beat) {
@@ -282,7 +329,7 @@ qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekBeat (
 		// Seek beat backward...
 		while (node && node->beat > iBeat)
 			node = node->prev();
-		if (node == 0)
+		if (node == nullptr)
 			node = ts->nodes().first();
 	}
 
@@ -294,10 +341,10 @@ qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekBeat (
 qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekTick (
 	unsigned long iTick )
 {
-	if (node == 0) {
+	if (node == nullptr) {
 		node = ts->nodes().first();
-		if (node == 0)
-			return 0;
+		if (node == nullptr)
+			return nullptr;
 	}
 
 	if (iTick > node->tick) {
@@ -310,7 +357,7 @@ qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekTick (
 		// Seek tick backward...
 		while (node && node->tick > iTick)
 			node = node->prev();
-		if (node == 0)
+		if (node == nullptr)
 			node = ts->nodes().first();
 	}
 
@@ -321,10 +368,10 @@ qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekTick (
 // Time-scale cursor node seeker (by pixel).
 qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekPixel ( int x )
 {
-	if (node == 0) {
+	if (node == nullptr) {
 		node = ts->nodes().first();
-		if (node == 0)
-			return 0;
+		if (node == nullptr)
+			return nullptr;
 	}
 
 	if (x > node->pixel) {
@@ -337,7 +384,7 @@ qtractorTimeScale::Node *qtractorTimeScale::Cursor::seekPixel ( int x )
 		// Seek tick backward...
 		while (node && node->pixel > x)
 			node = node->prev();
-		if (node == 0)
+		if (node == nullptr)
 			node = ts->nodes().first();
 	}
 
@@ -350,7 +397,7 @@ qtractorTimeScale::Node *qtractorTimeScale::addNode (
 	unsigned long iFrame, float fTempo, unsigned short iBeatType,
 	unsigned short iBeatsPerBar, unsigned short iBeatDivisor )
 {
-	Node *pNode	= 0;
+	Node *pNode	= nullptr;
 
 	// Seek for the nearest preceding node...
 	Node *pPrev = m_cursor.seekFrame(iFrame);
@@ -360,7 +407,7 @@ qtractorTimeScale::Node *qtractorTimeScale::addNode (
 		pPrev = m_cursor.seekFrame(iFrame);
 	}
 	// Either update existing node or add new one...
-	Node *pNext = (pPrev ? pPrev->next() : 0);
+	Node *pNext = (pPrev ? pPrev->next() : nullptr);
 	if (pPrev && pPrev->frame == iFrame) {
 		// Update exact matching node...
 		pNode = pPrev;
@@ -368,13 +415,13 @@ qtractorTimeScale::Node *qtractorTimeScale::addNode (
 		pNode->beatType = iBeatType;
 		pNode->beatsPerBar = iBeatsPerBar;
 		pNode->beatDivisor = iBeatDivisor;
-	} else if (pPrev && pPrev->tempo == fTempo
+	} else if (pPrev && qAbs(pPrev->tempo - fTempo) < 0.01f
 		&& pPrev->beatType == iBeatType
 		&& pPrev->beatsPerBar == iBeatsPerBar
 		&& pPrev->beatDivisor == iBeatDivisor) {
 		// No need for a new node...
 		return pPrev;
-	} else if (pNext && pNext->tempo == fTempo
+	} else if (pNext && qAbs(pNext->tempo - fTempo) < 0.01f
 		&& pNext->beatType == iBeatType
 		&& pNext->beatsPerBar == iBeatsPerBar
 		&& pNext->beatDivisor == iBeatDivisor) {
@@ -425,7 +472,7 @@ void qtractorTimeScale::removeNode ( qtractorTimeScale::Node *pNode )
 {
 	// Don't ever remove the very first node... 
 	Node *pNodePrev = pNode->prev();
-	if (pNodePrev == 0)
+	if (pNodePrev == nullptr)
 		return;
 
 	// Relocate internal cursor...
@@ -456,7 +503,7 @@ void qtractorTimeScale::updateScale (void)
 	m_fFrameRate = 60.0f * float(m_iSampleRate);
 
 	// Update all nodes thereafter...
-	Node *pPrev = 0;
+	Node *pPrev = nullptr;
 	Node *pNext = m_nodes.first();
 	while (pNext) {
 		pNext->update();
@@ -488,7 +535,7 @@ unsigned long qtractorTimeScale::frameFromTextEx (
 				pNode = m_cursor.seekFrame(iFrame);
 				if (pNode) {
 					beats += bars  * pNode->beatsPerBar;
-					ticks += beats * pNode->ticksPerBeat;
+					ticks += beats * pNode->ticksPerBeat2();
 					ticks += pNode->tickFromFrame(iFrame);
 					iFrame = pNode->frameFromTick(ticks) - iFrame;
 				}
@@ -499,8 +546,8 @@ unsigned long qtractorTimeScale::frameFromTextEx (
 					--beats;
 				pNode = m_cursor.seekBar(bars);
 				if (pNode) {
-					beats += (bars - pNode->bar) * pNode->beatsPerBar;
-					ticks += pNode->tick + beats * pNode->ticksPerBeat;
+					beats += (bars - pNode->bar) * pNode->beatsPerBar2();
+					ticks += pNode->tick + beats * pNode->ticksPerBeat2();
 					iFrame = pNode->frameFromTick(ticks);
 				}
 			}
@@ -520,7 +567,6 @@ unsigned long qtractorTimeScale::frameFromTextEx (
 		}
 
 		case Frames:
-		default:
 		{
 			iFrame = sText.toULong();
 			break;
@@ -569,6 +615,14 @@ QString qtractorTimeScale::textFromFrameEx (
 					bars   = (unsigned short) (beats / pNode->beatsPerBar);
 					beats -= (unsigned int) (bars * pNode->beatsPerBar);
 				}
+				if (beatsPerBar2() > 0 || beatDivisor2() > 0) {
+					const unsigned short iTicksPerBeat2 = pNode->ticksPerBeat2();
+					ticks += (unsigned long) (beats * pNode->ticksPerBeat);
+					if (ticks >= (unsigned long) iTicksPerBeat2) {
+						beats  = (unsigned int) (ticks / iTicksPerBeat2);
+						ticks -= (unsigned long) (beats * iTicksPerBeat2);
+					}
+				}
 				if (!bDelta)
 					bars += pNode->bar;
 			}
@@ -576,7 +630,11 @@ QString qtractorTimeScale::textFromFrameEx (
 				++bars;
 				++beats;
 			}
+		#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 			sText.sprintf("%u.%u.%03lu", bars, beats, ticks);
+		#else
+			sText = QString::asprintf("%u.%u.%03lu", bars, beats, ticks);
+		#endif
 			break;
 		}
 
@@ -599,12 +657,15 @@ QString qtractorTimeScale::textFromFrameEx (
 				secs -= float(ss);
 			}
 			zzz = (unsigned int) (secs * 1000.0f);
+		#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 			sText.sprintf("%02u:%02u:%02u.%03u", hh, mm, ss, zzz);
+		#else
+			sText = QString::asprintf("%02u:%02u:%02u.%03u", hh, mm, ss, zzz);
+		#endif
 			break;
 		}
 
 		case Frames:
-		default:
 		{
 			sText = QString::number(bDelta ? iDelta : iFrame);
 			break;
@@ -739,10 +800,10 @@ void qtractorTimeScale::MarkerCursor::reset (
 qtractorTimeScale::Marker *qtractorTimeScale::MarkerCursor::seekFrame (
 	unsigned long iFrame )
 {
-	if (marker == 0) {
+	if (marker == nullptr) {
 		marker = ts->markers().first();
-		if (marker == 0)
-			return 0;
+		if (marker == nullptr)
+			return nullptr;
 	}
 
 	if (iFrame > marker->frame) {
@@ -755,7 +816,7 @@ qtractorTimeScale::Marker *qtractorTimeScale::MarkerCursor::seekFrame (
 		// Seek frame backward...
 		while (marker && marker->frame > iFrame)
 			marker = marker->prev();
-		if (marker == 0)
+		if (marker == nullptr)
 			marker = ts->markers().first();
 	}
 
@@ -795,7 +856,7 @@ qtractorTimeScale::Marker *qtractorTimeScale::MarkerCursor::seekPixel ( int x )
 qtractorTimeScale::Marker *qtractorTimeScale::addMarker (
 	unsigned long iFrame, const QString& sText, const QColor& rgbColor )
 {
-	Marker *pMarker	= 0;
+	Marker *pMarker	= nullptr;
 
 	// Snap to nearest bar...
 	unsigned short iBar = 0;
@@ -834,6 +895,49 @@ qtractorTimeScale::Marker *qtractorTimeScale::addMarker (
 }
 
 
+// Key-signature list specifics.
+qtractorTimeScale::Marker *qtractorTimeScale::addKeySignature (
+	unsigned long iFrame, int iAccidentals, int iMode )
+{
+	Marker *pMarker	= nullptr;
+
+	// Snap to nearest bar...
+	unsigned short iBar = 0;
+
+	Node *pNodePrev = m_cursor.seekFrame(iFrame);
+	if (pNodePrev) {
+		iBar = pNodePrev->barFromFrame(iFrame);
+		iFrame = pNodePrev->frameFromBar(iBar);
+	}
+
+	// Seek for the nearest marker...
+	Marker *pMarkerNear = m_markerCursor.seekFrame(iFrame);
+	// Either update existing marker or add new one...
+	if (pMarkerNear && pMarkerNear->frame == iFrame) {
+		// Update exact matching marker...
+		pMarker = pMarkerNear;
+		pMarker->bar = iBar;
+		pMarker->accidentals = iAccidentals;
+		pMarker->mode = iMode;
+	} else {
+		// Add/insert a new marker...
+		pMarker = new Marker(iFrame, iBar, iAccidentals, iMode);
+		if (pMarkerNear && pMarkerNear->frame > iFrame)
+			m_markers.insertBefore(pMarker, pMarkerNear);
+		else
+		if (pMarkerNear && pMarkerNear->frame < iFrame)
+			m_markers.insertAfter(pMarker, pMarkerNear);
+		else
+			m_markers.append(pMarker);
+	}
+
+	// Update positioning...
+	updateMarker(pMarker);
+
+	return pMarker;
+}
+
+
 void qtractorTimeScale::updateMarker ( qtractorTimeScale::Marker *pMarker )
 {
 	// Relocate internal cursor...
@@ -854,9 +958,9 @@ void qtractorTimeScale::removeMarker ( qtractorTimeScale::Marker *pMarker )
 // Update markers from given node position.
 void qtractorTimeScale::updateMarkers ( qtractorTimeScale::Node *pNode )
 {
-	if (pNode == 0)
+	if (pNode == nullptr)
 		pNode = m_nodes.first();
-	if (pNode == 0)
+	if (pNode == nullptr)
 		return;
 
 	Marker *pMarker = m_markerCursor.seekFrame(pNode->frame);
@@ -870,4 +974,52 @@ void qtractorTimeScale::updateMarkers ( qtractorTimeScale::Node *pNode )
 }
 
 
+// Key signature map accessor.
+QString qtractorTimeScale::keySignatureName (
+	int iAccidentals, int iMode, char chMinor )
+{
+	static struct
+	{
+		const char *natural;
+		const char *sharp;
+		const char *flat;
+
+	} s_aAccidentalsTab[] = {
+
+		{ QT_TR_NOOP("C"), QT_TR_NOOP("B#"), nullptr          },
+		{ nullptr,         QT_TR_NOOP("C#"), QT_TR_NOOP("Db") },
+		{ QT_TR_NOOP("D"), nullptr,          nullptr          },
+		{ nullptr,         QT_TR_NOOP("D#"), QT_TR_NOOP("Eb") },
+		{ QT_TR_NOOP("E"), nullptr,          QT_TR_NOOP("Fb") },
+		{ QT_TR_NOOP("F"), QT_TR_NOOP("E#"), nullptr          },
+		{ nullptr,         QT_TR_NOOP("F#"), QT_TR_NOOP("Gb") },
+		{ QT_TR_NOOP("G"), nullptr,          nullptr          },
+		{ nullptr,         QT_TR_NOOP("G#"), QT_TR_NOOP("Ab") },
+		{ QT_TR_NOOP("A"), nullptr,          nullptr          },
+		{ nullptr,         QT_TR_NOOP("A#"), QT_TR_NOOP("Bb") },
+		{ QT_TR_NOOP("B"), nullptr,          QT_TR_NOOP("Cb") }
+	};
+
+	const int i
+		= (iAccidentals * (iAccidentals < 0 ? -5 : 7)
+		+ (iMode > 0 ? 9 : 0)) % 12;
+
+	const char *name = nullptr;
+	if (iAccidentals < 0)
+		name = s_aAccidentalsTab[i].flat;
+	else
+	if (iAccidentals > 0)
+		name = s_aAccidentalsTab[i].sharp;
+	if (name == nullptr)
+		name = s_aAccidentalsTab[i].natural;
+
+	QString sKeySignature = tr(name);
+
+	if (iMode && chMinor)
+		sKeySignature += chMinor;
+
+	return sKeySignature;
+}
+
+
 // end of qtractorTimeScale.cpp
