@@ -1,7 +1,7 @@
 // qtractorTimeScaleCommand.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -31,6 +31,8 @@
 class qtractorClipCommand;
 class qtractorCurveEditCommand;
 
+class qtractorMidiClip;
+
 
 //----------------------------------------------------------------------
 // class qtractorTimeScaleNodeCommand - declaration.
@@ -195,11 +197,12 @@ class qtractorTimeScaleMarkerCommand : public qtractorCommand
 {
 public:
 
-	// Constructor.
+	// Constructors.
 	qtractorTimeScaleMarkerCommand(const QString& sName,
 		qtractorTimeScale *pTimeScale, unsigned long iFrame = 0,
-		const QString& sText = QString(),
-		const QColor& rgbColor = Qt::darkGray);
+	const QString& sText = QString(),
+	const QColor& rgbColor = Qt::darkGray,
+	int iAccidentals = 0, int iMode = 0);
 
 	// Time-scale accessor.
 	qtractorTimeScale *timeScale() const
@@ -212,12 +215,18 @@ public:
 		{ return m_sText; }
 	const QColor& color() const
 		{ return m_rgbColor; }
+	int accidentals() const
+		{ return m_iAccidentals; }
+	bool mode() const
+		{ return m_iMode; }
 
 protected:
 
 	// Executive commands.
 	bool addMarker();
 	bool updateMarker();
+	bool addKeySignature();
+	bool updateKeySignature();
 	bool removeMarker();
 
 private:
@@ -228,6 +237,8 @@ private:
 	unsigned long m_iFrame;
 	QString       m_sText;
 	QColor        m_rgbColor;
+	int           m_iAccidentals;
+	int           m_iMode;
 };
 
 
@@ -251,7 +262,7 @@ public:
 
 
 //----------------------------------------------------------------------
-// class qtractorTimeScaleUpdateNodeCommand - declaration.
+// class qtractorTimeScaleUpdateMarkerCommand - declaration.
 //
 
 class qtractorTimeScaleUpdateMarkerCommand : public qtractorTimeScaleMarkerCommand
@@ -288,6 +299,63 @@ public:
 };
 
 
+//----------------------------------------------------------------------
+// class qtractorTimeScaleAddKeySignatureCommand - declaration.
+//
+
+class qtractorTimeScaleAddKeySignatureCommand : public qtractorTimeScaleMarkerCommand
+{
+public:
+
+	// Constructor.
+	qtractorTimeScaleAddKeySignatureCommand(
+		qtractorTimeScale *pTimeScale, unsigned long iFrame,
+		int iAccidentals = 0, int iMode = 0);
+
+	// Time-scale command methods.
+	bool redo();
+	bool undo();
+};
+
+
+//----------------------------------------------------------------------
+// class qtractorTimeScaleUpdateKeySignatureCommand - declaration.
+//
+
+class qtractorTimeScaleUpdateKeySignatureCommand : public qtractorTimeScaleMarkerCommand
+{
+public:
+
+	// Constructor.
+	qtractorTimeScaleUpdateKeySignatureCommand(
+		qtractorTimeScale *pTimeScale, unsigned long iFrame,
+		int iAccidentals = 0, int iMode = 0);
+
+	// Time-scale command methods.
+	bool redo();
+	bool undo();
+};
+
+
+//----------------------------------------------------------------------
+// class qtractorTimeScaleRemoveKeySignatureCommand - declaration.
+//
+
+class qtractorTimeScaleRemoveKeySignatureCommand : public qtractorTimeScaleMarkerCommand
+{
+public:
+
+	// Constructor.
+	qtractorTimeScaleRemoveKeySignatureCommand(
+		qtractorTimeScale *pTimeScale,
+		qtractorTimeScale::Marker *pMarker);
+
+	// Time-scale command methods.
+	bool redo();
+	bool undo();
+};
+
+
 //----------------------------------------------------------------------
 // class qtractorTimeScaleMoveMarkerCommand - declaration.
 //
@@ -314,6 +382,8 @@ private:
 	unsigned long m_iOldFrame;
 	QString       m_sOldText;
 	QColor        m_rgbOldColor;
+	int           m_iOldAccidentals;
+	int           m_iOldMode;
 };
 
 
@@ -345,6 +415,35 @@ private:
 };
 
 
+//----------------------------------------------------------------------
+// class qtractorTimeScaleTimeSig2Command - declaration.
+//
+
+class qtractorTimeScaleTimeSig2Command : public qtractorCommand
+{
+public:
+
+	// Constructor.
+	qtractorTimeScaleTimeSig2Command(
+		qtractorTimeScale *pTimeScale, qtractorMidiClip *pMidiClip,
+		unsigned short iBeatsPerBar2, unsigned short iBeatDivisor2);
+
+	// Time-scale command methods.
+	bool redo();
+	bool undo();
+
+private:
+
+	// Instance variables.
+	qtractorTimeScale *m_pTimeScale;
+
+	qtractorMidiClip *m_pMidiClip;
+
+	unsigned short m_iBeatsPerBar2;
+	unsigned short m_iBeatDivisor2;
+};
+
+
 #endif	// __qtractorTimeScaleCommand_h
 
 // end of qtractorTimeScaleCommand.h
