@@ -1,7 +1,7 @@
 // qtractorTimeScaleForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -34,7 +34,7 @@
 
 #include <QHeaderView>
 #include <QMessageBox>
-#include <QTime>
+#include <QElapsedTimer>
 #include <QMenu>
 
 #include <QColorDialog>
@@ -51,7 +51,7 @@ class qtractorTimeScaleItemDelegate : public QItemDelegate
 public:
 
 	// Constructor.
-	qtractorTimeScaleItemDelegate(QObject *pParent = 0)
+	qtractorTimeScaleItemDelegate(QObject *pParent = nullptr)
 		: QItemDelegate(pParent) {}
 
 protected:
@@ -64,6 +64,7 @@ protected:
 		switch (index.column()) {
 		case 0: // Bar
 		case 2: // Tempo
+		case 3: // Key
 			opt.displayAlignment = Qt::AlignCenter;
 			break;
 		default:
@@ -113,17 +114,28 @@ public:
 		else QTreeWidgetItem::setText(2, dash);
 
 		if (pMarker) {
-			if (pNode == NULL) {
+			if (pNode == nullptr) {
 				const unsigned int iBar
 					= pTimeScale->barFromFrame(pMarker->frame);
 				QTreeWidgetItem::setText(0, QString::number(iBar + 1));
 				QTreeWidgetItem::setText(1, pTimeScale->textFromFrameEx(
 					displayFormat, pMarker->frame));
 			}
-			QTreeWidgetItem::setText(3, pMarker->text);
-			QTreeWidgetItem::setForeground(3, pMarker->color);
+			if (pMarker->accidentals || pMarker->mode) {
+				QTreeWidgetItem::setText(3,
+					qtractorTimeScale::keySignatureName(
+						pMarker->accidentals, pMarker->mode));
+			}
+			else QTreeWidgetItem::setText(3, dash);
+			if (!pMarker->text.isEmpty()) {
+				QTreeWidgetItem::setText(4, pMarker->text);
+				QTreeWidgetItem::setForeground(4, pMarker->color);
+			}
+			else QTreeWidgetItem::setText(4, dash);
+		} else {
+			QTreeWidgetItem::setText(3, dash);
+			QTreeWidgetItem::setText(4, dash);
 		}
-		else QTreeWidgetItem::setText(3, dash);
 	}
 
 	// Node accessor.
@@ -155,9 +167,9 @@ qtractorTimeScaleForm::qtractorTimeScaleForm (
 	QDialog::setWindowModality(Qt::WindowModal);
 
 	// Initialize locals.
-	m_pTimeScale  = NULL;
+	m_pTimeScale  = nullptr;
 
-	m_pTempoTap   = new QTime();
+	m_pTempoTap   = new QElapsedTimer();
 	m_iTempoTap   = 0;
 	m_fTempoTap   = 0.0f;
 
@@ -180,12 +192,18 @@ qtractorTimeScaleForm::qtractorTimeScaleForm (
 	pHeaderModel->setHeaderData(0, Qt::Horizontal,
 		Qt::AlignCenter, Qt::TextAlignmentRole); // Bar
 	pHeaderModel->setHeaderData(2, Qt::Horizontal,
-		Qt::AlignCenter, Qt::TextAlignmentRole); // tempo
+		Qt::AlignCenter, Qt::TextAlignmentRole); // Tempo
+	pHeaderModel->setHeaderData(3, Qt::Horizontal,
+		Qt::AlignCenter, Qt::TextAlignmentRole); // Key
 
 	m_ui.TimeScaleListView->setItemDelegate(
 		new qtractorTimeScaleItemDelegate(m_ui.TimeScaleListView));
 	m_ui.TimeScaleListView->setContextMenuPolicy(Qt::CustomContextMenu);
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
+	m_ui.MarkerTextLineEdit->setClearButtonEnabled(true);
+#endif
+
 	// (Re)initial contents.
 	// Default is main session time-scale of course...
 	qtractorSession *pSession = qtractorSession::getInstance();
@@ -226,6 +244,13 @@ qtractorTimeScaleForm::qtractorTimeScaleForm (
 		SIGNAL(clicked()),
 		SLOT(tempoFactor()));
 
+	QObject::connect(m_ui.KeySignatureAccidentalsComboBox,
+		SIGNAL(activated(int)),
+		SLOT(changed()));
+	QObject::connect(m_ui.KeySignatureModeComboBox,
+		SIGNAL(activated(int)),
+		SLOT(modeChanged(int)));
+
 	QObject::connect(m_ui.MarkerTextLineEdit,
 		SIGNAL(textChanged(const QString&)),
 		SLOT(changed()));
@@ -272,7 +297,7 @@ qtractorTimeScale *qtractorTimeScaleForm::timeScale (void) const
 // Select(ed) node by frame (time)
 void qtractorTimeScaleForm::setFrame ( unsigned long iFrame )
 {
-	if (m_pTimeScale == NULL)
+	if (m_pTimeScale == nullptr)
 		return;
 
 	++m_iDirtySetup;
@@ -298,7 +323,11 @@ void qtractorTimeScaleForm::setFrame ( unsigned long iFrame )
 	if (pMarker && pMarker->frame == iFrame)
 		setCurrentMarker(pMarker);
 	else
-		setCurrentMarker(NULL);
+		setCurrentMarker(nullptr);
+	if (pMarker && iFrame >= pMarker->frame)
+		setCurrentKeySignature(pMarker);
+	else
+		setCurrentKeySignature(nullptr);
 
 	// Done.
 	m_iDirtySetup = 0;
@@ -336,7 +365,7 @@ bool qtractorTimeScaleForm::isDirty (void)
 // Refresh all list and views.
 void qtractorTimeScaleForm::refreshItems (void)
 {
-	if (m_pTimeScale == NULL)
+	if (m_pTimeScale == nullptr)
 		return;
 
 	// (Re)Load complete tempo-map listing ...
@@ -348,11 +377,11 @@ void qtractorTimeScaleForm::refreshItems (void)
 	qtractorTimeScale::Node *pNode = m_pTimeScale->nodes().first();
 	qtractorTimeScale::Marker *pMarker = m_pTimeScale->markers().first();
 
-	qtractorTimeScaleListItem *pListItem = NULL;
+	qtractorTimeScaleListItem *pListItem = nullptr;
 	while (pNode) {
 		while (pMarker && pMarker->frame < pNode->frame) {
 			pListItem = new qtractorTimeScaleListItem(m_ui.TimeScaleListView,
-				pListItem, m_pTimeScale, NULL, pMarker, displayFormat);
+				pListItem, m_pTimeScale, nullptr, pMarker, displayFormat);
 			pMarker = pMarker->next();
 		}
 		if (pMarker && pMarker->frame == pNode->frame) {
@@ -361,14 +390,14 @@ void qtractorTimeScaleForm::refreshItems (void)
 			pMarker = pMarker->next();
 		} else {
 			pListItem = new qtractorTimeScaleListItem(m_ui.TimeScaleListView,
-				pListItem, m_pTimeScale, pNode, NULL, displayFormat);
+				pListItem, m_pTimeScale, pNode, nullptr, displayFormat);
 		}
 		pNode = pNode->next();
 	}
 
 	while (pMarker) {
 		pListItem = new qtractorTimeScaleListItem(m_ui.TimeScaleListView,
-			pListItem, m_pTimeScale, NULL, pMarker, displayFormat);
+			pListItem, m_pTimeScale, nullptr, pMarker, displayFormat);
 		pMarker = pMarker->next();
 	}
 }
@@ -425,6 +454,60 @@ void qtractorTimeScaleForm::setCurrentMarker (
 }
 
 
+// Set current key-signature...
+void qtractorTimeScaleForm::setCurrentKeySignature (
+	qtractorTimeScale::Marker *pMarker )
+{
+	int iAccidentals = 0;
+	int iMode = 0;
+
+	if (pMarker) {
+		iAccidentals = pMarker->accidentals;
+		iMode = pMarker->mode;
+	}
+
+	updateKeySignatures(iAccidentals, iMode);
+
+	const bool bBlockSignals
+		= m_ui.KeySignatureModeComboBox->blockSignals(true);
+	m_ui.KeySignatureModeComboBox->setCurrentIndex(iMode);
+	m_ui.KeySignatureModeComboBox->blockSignals(bBlockSignals);
+}
+
+
+// Refresh key signatures.
+void qtractorTimeScaleForm::updateKeySignatures (
+	int iAccidentals, int iMode )
+{
+#ifdef CONFIG_DEBUG
+	qDebug("qtractorTimeScaleForm::updateKeySignatures(%d, %d)",
+		iAccidentals, iMode);
+#endif
+
+	const bool bBlockSignals
+		= m_ui.KeySignatureAccidentalsComboBox->blockSignals(true);
+
+	const QString sAccidentals
+		= m_ui.KeySignatureAccidentalsComboBox->currentText();
+
+	m_ui.KeySignatureAccidentalsComboBox->clear();
+
+	int iIndex = 0;
+	for (int i = 0; i < 18; ++i) {
+		const int iData = i - 8;
+		m_ui.KeySignatureAccidentalsComboBox->addItem(
+			qtractorTimeScale::keySignatureName(iData, iMode, 0));
+		m_ui.KeySignatureAccidentalsComboBox->setItemData(iIndex++, iData);
+	}
+
+	iIndex = m_ui.KeySignatureAccidentalsComboBox->findData(iAccidentals);
+	if (iIndex >= 0)
+		m_ui.KeySignatureAccidentalsComboBox->setCurrentIndex(iIndex);
+
+	m_ui.KeySignatureAccidentalsComboBox->blockSignals(bBlockSignals);
+}
+
+
 // Make given frame visble at the main tracks view.
 void qtractorTimeScaleForm::ensureVisibleFrame ( unsigned long iFrame )
 {
@@ -437,7 +520,7 @@ void qtractorTimeScaleForm::ensureVisibleFrame ( unsigned long iFrame )
 // Time-scale node selection slot.
 void qtractorTimeScaleForm::selectItem (void)
 {
-	if (m_pTimeScale == NULL)
+	if (m_pTimeScale == nullptr)
 		return;
 
 	if (m_iDirtySetup > 0)
@@ -448,13 +531,13 @@ void qtractorTimeScaleForm::selectItem (void)
 		= static_cast<qtractorTimeScaleListItem *> (
 			m_ui.TimeScaleListView->currentItem());
 
-	if (pListItem == NULL)
+	if (pListItem == nullptr)
 		return;
 
 	qtractorTimeScale::Node   *pNode   = pListItem->node();
 	qtractorTimeScale::Marker *pMarker = pListItem->marker();
 
-	if (pNode == NULL && pMarker == NULL)
+	if (pNode == nullptr && pMarker == nullptr)
 		return;
 
 	if (m_iDirtyCount > 0) {
@@ -463,7 +546,7 @@ void qtractorTimeScaleForm::selectItem (void)
 		if (m_ui.UpdatePushButton->isEnabled())
 			buttons |= QMessageBox::Apply;
 		switch (QMessageBox::warning(this,
-			tr("Warning") + " - " QTRACTOR_TITLE,
+			tr("Warning"),
 			tr("Some settings have been changed.\n\n"
 			"Do you want to apply the changes?"),
 			buttons)) {
@@ -471,8 +554,8 @@ void qtractorTimeScaleForm::selectItem (void)
 			updateItem();
 			// Fall thru...
 		case QMessageBox::Discard:
-			break;;
-		default:    // Cancel.
+			break;
+		default: // Cancel.
 			return;
 		}
 	}
@@ -489,7 +572,7 @@ void qtractorTimeScaleForm::selectItem (void)
 		ensureVisibleFrame(pNode->frame);
 	}
 
-	if (pMarker && pNode == NULL) {
+	if (pMarker && pNode == nullptr) {
 		const unsigned int iBar = m_pTimeScale->barFromFrame(pMarker->frame);
 		m_ui.BarSpinBox->setValue(iBar + 1);
 		m_ui.TimeSpinBox->setValue(pMarker->frame);
@@ -497,6 +580,7 @@ void qtractorTimeScaleForm::selectItem (void)
 	}
 
 	setCurrentMarker(pMarker);
+	setCurrentKeySignature(pMarker);
 
 	m_iDirtySetup = 0;
 	m_iDirtyCount = 0;
@@ -508,7 +592,7 @@ void qtractorTimeScaleForm::selectItem (void)
 // Check whether the current view is elligible for action.
 unsigned int qtractorTimeScaleForm::flags (void) const
 {
-	if (m_pTimeScale == NULL)
+	if (m_pTimeScale == nullptr)
 		return 0;
 
 	unsigned int iFlags = 0;
@@ -553,8 +637,18 @@ unsigned int qtractorTimeScaleForm::flags (void) const
 	const QColor& rgbMarkerColor
 		= m_ui.MarkerTextLineEdit->palette().text().color();
 
+	int iAccidentals = 0;
+	const int iIndex
+		= m_ui.KeySignatureAccidentalsComboBox->currentIndex();
+	if (iIndex >= 0)
+		iAccidentals = m_ui.KeySignatureAccidentalsComboBox->itemData(iIndex).toInt();
+	const int iMode = m_ui.KeySignatureModeComboBox->currentIndex();
+
 	if (pMarker && pMarker->frame == iFrame) {
-		iFlags |= UpdateMarker;
+		if (!sMarkerText.isEmpty())
+			iFlags |= UpdateMarker;
+		if (iAccidentals || iMode)
+			iFlags |= UpdateKeySignature;
 		iFlags |= RemoveMarker;
 	}
 	if (pMarker
@@ -563,8 +657,17 @@ unsigned int qtractorTimeScaleForm::flags (void) const
 		iFlags &= ~UpdateMarker;
 	else if (!sMarkerText.isEmpty())
 		iFlags |=  AddMarker;
-	if (pMarker && pMarker->frame == iFrame)
+	if (pMarker
+		&& pMarker->accidentals == iAccidentals
+		&& pMarker->mode == iMode)
+		iFlags &= ~UpdateKeySignature;
+	else if (iAccidentals || iMode)
+		iFlags |=  AddKeySignature;
+
+	if (pMarker && pMarker->frame == iFrame) {
 		iFlags &= ~AddMarker;
+		iFlags &= ~AddKeySignature;
+	}
 
 	return iFlags;
 }
@@ -573,12 +676,12 @@ unsigned int qtractorTimeScaleForm::flags (void) const
 // Add node method.
 void qtractorTimeScaleForm::addItem (void)
 {
-	if (m_pTimeScale == NULL)
+	if (m_pTimeScale == nullptr)
 		return;
 
 	// Make it as an undoable command...
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	const unsigned int  iFlags = flags();
@@ -603,6 +706,20 @@ void qtractorTimeScaleForm::addItem (void)
 		++m_iDirtyTotal;
 	}
 
+	if (iFlags & AddKeySignature) {
+		int iAccidentals = 0;
+		const int iIndex = m_ui.KeySignatureAccidentalsComboBox->currentIndex();
+		if (iIndex >= 0)
+			iAccidentals = m_ui.KeySignatureAccidentalsComboBox->itemData(iIndex).toInt();
+		const int iMode = m_ui.KeySignatureModeComboBox->currentIndex();
+		if (iAccidentals || iMode) {
+			pSession->execute(
+				new qtractorTimeScaleAddKeySignatureCommand(
+					m_pTimeScale, iFrame, iAccidentals, iMode));
+			++m_iDirtyTotal;
+		}
+	}
+
 	refresh();
 }
 
@@ -610,12 +727,12 @@ void qtractorTimeScaleForm::addItem (void)
 // Update current node.
 void qtractorTimeScaleForm::updateItem (void)
 {
-	if (m_pTimeScale == NULL)
+	if (m_pTimeScale == nullptr)
 		return;
 
 	// Make it as an undoable command...
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	const unsigned int   iFlags = flags();
@@ -650,6 +767,23 @@ void qtractorTimeScaleForm::updateItem (void)
 		}
 	}
 
+	if (iFlags & UpdateKeySignature) {
+		const unsigned long iFrame = m_pTimeScale->frameFromBar(iBar);
+		qtractorTimeScale::Marker *pMarker
+			= m_pTimeScale->markers().seekFrame(iFrame);
+		if (pMarker && pMarker->frame == iFrame) {
+			int iAccidentals = 0;
+			const int iIndex = m_ui.KeySignatureAccidentalsComboBox->currentIndex();
+			if (iIndex >= 0)
+				iAccidentals = m_ui.KeySignatureAccidentalsComboBox->itemData(iIndex).toInt();
+			const int iMode = m_ui.KeySignatureModeComboBox->currentIndex();
+			pSession->execute(
+				new qtractorTimeScaleUpdateKeySignatureCommand(
+					m_pTimeScale, iFrame, iAccidentals, iMode));
+			++m_iDirtyTotal;
+		}
+	}
+
 	refresh();
 }
 
@@ -657,12 +791,12 @@ void qtractorTimeScaleForm::updateItem (void)
 // Remove current node.
 void qtractorTimeScaleForm::removeItem (void)
 {
-	if (m_pTimeScale == NULL)
+	if (m_pTimeScale == nullptr)
 		return;
 
 	// Make it as an undoable command...
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	const unsigned int   iFlags = flags();
@@ -677,7 +811,7 @@ void qtractorTimeScaleForm::removeItem (void)
 			if (pOptions && pOptions->bConfirmRemove) {
 				// Show the warning...
 				if (QMessageBox::warning(this,
-					tr("Warning") + " - " QTRACTOR_TITLE,
+					tr("Warning"),
 					tr("About to remove tempo node:\n\n"
 					"%1 (%2) %3  %4/%5\n\n"
 					"Are you sure?")
@@ -717,7 +851,7 @@ void qtractorTimeScaleForm::removeItem (void)
 // Make changes due.
 void qtractorTimeScaleForm::barChanged ( int iBar )
 {
-	if (m_pTimeScale == NULL)
+	if (m_pTimeScale == nullptr)
 		return;
 	if (m_iDirtySetup > 0)
 		return;
@@ -738,7 +872,11 @@ void qtractorTimeScaleForm::barChanged ( int iBar )
 	if (pMarker && pMarker->frame == iFrame)
 		setCurrentMarker(pMarker);
 	else
-		setCurrentMarker(NULL);
+		setCurrentMarker(nullptr);
+	if (pMarker && iFrame >= pMarker->frame)
+		setCurrentKeySignature(pMarker);
+	else
+		setCurrentKeySignature(nullptr);
 
 	m_iDirtySetup = 0;
 
@@ -754,7 +892,7 @@ void qtractorTimeScaleForm::barChanged ( int iBar )
 
 void qtractorTimeScaleForm::timeChanged ( unsigned long iFrame )
 {
-	if (m_pTimeScale == NULL)
+	if (m_pTimeScale == nullptr)
 		return;
 	if (m_iDirtySetup > 0)
 		return;
@@ -777,7 +915,11 @@ void qtractorTimeScaleForm::timeChanged ( unsigned long iFrame )
 	if (pMarker && pMarker->frame == iFrame)
 		setCurrentMarker(pMarker);
 	else
-		setCurrentMarker(NULL);
+		setCurrentMarker(nullptr);
+	if (pMarker && iFrame >= pMarker->frame)
+		setCurrentKeySignature(pMarker);
+	else
+		setCurrentKeySignature(nullptr);
 
 	m_iDirtySetup = 0;
 
@@ -791,7 +933,7 @@ void qtractorTimeScaleForm::timeChanged ( unsigned long iFrame )
 }
 
 
-// Tempo signature has changed.
+// Tempo/Time-signature has changed.
 void qtractorTimeScaleForm::tempoChanged (void)
 {
 	if (m_iDirtySetup > 0)
@@ -808,6 +950,28 @@ void qtractorTimeScaleForm::tempoChanged (void)
 }
 
 
+// Key signature has changed.
+void qtractorTimeScaleForm::modeChanged ( int iMode )
+{
+	if (m_iDirtySetup > 0)
+		return;
+
+#ifdef CONFIG_DEBUG
+	qDebug("qtractorTimeScaleForm::modeChanged(%d)", iMode);
+#endif
+
+	int iAccidentals = 0;
+	const int iIndex
+		= m_ui.KeySignatureAccidentalsComboBox->currentIndex();
+	if (iIndex >= 0)
+		iAccidentals = m_ui.KeySignatureAccidentalsComboBox->itemData(iIndex).toInt();
+
+	updateKeySignatures(iAccidentals, iMode);
+
+	changed();
+}
+
+
 // Something has changed.
 void qtractorTimeScaleForm::changed (void)
 {
@@ -827,7 +991,7 @@ void qtractorTimeScaleForm::reject (void)
 	// Check if there's any pending changes...
 	if (m_iDirtyCount > 0) {
 		if (QMessageBox::warning(this,
-			tr("Warning") + " - " QTRACTOR_TITLE,
+			tr("Warning"),
 			tr("Some settings have been changed.\n\n"
 			"Do you want to discard the changes?"),
 			QMessageBox::Discard | QMessageBox::Cancel)
@@ -845,7 +1009,7 @@ void qtractorTimeScaleForm::reject (void)
 void qtractorTimeScaleForm::tempoFactor (void)
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	const float fTempoFactor = float(m_ui.TempoFactorSpinBox->value());
@@ -901,7 +1065,7 @@ void qtractorTimeScaleForm::markerColor (void)
 
 	QPalette pal(m_ui.MarkerTextLineEdit->palette());
 
-	QWidget *pParentWidget = NULL;
+	QWidget *pParentWidget = nullptr;
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	QColorDialog::ColorDialogOptions options = 0;
 	if (pOptions && pOptions->bDontUseNativeDialogs) {
@@ -911,7 +1075,7 @@ void qtractorTimeScaleForm::markerColor (void)
 
 	const QColor& color	= QColorDialog::getColor(
 		pal.text().color(), pParentWidget,
-		tr("Marker Color") + " - " QTRACTOR_TITLE, options);
+		tr("Marker Color"), options);
 
 	if (color.isValid()) {
 		pal.setColor(QPalette::Text, color);
@@ -926,8 +1090,8 @@ void qtractorTimeScaleForm::stabilizeForm (void)
 {
 	const unsigned int iFlags = flags();
 //	m_ui.RefreshPushButton->setEnabled(m_iDirtyCount > 0);
-	m_ui.AddPushButton->setEnabled(iFlags & (AddNode | AddMarker));
-	m_ui.UpdatePushButton->setEnabled(iFlags & (UpdateNode | UpdateMarker));
+	m_ui.AddPushButton->setEnabled(iFlags & (AddNode | AddMarker | AddKeySignature));
+	m_ui.UpdatePushButton->setEnabled(iFlags & (UpdateNode | UpdateMarker | UpdateKeySignature));
 	m_ui.RemovePushButton->setEnabled(iFlags & (RemoveNode | RemoveMarker));
 }
 
@@ -944,12 +1108,12 @@ void qtractorTimeScaleForm::contextMenu ( const QPoint& /*pos*/ )
 	pAction = menu.addAction(
 		QIcon(":/images/formAdd.png"),
 		tr("&Add"), this, SLOT(addItem()));
-	pAction->setEnabled(iFlags & (AddNode | AddMarker));
+	pAction->setEnabled(iFlags & (AddNode | AddMarker | AddKeySignature));
 
 	pAction = menu.addAction(
 		QIcon(":/images/formAccept.png"),
 		tr("&Update"), this, SLOT(updateItem()));
-	pAction->setEnabled(iFlags & (UpdateNode | UpdateMarker));
+	pAction->setEnabled(iFlags & (UpdateNode | UpdateMarker | UpdateKeySignature));
 
 	pAction = menu.addAction(
 		QIcon(":/images/formRemove.png"),
