@@ -1,7 +1,7 @@
 // qtractorTrackCommand.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -46,7 +46,7 @@ public:
 
 	// Constructor.
 	qtractorTrackCommand(const QString& sName,
-		qtractorTrack *pTrack, qtractorTrack *pAfterTrack = NULL);
+		qtractorTrack *pTrack, qtractorTrack *pAfterTrack = nullptr);
 
 	// Destructor.
 	virtual ~qtractorTrackCommand();
@@ -91,7 +91,7 @@ public:
 
 	// Constructor.
 	qtractorAddTrackCommand(qtractorTrack *pTrack,
-		qtractorTrack *pAfterTrack = NULL);
+		qtractorTrack *pAfterTrack = nullptr);
 
 	// Track insertion command methods.
 	bool redo();
