@@ -133,10 +133,10 @@ qtractorTrackForm::qtractorTrackForm (
 	QDialog::setWindowModality(Qt::WindowModal);
 
 	// No settings descriptor initially (the caller will set it).
-	m_pTrack = NULL;
+	m_pTrack = nullptr;
 
 	// Current MIDI output bus to be cached.
-	m_pMidiBus = NULL;
+	m_pMidiBus = nullptr;
 
 	// Set some dialog validators...
 	m_ui.BankComboBox->setValidator(new QIntValidator(m_ui.BankComboBox));
@@ -165,7 +165,7 @@ qtractorTrackForm::qtractorTrackForm (
 	}
 	
 	// To save and keep bus/channel patching consistency.
-	m_pOldMidiBus = NULL;
+	m_pOldMidiBus = nullptr;
 	m_iOldChannel = -1;
 	m_sOldInstrumentName.clear();
 	m_iOldBankSelMethod = -1;
@@ -173,10 +173,10 @@ qtractorTrackForm::qtractorTrackForm (
 	m_iOldProg = -1;
 
 	// No last acceptable command yet.
-	m_pLastCommand = NULL;
+	m_pLastCommand = nullptr;
 
 	// MIDI ban/program observer.
-	m_pMidiProgramObserver = NULL;
+	m_pMidiProgramObserver = nullptr;
 
 	// Initialize dirty control state.
 	m_iDirtySetup = 0;
@@ -307,17 +307,24 @@ qtractorTrackForm::~qtractorTrackForm (void)
 // Populate (setup) dialog controls from settings descriptors.
 void qtractorTrackForm::setTrack ( qtractorTrack *pTrack )
 {
-	// Avoid dirty this all up.
-	++m_iDirtySetup;
-
 	// Set target track reference descriptor.
 	m_pTrack = pTrack;
 
+	if (m_pTrack == nullptr)
+		return;
+
+	qtractorSession *pSession = m_pTrack->session();
+	if (pSession == nullptr)
+		return;
+
+	// Avoid dirty this all up.
+	++m_iDirtySetup;
+
 	// Track properties cloning...
 	m_props = m_pTrack->properties();
 
 	// Get reference of the last acceptable command...
-	qtractorCommandList *pCommands = (m_pTrack->session())->commands();
+	qtractorCommandList *pCommands = pSession->commands();
 	m_pLastCommand = pCommands->lastCommand();
 
 	// Set plugin list stuff...
@@ -326,14 +333,14 @@ void qtractorTrackForm::setTrack ( qtractorTrack *pTrack )
 
 	// Initialize dialog widgets...
 	m_ui.TrackNameTextEdit->setPlainText(m_props.trackName);
-	qtractorEngine *pEngine = NULL;
+	qtractorEngine *pEngine = nullptr;
 	switch (m_props.trackType) {
 	case qtractorTrack::Audio:
-		pEngine = (m_pTrack->session())->audioEngine();
+		pEngine = pSession->audioEngine();
 		m_ui.AudioRadioButton->setChecked(true);
 		break;
 	case qtractorTrack::Midi:
-		pEngine = (m_pTrack->session())->midiEngine();
+		pEngine = pSession->midiEngine();
 		m_ui.MidiRadioButton->setChecked(true);
 		break;
 	default:
@@ -425,7 +432,7 @@ qtractorTrack::TrackType qtractorTrackForm::trackType (void) const
 void qtractorTrackForm::accept (void)
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	// Save options...
@@ -477,7 +484,7 @@ void qtractorTrackForm::reject (void)
 		if (m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->isEnabled())
 			buttons |= QMessageBox::Apply;
 		switch (QMessageBox::warning(this,
-			tr("Warning") + " - " QTRACTOR_TITLE,
+			tr("Warning"),
 			tr("Some settings have been changed.\n\n"
 			"Do you want to apply the changes?"),
 			buttons)) {
@@ -494,13 +501,18 @@ void qtractorTrackForm::reject (void)
 
 	if (bReject) {
 		// Bogus track? Unlikely, but...
-		if (m_pTrack) {
+		qtractorSession *pSession = nullptr;
+		if (m_pTrack)
+			pSession = m_pTrack->session();
+		if (pSession) {
 			// Backout all commands made this far...
-			((m_pTrack->session())->commands())->backout(m_pLastCommand);
+			(pSession->commands())->backout(m_pLastCommand);
 			// Restore old output bus...
 			if (!m_sOldOutputBusName.isEmpty()) {
+				pSession->lock();
 				m_pTrack->setOutputBusName(m_sOldOutputBusName);
 				m_pTrack->open(); // re-open...
+				pSession->unlock();
 				m_sOldOutputBusName.clear();
 			}
 			// Try to restore the previously saved patch...
@@ -510,7 +522,7 @@ void qtractorTrackForm::reject (void)
 			}
 		}
 		// Reset plugin list, before too late...
-		m_ui.PluginListView->setPluginList(NULL);
+		m_ui.PluginListView->setPluginList(nullptr);
 		// Just go away.
 		QDialog::reject();
 	}
@@ -529,7 +541,7 @@ void qtractorTrackForm::stabilizeForm (void)
 	const int iItemCount = m_ui.PluginListView->count();
 
 	int iItem = -1;
-	qtractorPlugin *pPlugin = NULL;
+	qtractorPlugin *pPlugin = nullptr;
 	qtractorPluginListItem *pItem
 		= static_cast<qtractorPluginListItem *> (
 			m_ui.PluginListView->currentItem());
@@ -539,7 +551,7 @@ void qtractorTrackForm::stabilizeForm (void)
 	}
 
 	m_ui.AddPluginToolButton->setEnabled(bEnabled);
-	m_ui.RemovePluginToolButton->setEnabled(pPlugin != NULL);
+	m_ui.RemovePluginToolButton->setEnabled(pPlugin != nullptr);
 
 	m_ui.MoveUpPluginToolButton->setEnabled(pItem && iItem > 0);
 	m_ui.MoveDownPluginToolButton->setEnabled(pItem && iItem < iItemCount - 1);
@@ -549,17 +561,21 @@ void qtractorTrackForm::stabilizeForm (void)
 // Retrieve currently assigned MIDI output-bus, if applicable.
 qtractorMidiBus *qtractorTrackForm::midiBus (void) const
 {
-	if (m_pTrack == NULL)
-		return NULL;
+	if (m_pTrack == nullptr)
+		return nullptr;
+
+	qtractorSession *pSession = m_pTrack->session();
+	if (pSession == nullptr)
+		return nullptr;
 
 	// If it ain't MIDI, bail out...
 	if (trackType() != qtractorTrack::Midi)
-		return NULL;
+		return nullptr;
 
 	// MIDI engine...
-	qtractorMidiEngine *pMidiEngine = m_pTrack->session()->midiEngine();
-	if (pMidiEngine == NULL)
-		return NULL;
+	qtractorMidiEngine *pMidiEngine = pSession->midiEngine();
+	if (pMidiEngine == nullptr)
+		return nullptr;
 
 	// MIDI bus...
 	const QString& sOutputBusName
@@ -598,15 +614,15 @@ int qtractorTrackForm::midiProg (void) const
 // Refresh instrument list.
 void qtractorTrackForm::updateInstruments (void)
 {
-	if (m_pTrack == NULL)
+	if (m_pTrack == nullptr)
 		return;
 
 	qtractorSession *pSession = m_pTrack->session();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	qtractorInstrumentList *pInstruments = pSession->instruments();
-	if (pInstruments == NULL)
+	if (pInstruments == nullptr)
 		return;
 
 	// Avoid superfluous change notifications...
@@ -640,7 +656,7 @@ void qtractorTrackForm::updateInstruments (void)
 void qtractorTrackForm::updateInstrumentsAdd (
 	const QIcon& icon, qtractorMidiManager *pMidiManager )
 {
-	if (pMidiManager == NULL)
+	if (pMidiManager == nullptr)
 		return;
 
 	pMidiManager->updateInstruments();
@@ -657,21 +673,28 @@ void qtractorTrackForm::updateInstrumentsAdd (
 // Update track type and buses.
 void qtractorTrackForm::updateTrackType ( qtractorTrack::TrackType trackType )
 {
+	if (m_pTrack == nullptr)
+		return;
+
+	qtractorSession *pSession = m_pTrack->session();
+	if (pSession == nullptr)
+		return;
+
 	// Avoid superfluos change notifications...
 	++m_iDirtySetup;
 
 	// Renew the MIDI bank/program observer.
 	if (m_pMidiProgramObserver) {
 		delete m_pMidiProgramObserver;
-		m_pMidiProgramObserver = NULL;
+		m_pMidiProgramObserver = nullptr;
 	}
 
 	// Make changes due to track type change.
-	qtractorEngine *pEngine = NULL;
+	qtractorEngine *pEngine = nullptr;
 	QIcon icon;
 	switch (trackType) {
 	case qtractorTrack::Audio:
-		pEngine = m_pTrack->session()->audioEngine();
+		pEngine = pSession->audioEngine();
 		icon = QIcon(":/images/trackAudio.png");
 		m_ui.MidiGroupBox->hide();
 		m_ui.MidiGroupBox->setEnabled(false);
@@ -679,7 +702,7 @@ void qtractorTrackForm::updateTrackType ( qtractorTrack::TrackType trackType )
 		m_ui.OutputBusNameComboBox->setEnabled(true);
 		break;
 	case qtractorTrack::Midi:
-		pEngine = m_pTrack->session()->midiEngine();
+		pEngine = pSession->midiEngine();
 		icon = QIcon(":/images/trackMidi.png");
 		m_ui.MidiGroupBox->show();
 		m_ui.MidiGroupBox->setEnabled(true);
@@ -734,7 +757,7 @@ void qtractorTrackForm::updateChannel ( int iChannel,
 		return;
 
 	// MIDI bus...
-	if (m_pMidiBus == NULL)
+	if (m_pMidiBus == nullptr)
 		return;
 
 #ifdef CONFIG_DEBUG
@@ -781,11 +804,11 @@ void qtractorTrackForm::updateChannel ( int iChannel,
 void qtractorTrackForm::updateBanks ( const QString& sInstrumentName,
 	int iBankSelMethod, int iBank, int iProg )
 {
-	if (m_pTrack == NULL)
+	if (m_pTrack == nullptr)
 		return;
 
 	qtractorSession *pSession = m_pTrack->session();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 //	if (sInstrumentName.isEmpty())
@@ -797,7 +820,7 @@ void qtractorTrackForm::updateBanks ( const QString& sInstrumentName,
 #endif
 
 	qtractorInstrumentList *pInstruments = pSession->instruments();
-	if (pInstruments == NULL)
+	if (pInstruments == nullptr)
 		return;
 
 	// Avoid superfluos change notifications...
@@ -894,11 +917,11 @@ void qtractorTrackForm::updateBanks ( const QString& sInstrumentName,
 void qtractorTrackForm::updatePrograms (  const QString& sInstrumentName,
 	int iBank, int iProg )
 {
-	if (m_pTrack == NULL)
+	if (m_pTrack == nullptr)
 		return;
 
 	qtractorSession *pSession = m_pTrack->session();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 //	if (sInstrumentName.isEmpty())
@@ -910,7 +933,7 @@ void qtractorTrackForm::updatePrograms (  const QString& sInstrumentName,
 #endif
 
 	qtractorInstrumentList *pInstruments = pSession->instruments();
-	if (pInstruments == NULL)
+	if (pInstruments == nullptr)
 		return;
 
 	// Avoid superfluos change notifications...
@@ -995,7 +1018,7 @@ bool qtractorTrackForm::updateBanksAdd (
 	const QIcon& icon, qtractorMidiManager *pMidiManager,
 	const QString& sInstrumentName, int iBank, int& iBankIndex )
 {
-	if (pMidiManager == NULL)
+	if (pMidiManager == nullptr)
 		return false;
 
 	const qtractorMidiManager::Instruments& list
@@ -1029,7 +1052,7 @@ bool qtractorTrackForm::updateProgramsAdd (
 	const QIcon& icon, qtractorMidiManager *pMidiManager,
 	const QString& sInstrumentName, int iBank, int iProg, int& iProgIndex )
 {
-	if (pMidiManager == NULL)
+	if (pMidiManager == nullptr)
 		return false;
 
 	const qtractorMidiManager::Instruments& list
@@ -1169,14 +1192,14 @@ void qtractorTrackForm::trackIconClicked (void)
 		sFilename.clear();
 
 	const QString& sTitle
-		= tr("Track Icon") + " - " QTRACTOR_TITLE;
+		= tr("Track Icon");
 
 	QStringList filters;
 	filters.append(tr("Image files (%1)").arg("*.png *.xpm *.jpg *.jpeg"));
 	filters.append(tr("All files (*.*)"));
 	const QString& sFilter = filters.join(";;");
 
-	QWidget *pParentWidget = NULL;
+	QWidget *pParentWidget = nullptr;
 	QFileDialog::Options options = 0;
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions && pOptions->bDontUseNativeDialogs) {
@@ -1186,7 +1209,7 @@ void qtractorTrackForm::trackIconClicked (void)
 #if 1//QT_VERSION < QT_VERSION_CHECK(4, 4, 0)
 	// Ask for the filename to open...
 	sFilename = QFileDialog::getOpenFileName(pParentWidget,
-		sTitle, sFilename, sFilter, NULL, options);
+		sTitle, sFilename, sFilter, nullptr, options);
 #else
 	// Construct open-file dialog...
 	QFileDialog fileDialog(pParentWidget, sTitle, sFilename, sFilter);
@@ -1212,12 +1235,18 @@ void qtractorTrackForm::trackTypeChanged (void)
 	if (m_iDirtySetup > 0)
 		return;
 
-	if (m_pTrack == NULL)
+	if (m_pTrack == nullptr)
+		return;
+
+	qtractorSession *pSession = m_pTrack->session();
+	if (pSession == nullptr)
 		return;
 
 	if (!m_sOldOutputBusName.isEmpty()) {
+		pSession->lock();
 		m_pTrack->setOutputBusName(m_sOldOutputBusName);
 		m_pTrack->open(); // re-open...
+		pSession->unlock();
 		m_sOldOutputBusName.clear();
 	}
 
@@ -1226,7 +1255,7 @@ void qtractorTrackForm::trackTypeChanged (void)
 		m_pOldMidiBus->setPatch(m_iOldChannel, m_sOldInstrumentName,
 			m_iOldBankSelMethod, m_iOldBank, m_iOldProg, m_pTrack);
 		// Reset restorable patch reference...
-		m_pOldMidiBus = NULL;
+		m_pOldMidiBus = nullptr;
 		m_iOldChannel = -1;
 		m_sOldInstrumentName.clear();
 		m_iOldBankSelMethod = -1;
@@ -1259,35 +1288,28 @@ void qtractorTrackForm::outputBusNameChanged ( const QString& sBusName )
 	if (m_iDirtySetup > 0)
 		return;
 
-	if (m_pTrack == NULL)
+	if (m_pTrack == nullptr)
 		return;
 
-	// It all depends on the track type we're into...
-	const qtractorTrack::TrackType trackType
-		= qtractorTrackForm::trackType();
+	qtractorSession *pSession = m_pTrack->session();
+	if (pSession == nullptr)
+		return;
 
-	switch (trackType) {
-	case qtractorTrack::Audio: {
-		// (Re)initialize plugin-list audio output bus properly...
-		const QString& sOutputBusName
-			= m_pTrack->outputBusName();
-		if (sOutputBusName != sBusName) {
-			if (m_sOldOutputBusName.isEmpty() && !sOutputBusName.isEmpty())
-				m_sOldOutputBusName = sOutputBusName;
-			m_pTrack->setOutputBusName(sBusName);
-			m_pTrack->open(); // re-open...
-		}
-		break;
-	}
-	case qtractorTrack::Midi:
-		// Re-open MIDI track and output bus properly...
-		m_pTrack->open();
+	// (Re)initialize output bus properly...
+	const QString& sOutputBusName
+		= m_pTrack->outputBusName();
+	if (sOutputBusName != sBusName) {
+		pSession->lock();
+		if (m_sOldOutputBusName.isEmpty() && !sOutputBusName.isEmpty())
+			m_sOldOutputBusName = sOutputBusName;
+		m_pTrack->setOutputBusName(sBusName);
+		m_pTrack->open(); // Re-open...
+		pSession->unlock();
 		// Recache the applicable MIDI output bus ...
-		m_pMidiBus = midiBus();
-		updateInstruments();
-		// Fall thru...
-	default:
-		break;
+		if (trackType() == qtractorTrack::Midi) {
+			m_pMidiBus = midiBus();
+			updateInstruments();
+		}
 	}
 
 	channelChanged(m_ui.ChannelSpinBox->value());
@@ -1300,14 +1322,21 @@ void qtractorTrackForm::busNameClicked (void)
 	if (m_iDirtySetup > 0)
 		return;
 
+	if (m_pTrack == nullptr)
+		return;
+
+	qtractorSession *pSession = m_pTrack->session();
+	if (pSession == nullptr)
+		return;
+
 	// Depending on track type...
-	qtractorEngine *pEngine = NULL;
+	qtractorEngine *pEngine = nullptr;
 	switch (trackType()) {
 	case qtractorTrack::Audio:
-		pEngine = m_pTrack->session()->audioEngine();
+		pEngine = pSession->audioEngine();
 		break;
 	case qtractorTrack::Midi:
-		pEngine = m_pTrack->session()->midiEngine();
+		pEngine = pSession->midiEngine();
 		break;
 	case qtractorTrack::None:
 	default:
@@ -1466,9 +1495,9 @@ void qtractorTrackForm::progChanged (void)
 void qtractorTrackForm::selectForegroundColor (void)
 {
 	const QString& sTitle
-		= tr("Foreground Color") + " - " QTRACTOR_TITLE;
+		= tr("Foreground Color");
 
-	QWidget *pParentWidget = NULL;
+	QWidget *pParentWidget = nullptr;
 	QColorDialog::ColorDialogOptions options = 0;
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions && pOptions->bDontUseNativeDialogs) {
@@ -1492,9 +1521,9 @@ void qtractorTrackForm::selectForegroundColor (void)
 void qtractorTrackForm::selectBackgroundColor (void)
 {
 	const QString& sTitle
-		= tr("Background Color") + " - " QTRACTOR_TITLE;
+		= tr("Background Color");
 
-	QWidget *pParentWidget = NULL;
+	QWidget *pParentWidget = nullptr;
 	QColorDialog::ColorDialogOptions options = 0;
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions && pOptions->bDontUseNativeDialogs) {
