@@ -62,7 +62,7 @@ qtractorTrackTime::qtractorTrackTime ( qtractorTracks *pTracks,
 	m_dragState  = DragNone;
 	m_dragCursor = DragNone;
 
-	m_pDragMarker = NULL;
+	m_pDragMarker = nullptr;
 
 	qtractorScrollView::setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 	qtractorScrollView::setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -103,15 +103,16 @@ void qtractorTrackTime::updatePixmap ( int cx, int /* cy */)
 	m_pixmap.fill(pal.window().color());
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	qtractorTimeScale *pTimeScale = pSession->timeScale();
-	if (pTimeScale == NULL)
+	if (pTimeScale == nullptr)
 		return;
 	
 	QPainter painter(&m_pixmap);
 //	painter.initFrom(this);
+	painter.setFont(qtractorScrollView::font());
 
 	// Draw the time scale...
 	//
@@ -124,7 +125,7 @@ void qtractorTrackTime::updatePixmap ( int cx, int /* cy */)
 	unsigned short iPixelsPerBeat = pNode->pixelsPerBeat();
 	unsigned int iBeat = pNode->beatFromPixel(cx);
 	if (iBeat > 0) pNode = cursor.seekBeat(--iBeat);
-	x = x1 = pNode->pixelFromBeat(iBeat) - cx;
+	x = x1 = pNode->pixelFromBeat(iBeat) - cx - 1;
 
 	while (x < w) {
 		const bool bBeatIsBar = pNode->beatIsBar(iBeat);
@@ -158,7 +159,7 @@ void qtractorTrackTime::updatePixmap ( int cx, int /* cy */)
 			}
 		}
 		pNode = cursor.seekBeat(++iBeat);
-		x = pNode->pixelFromBeat(iBeat) - cx;
+		x = pNode->pixelFromBeat(iBeat) - cx - 1;
 	}
 
 	// Draw location markers, if any...
@@ -167,8 +168,18 @@ void qtractorTrackTime::updatePixmap ( int cx, int /* cy */)
 	while (pMarker) {
 		x = pTimeScale->pixelFromFrame(pMarker->frame) - cx + 4;
 		if (x > w) break;
-		painter.setPen(pMarker->color);
-		painter.drawText(x, y2, pMarker->text);
+		if (pMarker->accidentals || pMarker->mode) {
+			const QString& sKeySignature
+				= qtractorTimeScale::keySignatureName(
+					pMarker->accidentals, pMarker->mode);
+			painter.setPen(Qt::darkGray);
+			painter.drawText(x, y2, sKeySignature);
+			x += fm.horizontalAdvance(sKeySignature) + 4;
+		}
+		if (!pMarker->text.isEmpty()) {
+			painter.setPen(pMarker->color);
+			painter.drawText(x, y2, pMarker->text);
+		}
 		pMarker = pMarker->next();
 	}
 
@@ -318,11 +329,11 @@ void qtractorTrackTime::contentsXMovingSlot ( int cx, int /*cy*/ )
 bool qtractorTrackTime::dragHeadStart ( const QPoint& pos )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	qtractorTimeScale *pTimeScale = pSession->timeScale();
-	if (pTimeScale == NULL)
+	if (pTimeScale == nullptr)
 		return false;
 
 	// Try to catch mouse clicks over the
@@ -703,11 +714,11 @@ void qtractorTrackTime::mouseReleaseEvent ( QMouseEvent *pMouseEvent )
 void qtractorTrackTime::mouseDoubleClickEvent ( QMouseEvent *pMouseEvent )
 {
 	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	// Direct snap positioning...
@@ -773,7 +784,7 @@ void qtractorTrackTime::resetDragState (void)
 	m_dragState  = DragNone;
 	m_dragCursor = DragNone;
 
-	m_pDragMarker = NULL;
+	m_pDragMarker = nullptr;
 
 	// HACK: give focus to track-view... 
 	m_pTracks->trackView()->setFocus();
@@ -852,11 +863,11 @@ void qtractorTrackTime::showToolTip ( unsigned long iFrame ) const
 		return;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	qtractorTimeScale *pTimeScale = pSession->timeScale();
-	if (pTimeScale == NULL)
+	if (pTimeScale == nullptr)
 		return;
 
 	QString sToolTip;
@@ -905,11 +916,11 @@ void qtractorTrackTime::showToolTip ( const QRect& rect ) const
 		return;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	qtractorTimeScale *pTimeScale = pSession->timeScale();
-	if (pTimeScale == NULL)
+	if (pTimeScale == nullptr)
 		return;
 
 	const unsigned long iFrameStart = pTimeScale->frameSnap(
