@@ -164,7 +164,7 @@ qtractorTrackView *qtractorTracks::trackView (void) const
 void qtractorTracks::horizontalZoomStep ( int iZoomStep )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	int iHorizontalZoom = pSession->horizontalZoom() + iZoomStep;
@@ -190,7 +190,7 @@ void qtractorTracks::horizontalZoomStep ( int iZoomStep )
 void qtractorTracks::verticalZoomStep ( int iZoomStep )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 		
 	int iVerticalZoom = pSession->verticalZoom() + iZoomStep;
@@ -252,7 +252,7 @@ void qtractorTracks::zoomOut (void)
 void qtractorTracks::zoomReset (void)
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	ZoomCenter zc;
@@ -325,7 +325,7 @@ void qtractorTracks::verticalZoomOutSlot (void)
 void qtractorTracks::viewZoomResetSlot (void)
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	ZoomCenter zc;
@@ -343,26 +343,27 @@ void qtractorTracks::viewZoomResetSlot (void)
 void qtractorTracks::zoomCenterPre ( ZoomCenter& zc ) const
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
+	const int cx = m_pTrackView->contentsX();
+	const int cy = m_pTrackView->contentsY();
+
 	QWidget *pViewport = m_pTrackView->viewport();
 	const QRect& rect = pViewport->rect();
 	const QPoint& pos = pViewport->mapFromGlobal(QCursor::pos());
 	if (rect.contains(pos)) {
 		zc.x = pos.x();
-		zc.y = 0; // pos.y();
+		zc.y = pos.y();
 	} else {
-	#if 0
 		zc.x = 0;
 		zc.y = 0;
-	#else
-		zc.x = (rect.width() >> 1);
-		zc.y = 0; // (rect.height() >> 1);
-	#endif
+		if (cx > rect.width())
+			zc.x += (rect.width() >> 1);
+		if (cy > rect.height())
+			zc.y += (rect.height() >> 1);
 	}
 
-	const int cx = m_pTrackView->contentsX();
 	zc.frame = pSession->frameFromPixel(cx + zc.x);
 }
 
@@ -372,7 +373,7 @@ void qtractorTracks::zoomCenterPre ( ZoomCenter& zc ) const
 void qtractorTracks::zoomCenterPost ( const ZoomCenter& zc )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	int cx = pSession->pixelFromFrame(zc.frame);
@@ -396,7 +397,7 @@ void qtractorTracks::zoomCenterPost ( const ZoomCenter& zc )
 void qtractorTracks::updateContents ( bool bRefresh )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 #ifdef CONFIG_DEBUG_0
@@ -446,22 +447,22 @@ qtractorClip *qtractorTracks::currentClip (void) const
 bool qtractorTracks::newClip (void)
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return false;
 
 	// Create on current track, or take the first...
 	qtractorTrack *pTrack = currentTrack();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		pTrack = pSession->tracks().first();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 
 	// Create the clip prototype...
-	qtractorClip *pClip = NULL;
+	qtractorClip *pClip = nullptr;
 	switch (pTrack->trackType()) {
 	case qtractorTrack::Audio:
 		pClip = new qtractorAudioClip(pTrack);
@@ -475,7 +476,7 @@ bool qtractorTracks::newClip (void)
 	}
 
 	// Correct so far?
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		return false;
 
 	// Set initial default clip parameters...
@@ -536,9 +537,9 @@ bool qtractorTracks::newClip (void)
 // Edit given(current) clip.
 bool qtractorTracks::editClip ( qtractorClip *pClip )
 {
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		pClip = m_pTrackView->currentClip();
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		return false;
 
 	// All else hasn't fail.
@@ -549,21 +550,21 @@ bool qtractorTracks::editClip ( qtractorClip *pClip )
 // Unlink given(current) clip.
 bool qtractorTracks::unlinkClip ( qtractorClip *pClip )
 {
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		pClip = m_pTrackView->currentClip();
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		return false;
 
 	qtractorMidiClip *pMidiClip
 		= static_cast<qtractorMidiClip *> (pClip);
-	if (pMidiClip == NULL)
+	if (pMidiClip == nullptr)
 		return false;
 
 	if (!pMidiClip->isHashLinked())
 		return false;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	// Have a new filename revision...
@@ -604,14 +605,14 @@ bool qtractorTracks::unlinkClip ( qtractorClip *pClip )
 bool qtractorTracks::splitClip ( qtractorClip *pClip )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	const unsigned long iPlayHead  = pSession->playHead();
 
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		pClip = m_pTrackView->currentClip();
-	if (pClip == NULL) {
+	if (pClip == nullptr) {
 		qtractorTrack *pTrack = m_pTrackList->currentTrack();
 		if (pTrack) {
 			pClip = pTrack->clips().first();
@@ -620,7 +621,7 @@ bool qtractorTracks::splitClip ( qtractorClip *pClip )
 		}
 	}
 
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		return false;
 
 	if (!pClip->queryEditor())
@@ -714,7 +715,7 @@ static void midiClipNormalize (
 bool qtractorTracks::normalizeClip ( qtractorClip *pClip )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	// Make it as an undoable command...
@@ -755,13 +756,13 @@ bool qtractorTracks::normalizeClip ( qtractorClip *pClip )
 bool qtractorTracks::normalizeClipCommand (
 	qtractorClipCommand *pClipCommand, qtractorClip *pClip )
 {
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		pClip = m_pTrackView->currentClip();
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		return false;
 
 	qtractorTrack *pTrack = pClip->track();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 
 	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
@@ -781,13 +782,13 @@ bool qtractorTracks::normalizeClipCommand (
 		// Normalize audio clip...
 		qtractorAudioClip *pAudioClip
 			= static_cast<qtractorAudioClip *> (pClip);
-		if (pAudioClip == NULL)
+		if (pAudioClip == nullptr)
 			return false;
 		qtractorAudioBus *pAudioBus
 			= static_cast<qtractorAudioBus *> (pTrack->outputBus());
-		if (pAudioBus == NULL)
+		if (pAudioBus == nullptr)
 			return false;
-		QProgressBar *pProgressBar = NULL;
+		QProgressBar *pProgressBar = nullptr;
 		if (pMainForm)
 			pProgressBar = pMainForm->progressBar();
 		if (pProgressBar) {
@@ -807,7 +808,7 @@ bool qtractorTracks::normalizeClipCommand (
 		// Normalize MIDI clip...
 		qtractorMidiClip *pMidiClip
 			= static_cast<qtractorMidiClip *> (pClip);
-		if (pMidiClip == NULL)
+		if (pMidiClip == nullptr)
 			return false;
 		unsigned char max = 0;
 		pMidiClip->clipExport(midiClipNormalize, &max, iOffset, iLength);
@@ -832,7 +833,7 @@ bool qtractorTracks::executeClipTool ( int iTool, qtractorClip *pClip )
 		return false;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 	
 	// Make it as an undoable named command...
@@ -885,22 +886,22 @@ bool qtractorTracks::executeClipToolCommand (
 	qtractorMidiToolsForm *pMidiToolsForm )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		pClip = m_pTrackView->currentClip();
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		return false;
 
 	qtractorTrack *pTrack = pClip->track();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 	if (pTrack->trackType() != qtractorTrack::Midi)
 		return false;
 
 	qtractorMidiClip *pMidiClip = static_cast<qtractorMidiClip *> (pClip);
-	if (pMidiClip == NULL)
+	if (pMidiClip == nullptr)
 		return false;
 
 	if (pClipToolCommand->isLinkedMidiClip(pMidiClip))
@@ -963,14 +964,14 @@ bool qtractorTracks::importClips (
 		return false;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	// Create on current track, or take the first...
 	qtractorTrack *pTrack = currentTrack();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		pTrack = pSession->tracks().first();
-	if (pTrack == NULL) // || pTrack->trackType() != qtractorTrack::Audio)
+	if (pTrack == nullptr) // || pTrack->trackType() != qtractorTrack::Audio)
 		return addAudioTracks(files, iClipStart);
 
 	// To log this import into session description.
@@ -1069,7 +1070,7 @@ bool qtractorTracks::importClips (
 // Export selected clips.
 bool qtractorTracks::exportClips (void)
 {
-	return mergeExportClips(NULL);
+	return mergeExportClips(nullptr);
 }
 
 
@@ -1077,7 +1078,7 @@ bool qtractorTracks::exportClips (void)
 bool qtractorTracks::mergeClips (void)
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	// Make it as an undoable command...
@@ -1107,7 +1108,7 @@ bool qtractorTracks::mergeExportClips ( qtractorClipCommand *pClipCommand )
 
 	// Should be one single track...
 	qtractorTrack *pTrack = pClipSelect->singleTrack();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 
 	// Dispatch to specialized method...
@@ -1163,28 +1164,28 @@ bool qtractorTracks::mergeExportAudioClips ( qtractorClipCommand *pClipCommand )
 	// Should be one single MIDI track...
 	qtractorClipSelect *pClipSelect = m_pTrackView->clipSelect();
 	qtractorTrack *pTrack = pClipSelect->singleTrack();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 	if (pTrack->trackType() != qtractorTrack::Audio)
 		return false;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	qtractorAudioBus *pAudioBus
 		= static_cast<qtractorAudioBus *> (pTrack->outputBus());
-	if (pAudioBus == NULL)
+	if (pAudioBus == nullptr)
 		return false;
 
 	const QString& sExt
 		= qtractorAudioFileFactory::defaultExt();
 	const QString& sTitle
-		= tr("Merge/Export Audio Clip") + " - " QTRACTOR_TITLE;
+		= tr("Merge/Export Audio Clip");
 	const QString& sFilter
 		= qtractorAudioFileFactory::filters().join(";;");
 
-	QWidget *pParentWidget = NULL;
+	QWidget *pParentWidget = nullptr;
 	QFileDialog::Options options = 0;
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions && pOptions->bDontUseNativeDialogs) {
@@ -1194,7 +1195,7 @@ bool qtractorTracks::mergeExportAudioClips ( qtractorClipCommand *pClipCommand )
 #if 1//QT_VERSION < QT_VERSION_CHECK(4, 4, 0)
 	// Ask for the filename to save...
 	QString sFilename = QFileDialog::getSaveFileName(pParentWidget, sTitle,
-		pSession->createFilePath(pTrack->trackName(), sExt), sFilter, NULL, options);
+		pSession->createFilePath(pTrack->trackName(), sExt), sFilter, nullptr, options);
 #else
 	// Construct save-file dialog...
 	QFileDialog fileDialog(pParentWidget, sTitle,
@@ -1227,7 +1228,7 @@ bool qtractorTracks::mergeExportAudioClips ( qtractorClipCommand *pClipCommand )
 	qtractorAudioFile *pAudioFile
 		= qtractorAudioFileFactory::createAudioFile(sFilename,
 			pAudioBus->channels(), pSession->sampleRate());
-	if (pAudioFile == NULL) {
+	if (pAudioFile == nullptr) {
 		QApplication::restoreOverrideCursor();
 		return false;
 	}
@@ -1275,7 +1276,7 @@ bool qtractorTracks::mergeExportAudioClips ( qtractorClipCommand *pClipCommand )
 	}
 
 	// A progress indication might be friendly...
-	QProgressBar *pProgressBar = NULL;
+	QProgressBar *pProgressBar = nullptr;
 	if (pMainForm)
 		pProgressBar = pMainForm->progressBar();
 	if (pProgressBar) {
@@ -1438,26 +1439,26 @@ bool qtractorTracks::mergeExportMidiClips ( qtractorClipCommand *pClipCommand )
 	// Should be one single MIDI track...
 	qtractorClipSelect *pClipSelect = m_pTrackView->clipSelect();
 	qtractorTrack *pTrack = pClipSelect->singleTrack();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 	if (pTrack->trackType() != qtractorTrack::Midi)
 		return false;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	// Merge MIDI Clip filename requester...
 	const QString  sExt("mid");
 	const QString& sTitle
-		= tr("Merge/Export MIDI Clip") + " - " QTRACTOR_TITLE;
+		= tr("Merge/Export MIDI Clip");
 
 	QStringList filters;
 	filters.append(tr("MIDI files (*.mid *.smf *.midi)"));
 	filters.append(tr("All files (*.*)"));
 	const QString& sFilter = filters.join(";;");
 
-	QWidget *pParentWidget = NULL;
+	QWidget *pParentWidget = nullptr;
 	QFileDialog::Options options = 0;
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions && pOptions->bDontUseNativeDialogs) {
@@ -1467,7 +1468,7 @@ bool qtractorTracks::mergeExportMidiClips ( qtractorClipCommand *pClipCommand )
 #if 1//QT_VERSION < QT_VERSION_CHECK(4, 4, 0)
 	// Ask for the filename to save...
 	QString sFilename = QFileDialog::getSaveFileName(pParentWidget, sTitle,
-		pSession->createFilePath(pTrack->trackName(), sExt), sFilter, NULL, options);
+		pSession->createFilePath(pTrack->trackName(), sExt), sFilter, nullptr, options);
 #else
 	// Construct save-file dialog...
 	QFileDialog fileDialog(pParentWidget, sTitle,
@@ -1547,13 +1548,12 @@ bool qtractorTracks::mergeExportMidiClips ( qtractorClipCommand *pClipCommand )
 	// Set proper tempo map...
 	if (file.tempoMap()) {
 		file.tempoMap()->fromTimeScale(
-			pSession->timeScale(),
-			pSession->tickFromFrame(iTimeStart));
+			pSession->timeScale(), iTimeStart);
 	}
 
 	// Setup track (SMF format 1).
 	if (iFormat == 1)
-		file.writeTrack(NULL);
+		file.writeTrack(nullptr);
 
 	// Setup merge sequence...
 	qtractorMidiSequence seq(pTrack->trackName(), 0, iTicksPerBeat);
@@ -1678,14 +1678,14 @@ bool qtractorTracks::loopClip ( qtractorClip *pClip )
 bool qtractorTracks::rangeClipEx ( qtractorClip *pClip, bool bLoopSet )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	unsigned long iEditHead = 0;
 	unsigned long iEditTail = 0;
 
 	// Multiple clip selection...
-	if (pClip == NULL && isClipSelected()) {
+	if (pClip == nullptr && isClipSelected()) {
 		// Multi-selection extents (in frames)...
 		iEditHead = pSession->sessionEnd();
 		iEditTail = pSession->sessionStart();
@@ -1706,7 +1706,7 @@ bool qtractorTracks::rangeClipEx ( qtractorClip *pClip, bool bLoopSet )
 			}
 		}
 	} else {
-		if (pClip == NULL)
+		if (pClip == nullptr)
 			pClip = m_pTrackView->currentClip();
 		if (pClip) {
 			iEditHead = pClip->clipStart();
@@ -1731,13 +1731,13 @@ bool qtractorTracks::rangeClipEx ( qtractorClip *pClip, bool bLoopSet )
 bool qtractorTracks::tempoClip ( qtractorClip *pClip )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	unsigned long iRangeStart  = pSession->editHead();
 	unsigned long iRangeLength = pSession->editTail() - iRangeStart;
 
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		pClip = m_pTrackView->currentClip();
 	if (pClip) {
 		if (pClip->isClipSelected()) {
@@ -1796,17 +1796,17 @@ bool qtractorTracks::tempoClip ( qtractorClip *pClip )
 // Auto-crossfade a give clip.
 bool qtractorTracks::crossFadeClip ( qtractorClip *pClip )
 {
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		pClip = m_pTrackView->currentClip();
-	if (pClip == NULL)
+	if (pClip == nullptr)
 		return false;
 
 	qtractorTrack *pTrack = pClip->track();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	// We'll build a command...
@@ -1894,7 +1894,7 @@ void qtractorTracks::clipSelectedRange (
 	unsigned long& iSelectEnd ) const
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	iSelectStart = pSession->sessionEnd();
@@ -1978,9 +1978,9 @@ void qtractorTracks::splitSelect (void)
 void qtractorTracks::selectEditRange ( bool bReset )
 {
 	if (m_pTrackView->isCurveEdit())
-		m_pTrackView->selectCurveTrackRange(NULL, bReset);
+		m_pTrackView->selectCurveTrackRange(nullptr, bReset);
 	else
-		m_pTrackView->selectClipTrackRange(NULL, bReset);
+		m_pTrackView->selectClipTrackRange(nullptr, bReset);
 }
 
 
@@ -1988,7 +1988,7 @@ void qtractorTracks::selectEditRange ( bool bReset )
 void qtractorTracks::selectCurrentTrack ( bool bReset )
 {
 	qtractorTrack *pTrack = currentTrack();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return;
 
 	if (m_pTrackView->isCurveEdit())
@@ -2002,7 +2002,7 @@ void qtractorTracks::selectCurrentTrack ( bool bReset )
 void qtractorTracks::selectCurrentTrackRange ( bool bReset )
 {
 	qtractorTrack *pTrack = currentTrack();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return;
 
 	if (m_pTrackView->isCurveEdit())
@@ -2045,11 +2045,11 @@ void qtractorTracks::selectInvert (void)
 bool qtractorTracks::insertEditRange ( qtractorTrack *pTrack )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	qtractorTimeScale *pTimeScale = pSession->timeScale();
-	if (pTimeScale == NULL)
+	if (pTimeScale == nullptr)
 		return false;
 
 	unsigned long iInsertStart = pSession->editHead();
@@ -2064,9 +2064,9 @@ bool qtractorTracks::insertEditRange ( qtractorTrack *pTrack )
 	iInsertOptions |= qtractorEditRangeForm::Clips;
 	iInsertOptions |= qtractorEditRangeForm::Automation;
 
-	if (pTrack == NULL) {
+	if (pTrack == nullptr) {
 		qtractorEditRangeForm rangeForm(this);
-		rangeForm.setWindowTitle(tr("Insert Range") + " - " QTRACTOR_TITLE);
+		rangeForm.setWindowTitle(tr("Insert Range"));
 		if (isClipSelected())
 			clipSelectedRange(iInsertStart, iInsertEnd);
 		rangeForm.setSelectionRange(iInsertStart, iInsertEnd);
@@ -2085,7 +2085,7 @@ bool qtractorTracks::insertEditRange ( qtractorTrack *pTrack )
 	int iUpdate = 0;
 
 	qtractorClipRangeCommand *pClipRangeCommand
-		= new qtractorClipRangeCommand(pTrack == NULL
+		= new qtractorClipRangeCommand(pTrack == nullptr
 			? tr("insert range")
 			: tr("insert track range"));
 
@@ -2270,11 +2270,11 @@ int qtractorTracks::insertEditRangeTrack (
 bool qtractorTracks::removeEditRange ( qtractorTrack *pTrack )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	qtractorTimeScale *pTimeScale = pSession->timeScale();
-	if (pTimeScale == NULL)
+	if (pTimeScale == nullptr)
 		return false;
 
 	unsigned long iRemoveStart = pSession->editHead();
@@ -2289,9 +2289,9 @@ bool qtractorTracks::removeEditRange ( qtractorTrack *pTrack )
 	iRemoveOptions |= qtractorEditRangeForm::Clips;
 	iRemoveOptions |= qtractorEditRangeForm::Automation;
 
-	if (pTrack == NULL) {
+	if (pTrack == nullptr) {
 		qtractorEditRangeForm rangeForm(this);
-		rangeForm.setWindowTitle(tr("Remove Range") + " - " QTRACTOR_TITLE);
+		rangeForm.setWindowTitle(tr("Remove Range"));
 		if (isClipSelected())
 			clipSelectedRange(iRemoveStart, iRemoveEnd);
 		rangeForm.setSelectionRange(iRemoveStart, iRemoveEnd);
@@ -2310,7 +2310,7 @@ bool qtractorTracks::removeEditRange ( qtractorTrack *pTrack )
 	int iUpdate = 0;
 
 	qtractorClipRangeCommand *pClipRangeCommand
-		= new qtractorClipRangeCommand(pTrack == NULL
+		= new qtractorClipRangeCommand(pTrack == nullptr
 			? tr("remove range")
 			: tr("remove track range"));
 
@@ -2547,11 +2547,11 @@ int qtractorTracks::removeEditRangeTrack (
 bool qtractorTracks::addTrack (void)
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return false;
 
 	// Create a new track right away...
@@ -2592,13 +2592,13 @@ bool qtractorTracks::addTrack (void)
 bool qtractorTracks::removeTrack ( qtractorTrack *pTrack )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	// Get the list view item reference of the intended track...
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		pTrack = currentTrack();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 
 	// Don't remove tracks engaged in recording...
@@ -2609,7 +2609,7 @@ bool qtractorTracks::removeTrack ( qtractorTrack *pTrack )
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions && pOptions->bConfirmRemove) {
 		if (QMessageBox::warning(this,
-			tr("Warning") + " - " QTRACTOR_TITLE,
+			tr("Warning"),
 			tr("About to remove track:\n\n"
 			"\"%1\"\n\n"
 			"Are you sure?")
@@ -2636,17 +2636,17 @@ bool qtractorTracks::removeTrack ( qtractorTrack *pTrack )
 bool qtractorTracks::editTrack ( qtractorTrack *pTrack )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return false;
 
 	// Get the list view item reference of the intended track...
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		pTrack = currentTrack();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 
 	// Don't edit tracks engaged in recording...
@@ -2676,13 +2676,13 @@ bool qtractorTracks::editTrack ( qtractorTrack *pTrack )
 bool qtractorTracks::copyTrack ( qtractorTrack *pTrack )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	// Get the list view item reference of the intended track...
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		pTrack = currentTrack();
-	if (pTrack == NULL)
+	if (pTrack == nullptr)
 		return false;
 
 	// Might take a while...
@@ -2720,7 +2720,7 @@ bool qtractorTracks::addAudioTracks ( const QStringList& files,
 		return false;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 //	pSession->lock();
@@ -2743,7 +2743,7 @@ bool qtractorTracks::addAudioTracks ( const QStringList& files,
 	// Needed whether we'll span to one single track
 	// or will have each clip intto several tracks...
 	const bool bDropSpan = m_pTrackView->isDropSpan();
-	qtractorTrack *pTrack = NULL;
+	qtractorTrack *pTrack = nullptr;
 	int iTrackClip = 0;
 
 	// For each one of those files...
@@ -2753,7 +2753,7 @@ bool qtractorTracks::addAudioTracks ( const QStringList& files,
 		// This is one of the selected filenames....
 		const QString& sPath = iter.next();
 		// Create a new track right away...
-		if (pTrack == NULL || !bDropSpan) {
+		if (pTrack == nullptr || !bDropSpan) {
 			const QColor& color = qtractorTrack::trackColor(++iTrack);
 			pTrack = new qtractorTrack(pSession, qtractorTrack::Audio);
 			pTrack->setBackground(color);
@@ -2820,7 +2820,7 @@ bool qtractorTracks::addMidiTracks ( const QStringList& files,
 		return false;
 
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 //	pSession->lock();
@@ -2936,7 +2936,7 @@ bool qtractorTracks::addMidiTrackChannel ( const QString& sPath,
 	int iTrackChannel, unsigned long iClipStart, qtractorTrack *pAfterTrack )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return false;
 
 	// To log this import into session description.
@@ -3008,7 +3008,7 @@ void qtractorTracks::updateTrack ( qtractorTrack *pTrack )
 void qtractorTracks::updateMidiTrack ( qtractorTrack *pMidiTrack )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
-	if (pSession == NULL)
+	if (pSession == nullptr)
 		return;
 
 	const QString& sBusName = pMidiTrack->outputBusName();
@@ -3025,6 +3025,7 @@ void qtractorTracks::updateMidiTrack ( qtractorTrack *pMidiTrack )
 			pTrack->setMidiBankSelMethod(pMidiTrack->midiBankSelMethod());
 			pTrack->setMidiBank(pMidiTrack->midiBank());
 			pTrack->setMidiProg(pMidiTrack->midiProg());
+			pTrack->updateMidiClips();
 			// Update the track list view, immediately...
 			m_pTrackList->updateTrack(pTrack);
 		}
@@ -3039,12 +3040,12 @@ void qtractorTracks::updateMidiTrack ( qtractorTrack *pMidiTrack )
 
 	// Update MIDI bus patch...
 	qtractorMidiEngine *pMidiEngine = pSession->midiEngine();
-	if (pMidiEngine == NULL)
+	if (pMidiEngine == nullptr)
 		return;
 
 	qtractorMidiBus *pMidiBus
 		= static_cast<qtractorMidiBus *> (pMidiTrack->outputBus());
-	if (pMidiBus == NULL)
+	if (pMidiBus == nullptr)
 		return;
 
 	const qtractorMidiBus::Patch& patch = pMidiBus->patch(iChannel);
@@ -3068,7 +3069,7 @@ void qtractorTracks::selectionChangeNotify (void)
 {
 	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
 	if (pMainForm)
-		pMainForm->selectionNotifySlot(NULL);
+		pMainForm->selectionNotifySlot(nullptr);
 }
 
 
@@ -3077,7 +3078,7 @@ void qtractorTracks::contentsChangeNotify (void)
 {
 	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
 	if (pMainForm)
-		pMainForm->changeNotifySlot(NULL);
+		pMainForm->changeNotifySlot(nullptr);
 }
 
 void qtractorTracks::dirtyChangeNotify (void)
