@@ -1,7 +1,7 @@
 // qtractorWsolaTimeStretcher.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    Adapted and refactored from the SoundTouch library (L)GPL,
    Copyright (C) 2001-2012, Olli Parviainen.
@@ -155,10 +155,10 @@ qtractorWsolaTimeStretcher::qtractorWsolaTimeStretcher (
 	m_bQuickSeek = false;
 
 	m_bMidBufferDirty = false;
-	m_ppMidBuffer = NULL;
-	m_ppRefMidBuffer = NULL;
-	m_ppRefMidBufferUnaligned = NULL;
-	m_ppFrames = NULL;
+	m_ppMidBuffer = nullptr;
+	m_ppRefMidBuffer = nullptr;
+	m_ppRefMidBufferUnaligned = nullptr;
+	m_ppFrames = nullptr;
 
 	m_iOverlapLength = 0;
 
@@ -288,7 +288,7 @@ void qtractorWsolaTimeStretcher::setParameters (
 
 
 // Get routine control parameters, see setParameters() function.
-// Any of the parameters to this function can be NULL, in such case
+// Any of the parameters to this function can be nullptr, in such case
 // corresponding parameter value isn't returned.
 void qtractorWsolaTimeStretcher::getParameters (
 	unsigned int *piSampleRate,
