@@ -1,7 +1,7 @@
 // qtractor_plugin_scan.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -19,8 +19,8 @@
 
 *****************************************************************************/
 
-#ifndef __qtractor_dssi_scan_h
-#define __qtractor_dssi_scan_h
+#ifndef __qtractor_plugin_scan_h
+#define __qtractor_plugin_scan_h
 
 #include <QString>
 
